@@ -19,16 +19,19 @@
 #include "tiling_window_manager.h"
 
 #include <miral/application_info.h>
+#include <miral/toolkit_event.h>
 #include <miral/window_info.h>
 #include <miral/window_manager_tools.h>
 #include <miral/zone.h>
 
 #include <linux/input.h>
 #include <algorithm>
+#include <limits>
 #include <csignal>
 
 namespace ms = mir::scene;
 using namespace miral;
+using namespace miral::toolkit;
 
 namespace
 {
@@ -111,6 +114,8 @@ auto TilingWindowManagerPolicy::place_new_window(
 
     if (app_info.application() != spinner->session())
     {
+        parameters.server_side_decorated() = false;
+
         Rectangle const& tile = tile_for(app_info);
 
         if (!parameters.parent().is_set() || !parameters.parent().value().lock())
@@ -174,6 +179,19 @@ void reset(mir::optional_value<ValueType>& option)
 {
     if (option.is_set()) option.consume();
 }
+
+template<typename ValueType>
+void set_if_needed(mir::optional_value<ValueType>& pending, ValueType const& current, ValueType const& correct)
+{
+    if (current == correct)
+    {
+        reset(pending);
+    }
+    else
+    {
+        pending = correct;
+    }
+}
 }
 
 void TilingWindowManagerPolicy::handle_modify_window(
@@ -206,6 +224,11 @@ void TilingWindowManagerPolicy::constrain_size_and_place(
     auto& info = tools.info_for(window);
     info.clip_area(tile);
 
+    set_if_needed(mods.min_width(), info.min_width(), Width{0});
+    set_if_needed(mods.min_height(), info.min_height(), Height{0});
+    set_if_needed(mods.max_width(), info.max_width(), Width{std::numeric_limits<int>::max()});
+    set_if_needed(mods.max_height(), info.max_height(), Height{std::numeric_limits<int>::max()});
+
     if ((mods.state().is_set() ? mods.state().value() : info.state()) == mir_window_state_maximized)
     {
         mods.top_left() = tile.top_left;
