@@ -27,7 +27,6 @@
 #include <chrono>
 #include <future>
 
-#include <csignal>
 #include <sys/wait.h>
 
 namespace me = mir::examples;
@@ -136,13 +135,6 @@ void me::TestClientRunner::operator()(mir::Server& server)
 
             if (pid == 0)
             {
-                // Enable tests with toolkits supporting mirclient
-                if (auto mir_socket_name = server.mir_socket_name())
-                {
-                    auto const mir_socket = mir_socket_name.value();
-                    setenv("MIR_SOCKET", mir_socket.c_str(), 1);
-                }
-
                 // Enable tests with toolkits supporting Wayland
                 auto const wayland_display = server.wayland_display();
                 setenv("WAYLAND_DISPLAY", wayland_display.value().c_str(),  true);   // configure Wayland socket
