@@ -20,6 +20,7 @@
 #include <miral/command_line_option.h>
 #include <miral/display_configuration_option.h>
 #include <miral/runner.h>
+#include <miral/toolkit_event.h>
 
 #include <linux/input.h>
 
@@ -28,6 +29,7 @@
 int main(int argc, char const* argv[])
 {
     using namespace miral;
+    using namespace miral::toolkit;
 
     MirRunner runner{argc, argv};
 
