@@ -103,6 +103,11 @@ public:
 
     auto is_same_output(Output const& other) const -> bool;
 
+    /// A positive number if this output is part of a logical output group (aka a display wall)
+    /// A single display area will stretch across all outputs in a group
+    /// Zero if this output is not part of a logical group
+    auto logical_group_id() const -> int;
+
 private:
     std::shared_ptr<mir::graphics::DisplayConfigurationOutput> self;
 };
