@@ -1,5 +1,5 @@
 /*
- * Copyright © 2016-2018 Canonical Ltd.
+ * Copyright © 2016-2020 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3 as
@@ -21,7 +21,12 @@
 
 #include <mir/geometry/displacement.h>
 #include <mir/geometry/rectangles.h>
-#include <mir_toolkit/event.h>
+#include <mir_toolkit/common.h>
+
+struct MirKeyboardEvent;
+struct MirTouchEvent;
+struct MirPointerEvent;
+struct MirInputEvent;
 
 #include <memory>
 
@@ -269,44 +274,21 @@ public:
      */
     virtual auto confirm_inherited_move(WindowInfo const& window_info, Displacement movement) -> Rectangle = 0;
 
-    virtual ~WindowManagementPolicy() = default;
-    WindowManagementPolicy() = default;
-    WindowManagementPolicy(WindowManagementPolicy const&) = delete;
-    WindowManagementPolicy& operator=(WindowManagementPolicy const&) = delete;
-
-/**
-* Handle additional requests related to application zones
-*
-* \note This interface is intended to be implemented by a WindowManagementPolicy implementation. We can't add these
-* functions directly to that interface without breaking ABI (the vtable could be incompatible). When initializing the
-* window manager this interface will be detected by dynamic_cast and registered accordingly.
-*  @{ */
-    class ApplicationZoneAddendum
-    {
-    public:
-        ApplicationZoneAddendum() = default;
-        virtual ~ApplicationZoneAddendum() = default;
-        ApplicationZoneAddendum(ApplicationZoneAddendum const&) = delete;
-        ApplicationZoneAddendum& operator=(ApplicationZoneAddendum const&) = delete;
-        /**
-         * Attempts to dynamic_cast the given policy into an ApplicationZoneAddendum.
-         * If successful, returns the casted pointer.
-         * If unsuccessful, retuns a static instance of an ApplicationZoneAddendum with the functions stubbed out.
-         */
-        static auto from(WindowManagementPolicy* policy) -> ApplicationZoneAddendum*;
-
     /** @name notification of changes to the current application zones
     * An application zone is the area a maximized application will fill.
     * There is often (but not necessarily) one zone per output.
     * The areas normal applications windows should avoid (such as the areas covered by panels)
     * will not be part of an application zone
     *  @{ */
-        virtual void advise_application_zone_create(Zone const& application_zone);
-        virtual void advise_application_zone_update(Zone const& updated, Zone const& original);
-        virtual void advise_application_zone_delete(Zone const& application_zone);
+    virtual void advise_application_zone_create(Zone const& application_zone);
+    virtual void advise_application_zone_update(Zone const& updated, Zone const& original);
+    virtual void advise_application_zone_delete(Zone const& application_zone);
     /** @} */
-    };
-/** @} */
+
+    virtual ~WindowManagementPolicy() = default;
+    WindowManagementPolicy() = default;
+    WindowManagementPolicy(WindowManagementPolicy const&) = delete;
+    WindowManagementPolicy& operator=(WindowManagementPolicy const&) = delete;
 };
 
 class WindowManagerTools;
