@@ -1,5 +1,5 @@
 /*
- * Copyright © 2016-2017 Canonical Ltd.
+ * Copyright © 2016-2020 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3 as
@@ -38,6 +38,7 @@ class Window;
 struct WindowInfo;
 struct ApplicationInfo;
 class WindowSpecification;
+class Zone;
 
 /**
  * Workspace is intentionally opaque in the miral API. Its only purpose is to
@@ -128,10 +129,6 @@ public:
     /// Send close request to the window
     void ask_client_to_close(Window const& window);
 
-    /// Close the window by force
-    /// \note ask_client_to_close() is the polite way
-    void force_close(Window const& window);
-
     /// retrieve the active window
     auto active_window() const -> Window;
 
@@ -167,6 +164,10 @@ public:
     /// Find the active output area
     auto active_output() -> mir::geometry::Rectangle const;
 
+    /// Find the active zone area
+    /// \remark Since MirAL 3.0
+    auto active_application_zone() const -> Zone;
+
     /// Raise window and all its children
     void raise_tree(Window const& root);
 
