@@ -30,7 +30,7 @@
 
 namespace mir
 {
-namespace scene { class Surface; struct SurfaceCreationParameters; }
+namespace scene { class Surface; }
 namespace shell { struct SurfaceSpecification; }
 }
 
@@ -56,8 +56,6 @@ public:
     auto operator=(WindowSpecification const& that) -> WindowSpecification&;
 
     WindowSpecification(mir::shell::SurfaceSpecification const& spec);
-    WindowSpecification(mir::scene::SurfaceCreationParameters const& params);
-    void update(mir::scene::SurfaceCreationParameters& params) const;
 
     ~WindowSpecification();
 
@@ -165,7 +163,15 @@ public:
     auto server_side_decorated() -> mir::optional_value<bool>&;
     ///@}
 
+    /// How the window should gain and lose focus
+    /// \remark Since MirAL 3.3
+    ///@{
+    auto focus_mode() const -> mir::optional_value<MirFocusMode> const&;
+    auto focus_mode() -> mir::optional_value<MirFocusMode>&;
+    ///@}
+
 private:
+    friend auto make_surface_spec(WindowSpecification const& miral_spec) -> mir::shell::SurfaceSpecification;
     struct Self;
     std::unique_ptr<Self> self;
 };
