@@ -26,6 +26,7 @@ namespace mir
 {
 namespace input
 {
+class Device;
 class InputDevice;
 
 class InputDeviceRegistry
@@ -34,7 +35,7 @@ public:
     InputDeviceRegistry() = default;
     virtual ~InputDeviceRegistry() = default;
 
-    virtual void add_device(std::shared_ptr<InputDevice> const& device) = 0;
+    virtual auto add_device(std::shared_ptr<InputDevice> const& device) -> std::weak_ptr<Device> = 0;
     virtual void remove_device(std::shared_ptr<InputDevice> const& device) = 0;
 protected:
     InputDeviceRegistry(InputDeviceRegistry const&) = delete;
