@@ -20,26 +20,10 @@
 #define MIR_TEST_DOUBLES_MOCK_PLATFORM_AUTHENTICATION_H_
 
 #include "mir/graphics/platform_authentication.h"
-#include "mir/graphics/platform_operation_message.h"
 #include <gmock/gmock.h>
 
 namespace mir
 {
-namespace graphics
-{
-inline bool operator==(PlatformOperationMessage const& msg1,
-                       PlatformOperationMessage const& msg2)
-{
-    return msg1.data == msg2.data && msg1.fds == msg2.fds;
-}
-
-inline bool operator!=(PlatformOperationMessage const& msg1,
-                       PlatformOperationMessage const& msg2)
-{
-    return !(msg1 == msg2);
-}
-}
-
 namespace test
 {
 namespace doubles
@@ -48,8 +32,6 @@ namespace doubles
 struct MockPlatformAuthentication : graphics::PlatformAuthentication
 {
     MOCK_METHOD0(platform_fd_items, std::vector<int>());
-    MOCK_METHOD2(platform_operation, graphics::PlatformOperationMessage(
-        unsigned int, graphics::PlatformOperationMessage const&));
     MOCK_METHOD0(auth_extension, optional_value<std::shared_ptr<graphics::MesaAuthExtension>>());
     MOCK_METHOD0(set_gbm_extension, optional_value<std::shared_ptr<graphics::SetGbmExtension>>());
     MOCK_METHOD0(drm_fd, optional_value<mir::Fd>());
