@@ -58,14 +58,9 @@ inline MirEvent const* to_address(std::shared_ptr<MirEvent const> const& event)
     return event.get();
 }
 
-inline MirEvent const& to_ref(MirEvent const* event)
+inline MirEvent const* to_address(std::reference_wrapper<MirEvent> const& event)
 {
-    return *event;
-}
-
-inline MirEvent const& to_ref(MirEvent const& event)
-{
-    return event;
+    return &event.get();
 }
 
 inline MirKeyboardEvent const* maybe_key_event(MirEvent const* event)
@@ -157,7 +152,7 @@ MATCHER_P(KeyOfSymbol, keysym, "")
     if (kev == nullptr)
         return false;
 
-    if(mir_keyboard_event_key_code(kev) != static_cast<xkb_keysym_t>(keysym))
+    if(mir_keyboard_event_keysym(kev) != static_cast<xkb_keysym_t>(keysym))
         return false;
 
     return true;
@@ -187,6 +182,15 @@ MATCHER_P(KeyOfScanCode, code, "")
     return true;
 }
 
+MATCHER(KeybaordResyncEvent, "")
+{
+    if (mir_event_get_type(arg.get()) != mir_event_type_input)
+    {
+        return false;
+    }
+    return mir_input_event_get_type(mir_event_get_input_event(arg.get())) == mir_input_event_type_keyboard_resync;
+}
+
 MATCHER_P(MirKeyboardEventMatches, event, "")
 {
     auto expected = maybe_key_event(to_address(event));
@@ -196,7 +200,7 @@ MATCHER_P(MirKeyboardEventMatches, event, "")
         return false;
 
     return mir_keyboard_event_action(expected) == mir_keyboard_event_action(actual) &&
-        mir_keyboard_event_key_code(expected) == mir_keyboard_event_key_code(actual) &&
+        mir_keyboard_event_keysym(expected) == mir_keyboard_event_keysym(actual) &&
         mir_keyboard_event_scan_code(expected) == mir_keyboard_event_scan_code(actual) &&
         mir_keyboard_event_modifiers(expected) == mir_keyboard_event_modifiers(actual);
 }
@@ -521,15 +525,6 @@ MATCHER_P2(WindowEvent, attrib, value, "")
     return true;
 }
 
-MATCHER_P(KeymapEventForDevice, device_id, "")
-{
-    auto as_address = to_address(arg);
-    if (mir_event_get_type(as_address) != mir_event_type_keymap)
-        return false;
-    auto kmev = mir_event_get_keymap_event(as_address);
-    return device_id == mir_keymap_event_get_device_id(kmev);
-}
-
 MATCHER_P(OrientationEvent, direction, "")
 {
     auto as_address = to_address(arg);
@@ -541,7 +536,6 @@ MATCHER_P(OrientationEvent, direction, "")
     return true;
 }
 
-
 MATCHER_P(InputDeviceIdMatches, device_id, "")
 {
     if (mir_event_get_type(to_address(arg)) != mir_event_type_input)
@@ -550,17 +544,6 @@ MATCHER_P(InputDeviceIdMatches, device_id, "")
     return mir_input_event_get_device_id(input_event) == device_id;
 }
 
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-MATCHER(InputConfigurationEvent, "")
-{
-    auto as_address = to_address(arg);
-    if (mir_event_get_type(as_address) != mir_event_type_input_configuration)
-        return true;
-    return false;
-}
-#pragma GCC diagnostic pop
-
 MATCHER(InputDeviceStateEvent, "")
 {
     auto as_address = to_address(arg);
