@@ -39,7 +39,11 @@ namespace mir_test_framework
 {
 class FakeInputDevice;
 
-std::shared_ptr<mir::graphics::Platform> make_stubbed_server_graphics_platform(std::vector<mir::geometry::Rectangle> const& display_rects);
+auto make_stubbed_display_platform(std::vector<mir::geometry::Rectangle> const& display_rects)
+    -> std::shared_ptr<mir::graphics::DisplayPlatform>;
+
+auto make_stubbed_rendering_platform()
+    -> std::shared_ptr<mir::graphics::RenderingPlatform>;
 
 void set_next_display_rects(std::unique_ptr<std::vector<mir::geometry::Rectangle>>&& display_rects);
 
