@@ -21,11 +21,8 @@
 
 #include <stdexcept>
 
-MirTouchEvent::MirTouchEvent()
+MirTouchEvent::MirTouchEvent() : MirInputEvent(mir_input_event_type_touch)
 {
-    event.initInput();
-    event.getInput().initTouch();
-    event.getInput().getTouch().initContacts(mir::capnp::TouchScreenEvent::MAX_COUNT);
 }
 
 MirTouchEvent::MirTouchEvent(MirInputDeviceId id,
@@ -33,47 +30,29 @@ MirTouchEvent::MirTouchEvent(MirInputDeviceId id,
                              std::vector<uint8_t> const& cookie,
                              MirInputEventModifiers modifiers,
                              std::vector<mir::events::ContactState> const& contacts)
-    : MirInputEvent(id,timestamp, modifiers, cookie)
+    : MirInputEvent(mir_input_event_type_touch, id, timestamp, modifiers, cookie),
+      contacts{contacts}
 {
-    event.getInput().initTouch();
+}
 
-    auto tev = event.getInput().getTouch();
-    tev.initContacts(mir::capnp::TouchScreenEvent::MAX_COUNT);
-    tev.setCount(contacts.size());
-
-    for (size_t i = 0; i < contacts.size(); ++i)
-    {
-        using ContactType = mir::capnp::TouchScreenEvent::Contact;
-        auto& contact = contacts[i];
-        auto event_contact = tev.getContacts()[i];
-        event_contact.setId(contact.touch_id);
-        event_contact.setX(contact.x);
-        event_contact.setY(contact.y);
-        event_contact.setPressure(contact.pressure);
-        event_contact.setTouchMajor(contact.touch_major);
-        event_contact.setTouchMinor(contact.touch_minor);
-        event_contact.setOrientation(contact.orientation);
-        auto const action = static_cast<ContactType::TouchAction>(contact.action);
-        event_contact.setAction(action);
-
-        auto capnp_tool_type = static_cast<ContactType::ToolType>(contact.tooltype);
-        event_contact.setToolType(capnp_tool_type);
-    }
+auto MirTouchEvent::clone() const -> MirTouchEvent*
+{
+    return new MirTouchEvent{*this};
 }
 
 size_t MirTouchEvent::pointer_count() const
 {
-    return event.asReader().getInput().getTouch().getCount();
+    return contacts.size();
 }
 
 void MirTouchEvent::set_pointer_count(size_t count)
 {
-    return event.getInput().getTouch().setCount(count);
+    return contacts.resize(count);
 }
 
 void MirTouchEvent::throw_if_out_of_bounds(size_t index) const
 {
-    if (index > event.asReader().getInput().getTouch().getCount())
+    if (index > pointer_count())
          BOOST_THROW_EXCEPTION(std::out_of_range("Out of bounds index in pointer coordinates"));
 }
 
@@ -81,126 +60,124 @@ int MirTouchEvent::id(size_t index) const
 {
     throw_if_out_of_bounds(index);
 
-    return event.asReader().getInput().getTouch().getContacts()[index].getId();
+    return contacts[index].touch_id;
 }
 
 void MirTouchEvent::set_id(size_t index, int id)
 {
     throw_if_out_of_bounds(index);
 
-    event.getInput().getTouch().getContacts()[index].setId(id);
+    contacts[index].touch_id = id;
 }
 
 float MirTouchEvent::x(size_t index) const
 {
     throw_if_out_of_bounds(index);
 
-    return event.asReader().getInput().getTouch().getContacts()[index].getX();
+    return contacts[index].x;
 }
 
 void MirTouchEvent::set_x(size_t index, float x)
 {
     throw_if_out_of_bounds(index);
 
-    event.getInput().getTouch().getContacts()[index].setX(x);
+    contacts[index].x = x;
 }
 
 float MirTouchEvent::y(size_t index) const
 {
     throw_if_out_of_bounds(index);
 
-    return event.asReader().getInput().getTouch().getContacts()[index].getY();
+    return contacts[index].y;
 }
 
 void MirTouchEvent::set_y(size_t index, float y)
 {
     throw_if_out_of_bounds(index);
 
-    event.getInput().getTouch().getContacts()[index].setY(y);
+    contacts[index].y = y;
 }
 
 float MirTouchEvent::touch_major(size_t index) const
 {
     throw_if_out_of_bounds(index);
 
-    return event.asReader().getInput().getTouch().getContacts()[index].getTouchMajor();
+    return contacts[index].touch_major;
 }
 
 void MirTouchEvent::set_touch_major(size_t index, float major)
 {
     throw_if_out_of_bounds(index);
 
-    event.getInput().getTouch().getContacts()[index].setTouchMajor(major);
+    contacts[index].touch_major = major;
 }
 
 float MirTouchEvent::touch_minor(size_t index) const
 {
     throw_if_out_of_bounds(index);
 
-    return event.asReader().getInput().getTouch().getContacts()[index].getTouchMinor();
+    return contacts[index].touch_minor;
 }
 
 void MirTouchEvent::set_touch_minor(size_t index, float minor)
 {
     throw_if_out_of_bounds(index);
 
-    event.getInput().getTouch().getContacts()[index].setTouchMinor(minor);
+    contacts[index].touch_minor = minor;
 }
 
 float MirTouchEvent::pressure(size_t index) const
 {
     throw_if_out_of_bounds(index);
 
-    return event.asReader().getInput().getTouch().getContacts()[index].getPressure();
+    return contacts[index].pressure;
 }
 
 void MirTouchEvent::set_pressure(size_t index, float pressure)
 {
     throw_if_out_of_bounds(index);
 
-    event.getInput().getTouch().getContacts()[index].setPressure(pressure);
+    contacts[index].pressure = pressure;
 }
 
 float MirTouchEvent::orientation(size_t index) const
 {
     throw_if_out_of_bounds(index);
 
-    return event.asReader().getInput().getTouch().getContacts()[index].getOrientation();
+    return contacts[index].orientation;
 }
 
 void MirTouchEvent::set_orientation(size_t index, float orientation)
 {
     throw_if_out_of_bounds(index);
 
-    event.getInput().getTouch().getContacts()[index].setOrientation(orientation);
+    contacts[index].orientation = orientation;
 }
 
 MirTouchTooltype MirTouchEvent::tool_type(size_t index) const
 {
     throw_if_out_of_bounds(index);
 
-    return static_cast<MirTouchTooltype>(event.asReader().getInput().getTouch().getContacts()[index].getToolType());
+    return contacts[index].tooltype;
 }
 
 void MirTouchEvent::set_tool_type(size_t index, MirTouchTooltype tool_type)
 {
     throw_if_out_of_bounds(index);
 
-    auto capnp_tool_type = static_cast<mir::capnp::TouchScreenEvent::Contact::ToolType>(tool_type);
-    event.getInput().getTouch().getContacts()[index].setToolType(capnp_tool_type);
+    contacts[index].tooltype = tool_type;
 }
 
 MirTouchAction MirTouchEvent::action(size_t index) const
 {
     throw_if_out_of_bounds(index);
 
-    return static_cast<MirTouchAction>(event.asReader().getInput().getTouch().getContacts()[index].getAction());
+    return contacts[index].action;
 }
 
 void MirTouchEvent::set_action(size_t index, MirTouchAction action)
 {
     throw_if_out_of_bounds(index);
 
-    event.getInput().getTouch().getContacts()[index].setAction(
-        static_cast<mir::capnp::TouchScreenEvent::Contact::TouchAction>(action));
+    contacts[index].action = action;
 }
