@@ -20,6 +20,7 @@
 #include "mir/geometry/displacement.h"
 #include <algorithm>
 #include <limits>
+#include <ostream>
 
 namespace geom = mir::geometry;
 
@@ -192,3 +193,12 @@ bool geom::Rectangles::operator!=(Rectangles const& rects) const
 {
     return !(*this == rects);
 }
+
+std::ostream& geom::operator<<(std::ostream& out, Rectangles const& value)
+{
+    out << '[';
+    for (auto const& rect : value)
+        out << rect << ", ";
+    out << ']';
+    return out;
+}
