@@ -26,17 +26,16 @@
 #define MIR_COMMON_EVENT_PRIVATE_H_
 
 #include "mir/events/event.h"
-#include "mir/events/close_surface_event.h"
+#include "mir/events/close_window_event.h"
 #include "mir/events/input_event.h"
 #include "mir/events/keyboard_event.h"
-#include "mir/events/keymap_event.h"
 #include "mir/events/touch_event.h"
 #include "mir/events/pointer_event.h"
 #include "mir/events/orientation_event.h"
 #include "mir/events/prompt_session_event.h"
 #include "mir/events/resize_event.h"
-#include "mir/events/surface_event.h"
-#include "mir/events/surface_output_event.h"
+#include "mir/events/window_event.h"
+#include "mir/events/window_output_event.h"
 #include "mir/events/input_device_state_event.h"
 
 #endif /* MIR_COMMON_EVENT_PRIVATE_H_ */
