@@ -52,20 +52,13 @@ namespace compositor
 {
 class BufferStreamFactory;
 class Scene;
-class Drawer;
 class DisplayBufferCompositorFactory;
 class Compositor;
 class CompositorReport;
 }
 namespace frontend
 {
-class Shell;
 class Connector;
-class ConnectorReport;
-class ProtobufIpcFactory;
-class ConnectionCreator;
-class SessionMediatorObserver;
-class MessageProcessorReport;
 class SessionAuthorizer;
 class EventSink;
 class DisplayChanger;
@@ -77,16 +70,13 @@ namespace shell
 {
 class DisplayConfigurationController;
 class InputTargeter;
-class FocusSetter;
 class FocusController;
 class DisplayLayout;
-class HostLifecycleEventListener;
 class Shell;
 class ShellReport;
 class SurfaceStack;
 class PersistentSurfaceStore;
 namespace decoration { class Manager; }
-namespace detail { class FrontendShell; }
 }
 namespace time
 {
@@ -98,18 +88,15 @@ class SurfaceFactory;
 class BroadcastingSessionEventSink;
 class BufferStreamFactory;
 class MediatingDisplayChanger;
-class PixelBuffer;
 class SessionContainer;
 class SessionEventSink;
 class SessionEventHandlerRegister;
 class SessionListener;
 class SessionCoordinator;
-class SnapshotStrategy;
 class SurfaceStack;
 class SceneReport;
 class PromptSessionListener;
 class PromptSessionManager;
-class CoordinateTranslator;
 }
 namespace graphics
 {
@@ -121,11 +108,6 @@ class GraphicBufferAllocator;
 class Cursor;
 class CursorImage;
 class GLConfig;
-namespace nested
-{
-class HostConnection;
-class MirClientHostConnection;
-}
 }
 namespace input
 {
@@ -182,10 +164,8 @@ public:
     /** @name DisplayServer dependencies
      * dependencies of DisplayServer on the rest of the Mir
      *  @{ */
-    std::shared_ptr<frontend::Connector>    the_connector() override;
     std::shared_ptr<frontend::Connector>    the_wayland_connector() override;
     std::shared_ptr<frontend::Connector>    the_xwayland_connector() override;
-    std::shared_ptr<frontend::Connector>    the_prompt_connector() override;
     std::shared_ptr<graphics::Display>      the_display() override;
     std::shared_ptr<compositor::Compositor> the_compositor() override;
     std::shared_ptr<input::InputManager>    the_input_manager() override;
@@ -198,6 +178,9 @@ public:
     std::shared_ptr<EmergencyCleanup>       the_emergency_cleanup() override;
     std::shared_ptr<cookie::Authority>      the_cookie_authority() override;
     std::shared_ptr<scene::Clipboard>       the_clipboard() override;
+    std::shared_ptr<scene::TextInputHub>    the_text_input_hub() override;
+    std::shared_ptr<scene::IdleHub>         the_idle_hub() override;
+    std::shared_ptr<shell::IdleHandler>     the_idle_handler() override;
     std::function<void()>                   the_stop_callback() override;
     void add_wayland_extension(
         std::string const& name,
@@ -265,21 +248,11 @@ public:
     /** @name frontend configuration - dependencies
      * dependencies of frontend on the rest of the Mir
      *  @{ */
-    virtual std::shared_ptr<ObserverRegistrar<frontend::SessionMediatorObserver>>
-        the_session_mediator_observer_registrar();
-    virtual std::shared_ptr<frontend::MessageProcessorReport> the_message_processor_report();
     virtual std::shared_ptr<frontend::SessionAuthorizer>      the_session_authorizer();
-    // the_frontend_shell() is an adapter for the_shell().
-    // To customize this behaviour it is recommended you override wrap_shell().
-    std::shared_ptr<frontend::Shell>                          the_frontend_shell();
     virtual std::shared_ptr<frontend::DisplayChanger>         the_frontend_display_changer();
-    virtual std::shared_ptr<frontend::InputConfigurationChanger> the_input_configuration_changer();
     /** @name frontend configuration - internal dependencies
      * internal dependencies of frontend
      *  @{ */
-    virtual std::shared_ptr<frontend::ConnectionCreator>      the_connection_creator();
-    virtual std::shared_ptr<frontend::ConnectionCreator>      the_prompt_connection_creator();
-    virtual std::shared_ptr<frontend::ConnectorReport>        the_connector_report();
     virtual std::shared_ptr<frontend::SurfaceStack>           the_frontend_surface_stack();
     /** @} */
     /** @} */
@@ -297,7 +270,7 @@ public:
     virtual std::shared_ptr<shell::DisplayLayout>       the_shell_display_layout();
     virtual std::shared_ptr<scene::PromptSessionListener> the_prompt_session_listener();
     virtual std::shared_ptr<scene::PromptSessionManager>  the_prompt_session_manager();
-    virtual std::shared_ptr<shell::HostLifecycleEventListener> the_host_lifecycle_event_listener();
+
     virtual std::shared_ptr<shell::PersistentSurfaceStore> the_persistent_surface_store();
     virtual std::shared_ptr<shell::ShellReport>         the_shell_report();
     /** @} */
@@ -325,7 +298,6 @@ public:
      * services provided by scene for the rest of Mir
      *  @{ */
     virtual std::shared_ptr<scene::SessionCoordinator>  the_session_coordinator();
-    virtual std::shared_ptr<scene::CoordinateTranslator> the_coordinate_translator();
     /** @} */
 
 
@@ -364,22 +336,13 @@ public:
     virtual std::shared_ptr<ConsoleServices> the_console_services();
     auto default_reports() -> std::shared_ptr<void>;
 
-private:
-    // We need to ensure the platform library is destroyed last as the
-    // DisplayConfiguration can hold weak_ptrs to objects created from the library
-    // TODO: We need a better way to manage the lifetimes of platform libraries
-    std::shared_ptr<mir::SharedLibrary> platform_library;
-
 protected:
     std::shared_ptr<options::Option> the_options() const;
     std::shared_ptr<input::DefaultInputDeviceHub>  the_default_input_device_hub();
     std::shared_ptr<graphics::DisplayConfigurationObserver> the_display_configuration_observer();
     std::shared_ptr<input::SeatObserver> the_seat_observer();
-    std::shared_ptr<frontend::SessionMediatorObserver> the_session_mediator_observer();
 
     virtual std::shared_ptr<scene::MediatingDisplayChanger> the_mediating_display_changer();
-    virtual std::shared_ptr<frontend::ProtobufIpcFactory> new_ipc_factory(
-        std::shared_ptr<frontend::SessionAuthorizer> const& session_authorizer);
 
     /** @} */
 
@@ -398,7 +361,6 @@ protected:
     CachedPtr<frontend::Connector>   connector;
     CachedPtr<frontend::Connector>   wayland_connector;
     CachedPtr<frontend::Connector>   xwayland_connector;
-    CachedPtr<frontend::Connector>   prompt_connector;
 
     CachedPtr<input::InputReport> input_report;
     CachedPtr<input::EventFilterChainDispatcher> event_filter_chain_dispatcher;
@@ -413,20 +375,13 @@ protected:
     CachedPtr<input::CursorListener> cursor_listener;
     CachedPtr<input::TouchVisualizer> touch_visualizer;
     CachedPtr<input::Seat> seat;
-    CachedPtr<graphics::Platform>     graphics_platform;
     CachedPtr<graphics::GraphicBufferAllocator> buffer_allocator;
     CachedPtr<graphics::Display>      display;
     CachedPtr<graphics::Cursor>       cursor;
     CachedPtr<graphics::CursorImage>  default_cursor_image;
     CachedPtr<input::CursorImages> cursor_images;
 
-    CachedPtr<frontend::ConnectorReport>   connector_report;
-    CachedPtr<frontend::MessageProcessorReport> message_processor_report;
     CachedPtr<frontend::SessionAuthorizer> session_authorizer;
-    CachedPtr<frontend::EventSink> global_event_sink;
-    CachedPtr<frontend::ConnectionCreator> connection_creator;
-    CachedPtr<frontend::ConnectionCreator> prompt_connection_creator;
-    CachedPtr<frontend::InputConfigurationChanger> input_configuration_changer;
     CachedPtr<renderer::RendererFactory> renderer_factory;
     CachedPtr<compositor::BufferStreamFactory> buffer_stream_factory;
     CachedPtr<scene::SurfaceStack> scene_surface_stack;
@@ -436,9 +391,10 @@ protected:
     CachedPtr<scene::SurfaceFactory> surface_factory;
     CachedPtr<scene::SessionContainer>  session_container;
     CachedPtr<scene::SessionListener> session_listener;
-    CachedPtr<scene::PixelBuffer>       pixel_buffer;
-    CachedPtr<scene::SnapshotStrategy>  snapshot_strategy;
     CachedPtr<scene::Clipboard>         clipboard;
+    CachedPtr<scene::TextInputHub>      text_input_hub;
+    CachedPtr<scene::IdleHub>           idle_hub;
+    CachedPtr<shell::IdleHandler>       idle_handler;
     CachedPtr<shell::DisplayLayout>     shell_display_layout;
     CachedPtr<compositor::DisplayBufferCompositorFactory> display_buffer_compositor_factory;
     CachedPtr<compositor::Compositor> compositor;
@@ -449,15 +405,12 @@ protected:
     CachedPtr<MainLoop> main_loop;
     CachedPtr<ServerStatusListener> server_status_listener;
     CachedPtr<graphics::DisplayConfigurationPolicy> display_configuration_policy;
-    CachedPtr<graphics::nested::MirClientHostConnection> host_connection;
     CachedPtr<scene::MediatingDisplayChanger> mediating_display_changer;
     CachedPtr<graphics::GLConfig> gl_config;
     CachedPtr<scene::PromptSessionListener> prompt_session_listener;
     CachedPtr<scene::PromptSessionManager> prompt_session_manager;
     CachedPtr<scene::SessionCoordinator> session_coordinator;
-    CachedPtr<scene::CoordinateTranslator> coordinate_translator;
     CachedPtr<EmergencyCleanup> emergency_cleanup;
-    CachedPtr<shell::HostLifecycleEventListener> host_lifecycle_event_listener;
     CachedPtr<shell::PersistentSurfaceStore> persistent_surface_store;
     CachedPtr<SharedLibraryProberReport> shared_library_prober_report;
     CachedPtr<shell::Shell> shell;
@@ -475,10 +428,6 @@ private:
         display_configuration_observer_multiplexer;
     CachedPtr<ObserverMultiplexer<input::SeatObserver>>
         seat_observer_multiplexer;
-    CachedPtr<ObserverMultiplexer<frontend::SessionMediatorObserver>>
-        session_mediator_observer_multiplexer;
-
-    virtual std::string the_socket_file() const;
 
     // The following caches and factory functions are internal to the
     // default implementations of corresponding the Mir components
@@ -488,7 +437,6 @@ private:
 
     auto report_factory(char const* report_opt) -> std::unique_ptr<report::ReportFactory>;
 
-    CachedPtr<shell::detail::FrontendShell> frontend_shell;
     std::vector<WaylandExtensionHook> wayland_extension_hooks;
     WaylandProtocolExtensionFilter wayland_extension_filter =
         [](std::shared_ptr<scene::Session> const&, char const*) { return true; };
