@@ -50,7 +50,7 @@ public:
 
     void surface_added(std::shared_ptr<Surface> const& surface) override;
     void surface_removed(std::shared_ptr<Surface> const& surface) override;
-    void surfaces_reordered() override;
+    void surfaces_reordered(SurfaceSet const& affected_surfaces) override;
     
     void scene_changed() override;
 
