@@ -46,13 +46,6 @@ public:
     void reception_mode_set_to(Surface const* surf, input::InputReceptionMode mode) override;
     void cursor_image_set_to(Surface const* surf, graphics::CursorImage const& image) override;
     void client_surface_close_requested(Surface const* surf) override;
-    void keymap_changed(
-        Surface const* surf,
-        MirInputDeviceId id,
-        std::string const& model,
-        std::string const& layout,
-        std::string const& variant,
-        std::string const& options) override;
     void renamed(Surface const* surf, char const*) override;
     void cursor_image_removed(Surface const* surf) override;
     void placed_relative(Surface const* surf, geometry::Rectangle const& placement) override;
