@@ -42,8 +42,6 @@ namespace options { class Option; }
 namespace frontend
 {
 class SessionAuthorizer;
-class SessionMediatorObserver;
-class MirClientSession;
 }
 namespace cookie
 {
@@ -55,7 +53,6 @@ namespace shell
 class DisplayLayout;
 class DisplayConfigurationController;
 class FocusController;
-class HostLifecycleEventListener;
 class InputTargeter;
 class PersistentSurfaceStore;
 class Shell;
@@ -70,7 +67,6 @@ class PromptSessionManager;
 class SessionListener;
 class SessionCoordinator;
 class SurfaceFactory;
-class CoordinateTranslator;
 class Session;
 }
 namespace input
@@ -268,14 +264,6 @@ public:
     /// with can verify Mir-generated cookies, or produce their own.
     void override_the_cookie_authority(Builder<cookie::Authority> const& cookie_authority_builder);
 
-    /// Sets an override functor for creating the coordinate translator.
-    void override_the_coordinate_translator(
-        Builder<scene::CoordinateTranslator> const& coordinate_translator_builder);
-
-    /// Sets an override functor for creating the host lifecycle event listener.
-    void override_the_host_lifecycle_event_listener(
-        Builder<shell::HostLifecycleEventListener> const& host_lifecycle_event_listener_builder);
-
     /// Sets an override functor for creating the input dispatcher.
     void override_the_input_dispatcher(Builder<input::InputDispatcher> const& input_dispatcher_builder);
 
@@ -437,10 +425,6 @@ public:
     auto the_seat_observer_registrar() const ->
         std::shared_ptr<ObserverRegistrar<input::SeatObserver>>;
 
-    /// \return a registrar to add and remove SessionMediatorObservers
-    auto the_session_mediator_observer_registrar() const ->
-        std::shared_ptr<ObserverRegistrar<frontend::SessionMediatorObserver>>;
-
 
 /** @} */
 
@@ -451,17 +435,6 @@ public:
  * @{ */
     using ConnectHandler = std::function<void(std::shared_ptr<scene::Session> const& session)>;
 
-    /// Get a file descriptor that can be used to connect a client
-    /// It can be passed to another process, or used directly with mir_connect()
-    /// using the format "fd://%d".
-    auto open_client_socket() -> Fd;
-
-    /// Get a file descriptor that can be used to connect a client
-    /// It can be passed to another process, or used directly with mir_connect()
-    /// using the format "fd://%d".
-    /// \param connect_handler callback to be invoked when the client connects
-    auto open_client_socket(ConnectHandler const& connect_handler) -> Fd;
-
     /// Get a file descriptor that can be used to connect a Wayland client
     /// \param connect_handler callback to be invoked when the client connects
     auto open_client_wayland(ConnectHandler const& connect_handler) -> int;
@@ -485,9 +458,6 @@ public:
     void set_wayland_extension_filter(
         std::function<bool(std::shared_ptr<scene::Session> const&, char const*)> const& extension_filter);
 
-    /// Get the name of the Mir endpoint (if any) usable as a $MIR_SERVER value
-    auto mir_socket_name() const -> optional_value<std::string>;
-
     /// Get the name of the Wayland endpoint (if any) usable as a $WAYLAND_DISPLAY value
     auto wayland_display() const -> optional_value<std::string>;
 
