@@ -42,6 +42,7 @@ namespace shell
 {
 class SessionContainer;
 class Shell;
+class IdleHandler;
 }
 namespace graphics
 {
@@ -62,6 +63,8 @@ namespace scene
 class ApplicationNotRespondingDetector;
 class Session;
 class Clipboard;
+class TextInputHub;
+class IdleHub;
 }
 
 class MainLoop;
@@ -74,10 +77,8 @@ class ServerConfiguration
 public:
     // TODO most of these interfaces are wider DisplayServer needs...
     // TODO ...some or all of them need narrowing
-    virtual std::shared_ptr<frontend::Connector> the_connector() = 0;
     virtual std::shared_ptr<frontend::Connector> the_wayland_connector() = 0;
     virtual std::shared_ptr<frontend::Connector> the_xwayland_connector() = 0;
-    virtual std::shared_ptr<frontend::Connector> the_prompt_connector() = 0;
     virtual std::shared_ptr<graphics::Display> the_display() = 0;
     virtual std::shared_ptr<compositor::Compositor> the_compositor() = 0;
     virtual std::shared_ptr<input::InputManager> the_input_manager() = 0;
@@ -92,6 +93,9 @@ public:
     virtual auto the_fatal_error_strategy() -> void (*)(char const* reason, ...) = 0;
     virtual std::shared_ptr<scene::ApplicationNotRespondingDetector> the_application_not_responding_detector() = 0;
     virtual std::shared_ptr<scene::Clipboard> the_clipboard() = 0;
+    virtual std::shared_ptr<scene::TextInputHub> the_text_input_hub() = 0;
+    virtual std::shared_ptr<scene::IdleHub> the_idle_hub() = 0;
+    virtual std::shared_ptr<shell::IdleHandler> the_idle_handler() = 0;
     virtual std::function<void()> the_stop_callback() = 0;
     virtual void add_wayland_extension(
         std::string const& name,
