@@ -24,10 +24,10 @@
 #include <mir/log.h>
 #include <mir/scene/session.h>
 #include <mir/scene/surface.h>
-#include <mir/scene/surface_creation_parameters.h>
 #include <mir/shell/display_layout.h>
 #include <mir/shell/persistent_surface_store.h>
 #include <mir/shell/surface_ready_observer.h>
+#include <mir/shell/surface_specification.h>
 
 #include <boost/throw_exception.hpp>
 
@@ -126,10 +126,10 @@ void miral::BasicWindowManager::remove_session(std::shared_ptr<scene::Session> c
 
 auto miral::BasicWindowManager::add_surface(
     std::shared_ptr<scene::Session> const& session,
-    scene::SurfaceCreationParameters const& params,
+    shell::SurfaceSpecification const& params,
     std::function<std::shared_ptr<scene::Surface>(
         std::shared_ptr<scene::Session> const& session,
-        scene::SurfaceCreationParameters const& params)> const& build)
+        shell::SurfaceSpecification const& params)> const& build)
 -> std::shared_ptr<scene::Surface>
 {
     Locker lock{this};
@@ -138,29 +138,23 @@ auto miral::BasicWindowManager::add_surface(
 
     WindowSpecification spec = policy->place_new_window(session_info, place_new_surface(params));
 
-    if (!spec.depth_layer().is_set() && spec.parent().is_set())
-        if (auto parent_surface = spec.parent().value().lock())
-            spec.depth_layer() = parent_surface->depth_layer();
-
-    scene::SurfaceCreationParameters parameters;
-    spec.update(parameters);
-    auto const surface = build(session, parameters);
+    auto const surface = build(session, make_surface_spec(spec));
     Window const window{session, surface};
     auto& window_info = this->window_info.emplace(window, WindowInfo{window, spec}).first->second;
 
-    if (spec.parent().is_set() && spec.parent().value().lock())
-        window_info.parent(info_for(spec.parent().value()).window());
+    session_info.add_window(window);
+
+    auto const parent_surface = spec.parent().is_set() ? spec.parent().value().lock() : nullptr;
+    auto const parent = parent_surface ? info_for(parent_surface).window() : Window{};
+    window_info.parent(parent);
+    if (parent)
+    {
+        info_for(parent).add_child(window);
+    }
 
     if (spec.userdata().is_set())
         window_info.userdata() = spec.userdata().value();
 
-    session_info.add_window(window);
-
-    auto const parent = window_info.parent();
-
-    if (parent)
-        info_for(parent).add_child(window);
-
     for_each_workspace_containing(parent,
         [&](std::shared_ptr<miral::Workspace> const& workspace) { add_tree_to_workspace(window, workspace); });
 
@@ -274,11 +268,11 @@ void miral::BasicWindowManager::remove_window(Application const& application, mi
 }
 
 void miral::BasicWindowManager::refocus(
-    miral::Application const& application, miral::Window const& parent,
+    miral::Application const& application, miral::Window const& hint,
     std::vector<std::shared_ptr<Workspace>> const& workspaces_containing_window)
 {
-    // Try to make the parent active
-    if (parent && select_active_window(parent))
+    // If there's a hint, try using that first
+    if (hint && select_active_window(hint))
         return;
 
     if (can_activate_window_for_session_in_workspace(application, workspaces_containing_window))
@@ -1015,6 +1009,7 @@ void miral::BasicWindowManager::modify_window(WindowInfo& window_info, WindowSpe
     COPY_IF_SET(attached_edges);
     COPY_IF_SET(exclusive_rect);
     COPY_IF_SET(application_id);
+    COPY_IF_SET(focus_mode);
 
 #undef COPY_IF_SET
 
@@ -1164,6 +1159,24 @@ void miral::BasicWindowManager::modify_window(WindowInfo& window_info, WindowSpe
         }
     }
 
+    if (modifications.focus_mode().is_set())
+    {
+        switch (modifications.focus_mode().value())
+        {
+        case mir_focus_mode_grabbing:
+            select_active_window(window);
+            break;
+
+        case mir_focus_mode_disabled:
+            if (window == active_window())
+            {
+                refocus(window.application(), window_info.parent(), workspaces_containing(window));
+            }
+
+        default:;
+        }
+    }
+
     if (modifications.state().is_set())
     {
         set_state(window_info, modifications.state().value());
@@ -1581,8 +1594,26 @@ auto miral::BasicWindowManager::select_active_window(Window const& hint) -> mira
         return hint;
     }
 
+    auto const prev_windows_focus_mode = prev_window ? info_for(prev_window).focus_mode() : mir_focus_mode_focusable;
+    if (prev_windows_focus_mode == mir_focus_mode_grabbing)
+    {
+        return prev_window;
+    }
+
     auto& info_for_hint = info_for(hint);
 
+    if (info_for_hint.focus_mode() == mir_focus_mode_disabled)
+    {
+        if (prev_windows_focus_mode == mir_focus_mode_disabled)
+        {
+            return {};
+        }
+        else
+        {
+            return prev_window;
+        }
+    }
+
     for (auto const& child : info_for_hint.children())
     {
         auto const& info_for_child = info_for(child);
@@ -1770,6 +1801,11 @@ auto miral::BasicWindowManager::place_new_surface(WindowSpecification parameters
     if (!parameters.state().is_set())
         parameters.state() = mir_window_state_restored;
 
+    if (!parameters.size().is_set())
+    {
+        parameters.size() = {640, 480};
+    }
+
     std::shared_ptr<DisplayArea> display_area;
     if (parameters.output_id().is_set())
     {
@@ -1780,8 +1816,7 @@ auto miral::BasicWindowManager::place_new_surface(WindowSpecification parameters
         display_area = active_display_area();
     }
 
-    auto const application_zone = display_area->application_zone.extents();;
-    auto const height = parameters.size().value().height.as_int();
+    auto const application_zone = display_area->application_zone.extents();
 
     bool positioned = false;
 
@@ -1823,18 +1858,28 @@ auto miral::BasicWindowManager::place_new_surface(WindowSpecification parameters
             auto const parent_top_left = parent.top_left();
             auto const centred = parent_top_left
                                  + 0.5*(as_displacement(parent.size()) - as_displacement(parameters.size().value()))
-                                 - DeltaY{(parent.size().height.as_int()-height)/6};
+                                 - (as_delta(parent.size().height) - as_delta(parameters.size().value().height)) / 6;
 
             parameters.top_left() = centred;
             positioned = true;
         }
+
+        if (!parameters.depth_layer().is_set())
+        {
+            parameters.depth_layer() = parent_scene_surface->depth_layer();
+        }
+
+        if (!parameters.focus_mode().is_set())
+        {
+            parameters.focus_mode() = parent_scene_surface->focus_mode();
+        }
     }
 
     if (!positioned)
     {
         auto centred = application_zone.top_left
                        + 0.5*(as_displacement(application_zone.size) - as_displacement(parameters.size().value()))
-                       - DeltaY{(application_zone.size.height.as_int()-height)/6};
+                       - (as_delta(application_zone.size.height) - as_delta(parameters.size().value().height)) / 6;
 
         switch (parameters.state().value())
         {
