@@ -77,10 +77,10 @@ public:
 
     auto add_surface(
         std::shared_ptr<mir::scene::Session> const& session,
-        mir::scene::SurfaceCreationParameters const& params,
+        mir::shell::SurfaceSpecification const& params,
         std::function<std::shared_ptr<mir::scene::Surface>(
             std::shared_ptr<mir::scene::Session> const& session,
-            mir::scene::SurfaceCreationParameters const& params)> const& build)
+            mir::shell::SurfaceSpecification const& params)> const& build)
     -> std::shared_ptr<mir::scene::Surface> override;
 
     void modify_surface(
@@ -92,8 +92,8 @@ public:
         std::shared_ptr<mir::scene::Session> const& session,
         std::weak_ptr<mir::scene::Surface> const& surface) override;
 
-    void add_display(mir::geometry::Rectangle const& area) override
-    __attribute__((deprecated("Mir doesn't reliably call this: it is ignored. Use add_display_for_testing() instead")));
+    [[deprecated("Mir doesn't reliably call this: it is ignored. Use add_display_for_testing() instead")]]
+    void add_display(mir::geometry::Rectangle const& area) override;
 
     void remove_display(mir::geometry::Rectangle const& area) override;
 
