@@ -26,17 +26,18 @@
 #include <mir/server.h>
 #include <mir/udev/wrapper.h>
 
-#include <mir/input/keymap.h>
+#include <mir/input/parameter_keymap.h>
 #include <mir/input/mir_keyboard_config.h>
 
 #define MIR_LOG_COMPONENT "miral::Keymap"
 #include <mir/log.h>
 
-#include <algorithm>
 #include <mutex>
 #include <string>
 #include <vector>
 
+namespace mi = mir::input;
+
 namespace
 {
 std::string keymap_default()
@@ -114,12 +115,18 @@ struct miral::Keymap::Self : mir::input::InputDeviceObserver
     }
 
     void device_added(std::shared_ptr<mir::input::Device> const& device) override
+    try
     {
         std::lock_guard<decltype(mutex)> lock{mutex};
 
         if (mir::contains(device->capabilities(), mir::input::DeviceCapability::keyboard))
             add_keyboard(device);
     }
+    catch (...)
+    {
+        mir::log(mir::logging::Severity::warning, MIR_LOG_COMPONENT, std::current_exception(),
+                 "problem adding device (" + device->name() + ")");
+    }
 
     void device_changed(std::shared_ptr<mir::input::Device> const& device) override
     {
@@ -147,27 +154,29 @@ struct miral::Keymap::Self : mir::input::InputDeviceObserver
 
     void apply_keymap(std::shared_ptr<mir::input::Device> const& keyboard)
     {
+        std::string model = mi::ParameterKeymap::default_model;
         auto const keyboard_config = keyboard->keyboard_configuration();
-        mir::input::Keymap keymap;
-
         if (keyboard_config.is_set())
         {
-            keymap = keyboard_config.value().device_keymap();
+            model = keyboard_config.value().device_keymap()->model();
         }
-
-        keymap.layout = layout;
-        keymap.variant = variant;
-        keymap.options = options;
+        std::shared_ptr<mi::Keymap> keymap{std::make_shared<mi::ParameterKeymap>(model, layout, variant, options)};
         keyboard->apply_keyboard_configuration(std::move(keymap));
     }
 
     void device_removed(std::shared_ptr<mir::input::Device> const& device) override
+    try
     {
         std::lock_guard<decltype(mutex)> lock{mutex};
 
         if (mir::contains(device->capabilities(), mir::input::DeviceCapability::keyboard))
             keyboards.erase(std::find(begin(keyboards), end(keyboards), device));
     }
+    catch (...)
+    {
+        mir::log(mir::logging::Severity::warning, MIR_LOG_COMPONENT, std::current_exception(),
+            "problem removing device (" + device->name() + ")");
+    }
 
     void changes_complete() override
     {
