@@ -31,16 +31,10 @@
 
 namespace miral
 {
-auto launch_app(std::vector<std::string> const& app,
-                mir::optional_value<std::string> const& wayland_display,
-                mir::optional_value<std::string> const& mir_socket,
-                mir::optional_value<std::string> const& x11_display) -> pid_t;
-
 using AppEnvironment = std::map<std::string, std::experimental::optional<std::string>>;
 
 auto launch_app_env(std::vector<std::string> const& app,
     mir::optional_value<std::string> const& wayland_display,
-    mir::optional_value<std::string> const& mir_socket,
     mir::optional_value<std::string> const& x11_display,
     AppEnvironment const& app_env) -> pid_t;
 }
