@@ -56,6 +56,41 @@ auto touch_center(MirTouchEvent const* event) -> mir::geometry::Point
 
     return {total_x/count, total_y/count};
 }
+
+auto is_ancestor(
+    miral::WindowManagerTools const& tools,
+    miral::Window const& maybe_parent,
+    miral::Window const& maybe_child) -> bool
+{
+    if (maybe_parent == maybe_child)
+    {
+        return false;
+    }
+    auto window = maybe_child;
+    while ((window = tools.info_for(window).parent()))
+    {
+        if (window == maybe_parent)
+        {
+            return true;
+        }
+    }
+    return false;
+}
+
+/// Returns true if selecting the new window consums the current input event
+auto selecting_window_consumes_event(
+    miral::WindowManagerTools const& tools,
+    miral::Window const& selected_window) -> bool
+{
+    auto const active = tools.active_window();
+    // Return true if a menu window is currently active and a parent is being selected.
+    // If we don't consume the event in this case popup menus appear after being dismissed.
+    // (see https://github.com/MirServer/mir/issues/1818)
+    return (
+        active &&
+        tools.info_for(active).type() == mir_window_type_menu &&
+        is_ancestor(tools, selected_window, active));
+}
 }
 
 struct miral::MinimalWindowManager::Impl
@@ -361,6 +396,7 @@ bool miral::MinimalWindowManager::Impl::handle_pointer_event(MirPointerEvent con
     {
         if (auto const window = tools.window_at(new_cursor))
         {
+            consumes_event = selecting_window_consumes_event(tools, window);
             tools.select_active_window(window);
         }
     }
@@ -440,6 +476,7 @@ bool miral::MinimalWindowManager::Impl::handle_touch_event(MirTouchEvent const*
     {
         if (auto const window = tools.window_at(new_touch))
         {
+            consumes_event = selecting_window_consumes_event(tools, window);
             tools.select_active_window(window);
         }
     }
