@@ -17,13 +17,10 @@
  */
 
 #include "miral/window_info.h"
-#include "window_info_defaults.h"
 #include "window_info_internal.h"
 
 #include <mir/scene/surface.h>
 
-#include <limits>
-
 using namespace mir::geometry;
 
 miral::WindowInfo::WindowInfo() :
@@ -55,6 +52,11 @@ miral::WindowInfo& miral::WindowInfo::operator=(WindowInfo const& that)
 
 bool miral::WindowInfo::can_be_active() const
 {
+    if (focus_mode() == mir_focus_mode_disabled)
+    {
+        return false;
+    }
+
     switch (type())
     {
     case mir_window_type_normal:       /**< AKA "regular"                       */
@@ -302,7 +304,7 @@ auto miral::WindowInfo::restore_rect() const -> mir::geometry::Rectangle
         default:;
         }
 
-        // Half way between current size and min size is reasonable for a maximized/fullscreen window
+        // Halfway between current size and min size is reasonable for a maximized/fullscreen window
         auto const min_size_disp = Displacement{as_delta(self->min_width), as_delta(self->min_height)};
         Size const reasonable_size{as_size(
             (as_displacement(self->window.size()) - min_size_disp) * 0.5
@@ -467,3 +469,15 @@ auto miral::WindowInfo::application_id() const -> std::string
     else
         return "";
 }
+
+auto miral::WindowInfo::focus_mode() const -> MirFocusMode
+{
+    if (std::shared_ptr<mir::scene::Surface> const surface = self->window)
+    {
+        return surface->focus_mode();
+    }
+    else
+    {
+        return mir_focus_mode_disabled;
+    }
+}
