@@ -1,5 +1,5 @@
 /*
- * Copyright © 2016 Canonical Ltd.
+ * Copyright © 2016-2020 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3 as
@@ -17,6 +17,7 @@
  */
 
 #include "miral/window_manager_tools.h"
+#include "miral/zone.h"
 #include "window_manager_tools_implementation.h"
 
 miral::WindowManagerTools::WindowManagerTools(WindowManagerToolsImplementation* tools) :
@@ -50,9 +51,6 @@ auto miral::WindowManagerTools::info_for(Window const& window) const -> WindowIn
 void miral::WindowManagerTools::ask_client_to_close(Window const& window)
 { tools->ask_client_to_close(window); }
 
-void miral::WindowManagerTools::force_close(Window const& window)
-{ tools->force_close(window); }
-
 auto miral::WindowManagerTools::active_window() const -> Window
 { return tools->active_window(); }
 
@@ -83,6 +81,9 @@ auto miral::WindowManagerTools::window_at(mir::geometry::Point cursor) const ->
 auto miral::WindowManagerTools::active_output() -> mir::geometry::Rectangle const
 { return tools->active_output(); }
 
+auto miral::WindowManagerTools::active_application_zone() const -> Zone
+{ return tools->active_application_zone(); }
+
 void miral::WindowManagerTools::raise_tree(Window const& root)
 { tools->raise_tree(root); }
 
