@@ -1,5 +1,5 @@
 /*
- * Copyright © 2016-2019 Canonical Ltd.
+ * Copyright © 2016-2020 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3 as
@@ -37,6 +37,7 @@ struct WindowInfo;
 struct ApplicationInfo;
 class WindowSpecification;
 class Workspace;
+class Zone;
 
 // The interface through which the policy instructs the controller.
 class WindowManagerToolsImplementation
@@ -56,7 +57,6 @@ public:
     virtual auto info_for(Window const& window) const -> WindowInfo& = 0;
 
     virtual void ask_client_to_close(Window const& window) = 0;
-    virtual void force_close(Window const& window) = 0;
     virtual auto active_window() const -> Window = 0;
     virtual auto select_active_window(Window const& hint) -> Window = 0;
     virtual void drag_active_window(mir::geometry::Displacement movement) = 0;
@@ -67,6 +67,7 @@ public:
     virtual void focus_prev_within_application() = 0;
     virtual auto window_at(mir::geometry::Point cursor) const -> Window = 0;
     virtual auto active_output() -> mir::geometry::Rectangle const = 0;
+    virtual auto active_application_zone() -> Zone = 0;
     virtual void raise_tree(Window const& root) = 0;
     virtual void start_drag_and_drop(WindowInfo& window_info, std::vector<uint8_t> const& handle) = 0;
     virtual void end_drag_and_drop() = 0;
