@@ -24,7 +24,6 @@
 #include "mir/geometry/dimensions.h"
 #include "mir/geometry/size.h"
 #include "mir_toolkit/common.h"
-#include "mir/renderer/gl/texture_target.h"
 #include "mir_toolkit/mir_native_buffer.h"
 #include "mir/renderer/sw/pixel_source.h"
 #include "mir/graphics/texture.h"
@@ -79,7 +78,7 @@ private:
 
 class MemoryBackedShmBuffer :
     public ShmBuffer,
-    public renderer::software::PixelSource
+    public renderer::software::RWMappableBuffer
 {
 public:
     MemoryBackedShmBuffer(
@@ -87,15 +86,22 @@ public:
         MirPixelFormat const& pixel_format,
         std::shared_ptr<EGLContextExecutor> egl_delegate);
 
-    void write(unsigned char const* data, size_t size) override;
-    void read(std::function<void(unsigned char const*)> const& do_with_pixels) override;
-    geometry::Stride stride() const override;
+    auto map_writeable() -> std::unique_ptr<renderer::software::Mapping<unsigned char>> override;
+    auto map_readable() -> std::unique_ptr<renderer::software::Mapping<unsigned char const>> override;
+
+    auto map_rw() -> std::unique_ptr<renderer::software::Mapping<unsigned char>> override;
 
     void bind() override;
 
     MemoryBackedShmBuffer(MemoryBackedShmBuffer const&) = delete;
     MemoryBackedShmBuffer& operator=(MemoryBackedShmBuffer const&) = delete;
 private:
+    template<typename T>
+    class Mapping;
+
+    template<typename T>
+    friend class Mapping;
+
     geometry::Stride const stride_;
     std::unique_ptr<unsigned char[]> const pixels;
     std::mutex uploaded_mutex;
