@@ -27,9 +27,7 @@
 #include <cstring>
 #include <drm.h>
 #include <sys/ioctl.h>
-#include <vector>
 #include <boost/throw_exception.hpp>
-#include <unordered_map>
 #include <tuple>
 #include <sys/mman.h>
 
@@ -166,11 +164,11 @@ mgek::EGLOutput::~EGLOutput()
     {
         restore_saved_crtc();
     }
-    catch(std::exception const& e)
+    catch(std::exception const&)
     {
         log(logging::Severity::error,
             MIR_LOG_COMPONENT_FALLBACK,
-            std::make_exception_ptr(e),
+            std::current_exception(),
             "Failed to restore saved crtc");
     }
 }
