@@ -26,11 +26,7 @@
 #include "mir/graphics/egl_error.h"
 
 #include <boost/throw_exception.hpp>
-#include <boost/exception/info.hpp>
 #include <boost/exception/errinfo_file_name.hpp>
-#include <xf86drm.h>
-#include <fcntl.h>
-#include <sys/stat.h>
 #include <sys/sysmacros.h>
 #include <one_shot_device_observer.h>
 
@@ -100,41 +96,23 @@ mir::UniqueModulePtr<mg::Display> mge::DisplayPlatform::create_display(
     return retval;
 }
 
-mir::UniqueModulePtr<mg::GraphicBufferAllocator> mge::RenderingPlatform::create_buffer_allocator(
-    mg::Display const& output)
-{
-    return mir::make_module_ptr<mge::BufferAllocator>(output);
-}
-
 namespace
 {
 const auto mir_xwayland_option = "MIR_XWAYLAND_OPTION";
 }
 
-mge::Platform::Platform(
-    std::shared_ptr<RenderingPlatform> const& rendering,
-    std::shared_ptr<DisplayPlatform> const& display) :
-    rendering(rendering),
-    display(display)
+mge::RenderingPlatform::RenderingPlatform()
 {
     setenv(mir_xwayland_option, "-eglstream", 1);
 }
 
-mir::graphics::eglstream::Platform::~Platform()
+mge::RenderingPlatform::~RenderingPlatform()
 {
     unsetenv(mir_xwayland_option);
 }
 
-mir::UniqueModulePtr<mg::GraphicBufferAllocator>
-    mge::Platform::create_buffer_allocator(mg::Display const& output)
+mir::UniqueModulePtr<mg::GraphicBufferAllocator> mge::RenderingPlatform::create_buffer_allocator(
+    mg::Display const& output)
 {
-    return rendering->create_buffer_allocator(output);
+    return mir::make_module_ptr<mge::BufferAllocator>(output);
 }
-
-mir::UniqueModulePtr<mg::Display> mge::Platform::create_display(
-    std::shared_ptr<DisplayConfigurationPolicy> const& policy,
-    std::shared_ptr<GLConfig> const& config)
-{
-    return display->create_display(policy, config);
-}
-
