@@ -34,12 +34,10 @@
 #include "mir/graphics/egl_logger.h"
 
 #include <boost/throw_exception.hpp>
-#include <boost/exception/diagnostic_information.hpp>
 #include <xf86drm.h>
 #include <sstream>
 
 #include <fcntl.h>
-#include <sys/stat.h>
 #include <sys/sysmacros.h>
 #include <boost/exception/errinfo_file_name.hpp>
 #include <xf86drmMode.h>
@@ -88,25 +86,21 @@ mir::UniqueModulePtr<mg::DisplayPlatform> create_display_platform(
     std::shared_ptr<mo::Option> const& options,
     std::shared_ptr<mir::EmergencyCleanupRegistry> const&,
     std::shared_ptr<mir::ConsoleServices> const& console,
-    std::shared_ptr<mg::DisplayReport> const& display_report,
-    std::shared_ptr<mir::logging::Logger> const& logger)
+    std::shared_ptr<mg::DisplayReport> const& display_report)
 {
     mir::assert_entry_point_signature<mg::CreateDisplayPlatform>(&create_display_platform);
 
     if (options->is_set(mo::debug_opt))
     {
-        mg::initialise_egl_logger(logger);
+        mg::initialise_egl_logger();
     }
 
-    return mir::make_module_ptr<mge::Platform>(
-        std::make_shared<mge::RenderingPlatform>(),
-        std::make_shared<mge::DisplayPlatform>(*console, find_device(), display_report));
+    return mir::make_module_ptr<mge::DisplayPlatform>(*console, find_device(), display_report);
 }
 
 auto create_rendering_platform(
     mo::Option const&,
-    mir::EmergencyCleanupRegistry&,
-    std::shared_ptr<mir::logging::Logger> const&) -> mir::UniqueModulePtr<mg::RenderingPlatform>
+    mir::EmergencyCleanupRegistry&) -> mir::UniqueModulePtr<mg::RenderingPlatform>
 {
     mir::assert_entry_point_signature<mg::CreateRenderPlatform>(&create_rendering_platform);
 
