@@ -41,6 +41,11 @@ mir::Fd mie::FdStore::take_fd(char const* path)
     }
     catch (std::out_of_range const&)
     {
+        if (removed.first == path)
+        {
+            mir::log_warning("Requested fd for path %s was removed", path);
+            return fds.insert(std::move(removed)).first->second;
+        }
         mir::log_warning("Failed to find requested fd for path %s", path);
     }
     return mir::Fd{};
@@ -62,6 +67,8 @@ void mie::FdStore::remove_fd(int fd)
     }
     else
     {
+        // We keep the last removed element in case libinput asks for it
+        removed = *element;
         fds.erase(element);
     }
 }
