@@ -44,6 +44,13 @@ private:
     FdStore& operator=(FdStore const&) = delete;
 
     std::unordered_map<std::string, mir::Fd> fds;
+
+    // LibInputPtr calls remove_fd() for touchpads on suspend but
+    // continues to use take_fd() to access the fd after resume!
+    // As a workaround, we remember the last removed fd and reinstate
+    // it if asked for.
+    //                  https://github.com/MirServer/mir/issues/1612
+    std::pair<std::string, mir::Fd> removed;
 };
 
 }
