@@ -270,26 +270,64 @@ mir::EventUPtr mie::LibInputDevice::convert_axis_event(libinput_event_pointer* p
     auto const relative_x_value = 0.0f;
     auto const relative_y_value = 0.0f;
 
-    // TODO: Add descrete scroll to pointer events and source it from libinput_event_pointer_get_axis_value_discrete()
-    // if libinput_event_pointer_get_axis_source(pointer) == LIBINPUT_POINTER_AXIS_SOURCE_WHEEL
-
     auto hscroll_value = 0.0f;
     auto vscroll_value = 0.0f;
+    auto hscroll_stop = false;
+    auto vscroll_stop = false;
     if (libinput_event_pointer_has_axis(pointer, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL))
     {
         hscroll_value = horizontal_scroll_scale *
                         libinput_event_pointer_get_axis_value(pointer, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL);
+        hscroll_stop = hscroll_value == 0;
     }
 
     if (libinput_event_pointer_has_axis(pointer, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL))
     {
         vscroll_value = vertical_scroll_scale *
                         libinput_event_pointer_get_axis_value(pointer, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL);
+        vscroll_stop = vscroll_value == 0;
     }
 
     report->received_event_from_kernel(time.count(), EV_REL, 0, 0);
-    return builder->pointer_event(time, action, button_state, hscroll_value, vscroll_value, relative_x_value,
-                                  relative_y_value);
+
+    auto builder_pointer_axis_event = [&, this](MirPointerAxisSource axis_source)
+        {
+            return builder->pointer_axis_with_stop_event(
+                axis_source, time, action, button_state, 0, 0, hscroll_value, vscroll_value,
+                hscroll_stop, vscroll_stop, relative_x_value, relative_y_value);
+        };
+
+    switch (libinput_event_pointer_get_axis_source(pointer))
+    {
+    case LIBINPUT_POINTER_AXIS_SOURCE_WHEEL:
+    {
+        auto const hscroll_discrete =
+            libinput_event_pointer_has_axis(pointer, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL) ?
+            libinput_event_pointer_get_axis_value_discrete(pointer, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL) :
+            0.0;
+        auto const vscroll_discrete =
+            libinput_event_pointer_has_axis(pointer, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL) ?
+            libinput_event_pointer_get_axis_value_discrete(pointer, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL) :
+            0.0;
+
+        return builder->pointer_axis_discrete_scroll_event(
+            mir_pointer_axis_source_wheel, time, action, button_state, hscroll_value, vscroll_value,
+            hscroll_discrete, vscroll_discrete);
+    }
+
+    case LIBINPUT_POINTER_AXIS_SOURCE_FINGER:
+        return builder_pointer_axis_event(mir_pointer_axis_source_finger);
+
+    case LIBINPUT_POINTER_AXIS_SOURCE_CONTINUOUS:
+        return builder_pointer_axis_event(mir_pointer_axis_source_continuous);
+
+    case LIBINPUT_POINTER_AXIS_SOURCE_WHEEL_TILT:
+        return builder_pointer_axis_event(mir_pointer_axis_source_wheel_tilt);
+
+    default:
+        return builder->pointer_event(time, action, button_state, hscroll_value, vscroll_value, relative_x_value,
+                                      relative_y_value);
+    }
 }
 
 mir::EventUPtr mie::LibInputDevice::convert_touch_frame(libinput_event_touch* touch)
