@@ -27,11 +27,9 @@
 #include "mir/dispatch/multiplexing_dispatchable.h"
 #include "mir/dispatch/action_queue.h"
 #include "mir/module_properties.h"
-#include "mir/assert_module_entry_point.h"
 #include "mir/console_services.h"
 
 #include "mir/input/input_device_registry.h"
-#include "mir/input/input_device.h"
 #include "mir/input/input_report.h"
 #include "mir/fd.h"
 #include "mir/raii.h"
@@ -366,10 +364,10 @@ void mie::Platform::start()
                     break;
                 }
             }
-            catch (std::exception const& e)
+            catch (std::exception const&)
             {
                 auto const message = "Failed to handle UDev " + event_type + " event for " + device.syspath();
-                log(logging::Severity::warning, MIR_LOG_COMPONENT, std::make_exception_ptr(e), message);
+                log(logging::Severity::warning, MIR_LOG_COMPONENT, std::current_exception(), message);
             }
         });
 
