@@ -19,11 +19,9 @@
 
 #include "buffer_allocator.h"
 #include "mir/graphics/linux_dmabuf.h"
-#include "buffer_texture_binder.h"
 #include "mir/anonymous_shm_file.h"
 #include "shm_buffer.h"
 #include "display_helpers.h"
-#include "gbm_format_conversions.h"
 #include "egl_context_executor.h"
 #include "mir/graphics/egl_extensions.h"
 #include "mir/graphics/egl_error.h"
@@ -50,6 +48,7 @@
 #include <gbm.h>
 #include <cassert>
 #include <fcntl.h>
+#include <xf86drm.h>
 
 #include <wayland-server.h>
 
@@ -64,144 +63,6 @@ namespace geom = mir::geometry;
 
 namespace
 {
-
-class EGLImageBufferTextureBinder : public mgc::BufferTextureBinder
-{
-public:
-    EGLImageBufferTextureBinder(std::shared_ptr<gbm_bo> const& gbm_bo,
-                                std::shared_ptr<mg::EGLExtensions> const& egl_extensions)
-        : bo{gbm_bo},
-          egl_extensions{egl_extensions},
-          egl_image{EGL_NO_IMAGE_KHR}
-    {
-    }
-
-    ~EGLImageBufferTextureBinder()
-    {
-        if (egl_image != EGL_NO_IMAGE_KHR)
-            egl_extensions->base(egl_display).eglDestroyImageKHR(egl_display, egl_image);
-    }
-
-
-    void gl_bind_to_texture() override
-    {
-        ensure_egl_image();
-
-        egl_extensions->base(egl_display).glEGLImageTargetTexture2DOES(GL_TEXTURE_2D, egl_image);
-    }
-
-protected:
-    virtual void ensure_egl_image() = 0;
-
-    std::shared_ptr<gbm_bo> const bo;
-    std::shared_ptr<mg::EGLExtensions> const egl_extensions;
-    EGLDisplay egl_display;
-    EGLImageKHR egl_image;
-};
-
-class NativePixmapTextureBinder : public EGLImageBufferTextureBinder
-{
-public:
-    NativePixmapTextureBinder(std::shared_ptr<gbm_bo> const& gbm_bo,
-                              std::shared_ptr<mg::EGLExtensions> const& egl_extensions)
-        : EGLImageBufferTextureBinder(gbm_bo, egl_extensions)
-    {
-    }
-
-private:
-    void ensure_egl_image()
-    {
-        if (egl_image == EGL_NO_IMAGE_KHR)
-        {
-            eglBindAPI(EGL_OPENGL_ES_API);
-            egl_display = eglGetCurrentDisplay();
-            gbm_bo* bo_raw{bo.get()};
-
-            const EGLint image_attrs[] =
-            {
-                EGL_IMAGE_PRESERVED_KHR, EGL_TRUE,
-                EGL_NONE
-            };
-
-            egl_image = egl_extensions->base(egl_display).eglCreateImageKHR(
-                egl_display,
-                EGL_NO_CONTEXT,
-                EGL_NATIVE_PIXMAP_KHR,
-                reinterpret_cast<void*>(bo_raw),
-                image_attrs);
-            if (egl_image == EGL_NO_IMAGE_KHR)
-                BOOST_THROW_EXCEPTION(mg::egl_error("Failed to create EGLImage"));
-        }
-    }
-};
-
-class DMABufTextureBinder : public EGLImageBufferTextureBinder
-{
-public:
-    DMABufTextureBinder(std::shared_ptr<gbm_bo> const& gbm_bo,
-                        std::shared_ptr<mg::EGLExtensions> const& egl_extensions)
-        : EGLImageBufferTextureBinder(gbm_bo, egl_extensions)
-    {
-    }
-
-private:
-    void ensure_egl_image()
-    {
-        if (egl_image == EGL_NO_IMAGE_KHR)
-        {
-            eglBindAPI(EGL_OPENGL_ES_API);
-            egl_display = eglGetCurrentDisplay();
-            gbm_bo* bo_raw{bo.get()};
-
-            auto device = gbm_bo_get_device(bo_raw);
-            auto gem_handle = gbm_bo_get_handle(bo_raw).u32;
-            auto drm_fd = gbm_device_get_fd(device);
-            int raw_fd = -1;
-
-            auto ret = drmPrimeHandleToFD(drm_fd, gem_handle, DRM_CLOEXEC, &raw_fd);
-            prime_fd = mir::Fd{raw_fd};
-            if (ret)
-            {
-                std::string const msg("Failed to get PRIME fd from gbm-kms bo");
-                BOOST_THROW_EXCEPTION(
-                    std::system_error(errno, std::system_category(), "Failed to get PRIME fd from gbm-kms bo"));
-            }
-
-            const EGLint image_attrs_X[] =
-            {
-                EGL_IMAGE_PRESERVED_KHR, EGL_TRUE,
-                EGL_WIDTH, static_cast<EGLint>(gbm_bo_get_width(bo_raw)),
-                EGL_HEIGHT, static_cast<EGLint>(gbm_bo_get_height(bo_raw)),
-                EGL_LINUX_DRM_FOURCC_EXT, static_cast<EGLint>(gbm_bo_get_format(bo_raw)),
-                EGL_DMA_BUF_PLANE0_FD_EXT, prime_fd,
-                EGL_DMA_BUF_PLANE0_OFFSET_EXT, 0,
-                EGL_DMA_BUF_PLANE0_PITCH_EXT, static_cast<EGLint>(gbm_bo_get_stride(bo_raw)),
-                EGL_NONE
-            };
-
-            egl_image = egl_extensions->base(egl_display).eglCreateImageKHR(
-                egl_display,
-                EGL_NO_CONTEXT,
-                EGL_LINUX_DMA_BUF_EXT,
-                static_cast<EGLClientBuffer>(nullptr),
-                image_attrs_X);
-            if (egl_image == EGL_NO_IMAGE_KHR)
-                BOOST_THROW_EXCEPTION(mg::egl_error("Failed to create EGLImage"));
-        }
-    }
-
-    mir::Fd prime_fd;
-};
-
-struct GBMBODeleter
-{
-    void operator()(gbm_bo* handle) const
-    {
-        if (handle)
-            gbm_bo_destroy(handle);
-    }
-};
-
 std::unique_ptr<mir::renderer::gl::Context> context_for_output(mg::Display const& output)
 {
     try
@@ -331,10 +192,15 @@ void mgg::BufferAllocator::bind_display(wl_display* display, std::shared_ptr<Exe
                 });
         mir::log_info("Enabled linux-dmabuf import support");
     }
-    catch (std::runtime_error const&)
+    catch (std::runtime_error const& error)
     {
         mir::log_info(
-            "No EGL_EXT_image_dma_buf_import_modifiers support, disabling linux-dmabuf import");
+            "Cannot enable linux-dmabuf import support: %s", error.what());
+        mir::log(
+            mir::logging::Severity::debug,
+            MIR_LOG_COMPONENT,
+            std::current_exception(),
+            "Detailed error: ");
     }
 
     this->wayland_executor = std::move(wayland_executor);
