@@ -19,8 +19,8 @@
 #ifndef MIR_GRAPHICS_GBM_DISPLAY_HELPERS_H_
 #define MIR_GRAPHICS_GBM_DISPLAY_HELPERS_H_
 
-#include "drm_authentication.h"
 #include "mir/udev/wrapper.h"
+#include "mir/fd.h"
 
 #include <cstddef>
 #include <memory>
@@ -49,13 +49,7 @@ typedef std::unique_ptr<gbm_surface,std::function<void(gbm_surface*)>> GBMSurfac
 namespace helpers
 {
 
-enum class DRMNodeToUse
-{
-    render,
-    card
-};
-
-class DRMHelper : public DRMAuthentication
+class DRMHelper
 {
 public:
     ~DRMHelper();
@@ -71,18 +65,14 @@ public:
     static std::unique_ptr<DRMHelper> open_any_render_node(
         std::shared_ptr<mir::udev::Context> const& udev);
 
-    mir::Fd authenticated_fd();
-    void auth_magic(drm_magic_t magic);
-
     void drop_master() const;
     void set_master() const;
 
     mir::Fd fd;
 private:
-    DRMNodeToUse node_to_use;
     std::unique_ptr<Device> const device_handle;
 
-    explicit DRMHelper(mir::Fd&& fd, std::unique_ptr<mir::Device> device, DRMNodeToUse node_to_use);
+    explicit DRMHelper(mir::Fd&& fd, std::unique_ptr<mir::Device> device);
 };
 
 class GBMHelper
@@ -94,7 +84,7 @@ public:
     GBMHelper(const GBMHelper&) = delete;
     GBMHelper& operator=(const GBMHelper&) = delete;
 
-    GBMSurfaceUPtr create_scanout_surface(uint32_t width, uint32_t height, bool sharable) const;
+    GBMSurfaceUPtr create_scanout_surface(uint32_t width, uint32_t height, uint32_t gbm_format, bool sharable) const;
 
     gbm_device* const device;
 };
