@@ -32,7 +32,6 @@
 #include "mir/libname.h"
 #include "mir/console_services.h"
 #include "one_shot_device_observer.h"
-#include "mir/raii.h"
 #include "mir/graphics/egl_error.h"
 #include "mir/graphics/gl_config.h"
 #include "mir/graphics/egl_logger.h"
@@ -41,7 +40,7 @@
 #include <GLES2/gl2.h>
 #include "egl_helper.h"
 #include <fcntl.h>
-#include <sys/ioctl.h>
+#include <xf86drm.h>
 
 namespace mg = mir::graphics;
 namespace mgg = mg::gbm;
@@ -59,15 +58,14 @@ mir::UniqueModulePtr<mg::DisplayPlatform> create_display_platform(
     std::shared_ptr<mo::Option> const& options,
     std::shared_ptr<mir::EmergencyCleanupRegistry> const& emergency_cleanup_registry,
     std::shared_ptr<mir::ConsoleServices> const& console,
-    std::shared_ptr<mg::DisplayReport> const& report,
-    std::shared_ptr<mir::logging::Logger> const& logger)
+    std::shared_ptr<mg::DisplayReport> const& report)
 {
     mir::assert_entry_point_signature<mg::CreateDisplayPlatform>(&create_display_platform);
     // ensure gbm-kms finds the gbm-kms mir-platform symbols
 
     if (options->is_set(mir::options::debug_opt))
     {
-        mg::initialise_egl_logger(logger);
+        mg::initialise_egl_logger();
     }
 
     auto bypass_option = mgg::BypassOption::allowed;
@@ -82,8 +80,7 @@ mir::UniqueModulePtr<mg::DisplayPlatform> create_display_platform(
 
 auto create_rendering_platform(
     mo::Option const&,
-    mir::EmergencyCleanupRegistry&,
-    std::shared_ptr<mir::logging::Logger> const&) -> mir::UniqueModulePtr<mg::RenderingPlatform>
+    mir::EmergencyCleanupRegistry&) -> mir::UniqueModulePtr<mg::RenderingPlatform>
 {
     mir::assert_entry_point_signature<mg::CreateRenderPlatform>(&create_rendering_platform);
 
@@ -319,7 +316,9 @@ mg::PlatformPriority probe_rendering_platform(
     }
 
     // Check for suitability
-    auto maximum_suitability = mg::PlatformPriority::unsupported;
+    // The implementation claims to support the GBM EGL platform, so it *should*
+    // be at least minimally functional…
+    auto maximum_suitability = mg::PlatformPriority::supported;
     for (auto& device : drm_devices)
     {
         if (quirks.should_skip(device))
@@ -368,7 +367,6 @@ mg::PlatformPriority probe_rendering_platform(
                     strlen("llvmpipe")) == 0)
                 {
                     mir::log_info("Detected software renderer: %s", renderer_string);
-                    maximum_suitability = mg::PlatformPriority::supported;
                 }
                 else
                 {
