@@ -24,6 +24,7 @@
 
 #include <wayland-client.h>
 
+#include <functional>
 #include <mutex>
 
 namespace mir
@@ -36,14 +37,12 @@ namespace wayland
 class Cursor : public graphics::Cursor
 {
 public:
-    Cursor(wl_display* display, wl_compositor* compositor, wl_shm* shm);
+    Cursor(wl_compositor* compositor, wl_shm* shm, std::function<void()> flush_wl);
 
     ~Cursor();
 
     void show(graphics::CursorImage const& image) override;
 
-    void show() override;
-
     void hide() override;
 
     void move_to(geometry::Point position) override;
@@ -52,9 +51,8 @@ public:
     void leave(wl_pointer* pointer);
 
 private:
-    wl_display* const display;
     wl_shm* const shm;
-
+    std::function<void()> const flush_wl;
     wl_surface* surface;
 
     std::mutex mutable mutex;
