@@ -36,8 +36,8 @@ namespace wayland
 class KeyboardInput
 {
 public:
-    virtual void key_press(std::chrono::nanoseconds event_time, xkb_keysym_t key_sym, int32_t key_code) = 0;
-    virtual void key_release(std::chrono::nanoseconds event_time, xkb_keysym_t key_sym, int32_t key_code) = 0;
+    virtual void key_press(std::chrono::nanoseconds event_time, xkb_keysym_t keysym, int32_t scan_code) = 0;
+    virtual void key_release(std::chrono::nanoseconds event_time, xkb_keysym_t keysym, int32_t scan_code) = 0;
 
     KeyboardInput() = default;
     virtual ~KeyboardInput() = default;
@@ -63,6 +63,12 @@ public:
         geometry::PointF const& pos,
         geometry::DisplacementF const& scroll) = 0;
 
+    virtual void pointer_axis_motion(
+        MirPointerAxisSource pointer_axis_source,
+        std::chrono::nanoseconds event_time,
+        geometry::PointF const& pos,
+        geometry::DisplacementF const& scroll) = 0;
+
     PointerInput() = default;
     virtual ~PointerInput() = default;
     PointerInput(PointerInput const&) = delete;
