@@ -274,12 +274,17 @@ mgw::DisplayClient::Output::~Output()
         eglDestroyContext(owner->egldisplay, eglctx);
 }
 
+
+// If building against newer Wayland protocol definitions we may miss trailing fields
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
 wl_output_listener const mgw::DisplayClient::Output::output_listener = {
     &geometry,
     &mode,
     &done,
     &scale,
 };
+#pragma GCC diagnostic pop
 
 void mgw::DisplayClient::Output::done(void* data, struct wl_output* /*wl_output*/)
 {
@@ -388,7 +393,7 @@ void mgw::DisplayClient::Output::swap_buffers()
         void wait_for_done()
         {
             std::unique_lock<decltype(mutex)> lock{mutex};
-            cv.wait(lock, [this]{ return posted; });
+            cv.wait_for(lock, std::chrono::milliseconds{100}, [this]{ return posted; });
         }
 
         std::mutex mutex;
@@ -419,6 +424,11 @@ mgw::DisplayClient::DisplayClient(
     keyboard_context_{xkb_context_new(XKB_CONTEXT_NO_FLAGS)},
     registry{nullptr, [](auto){}}
 {
+    if (!keyboard_context_)
+    {
+        fatal_error("Failed to create XKB context");
+    }
+
     registry = {wl_display_get_registry(display), &wl_registry_destroy};
 
     static wl_registry_listener const registry_listener = {
