@@ -133,7 +133,7 @@ bool miw::GenericInputDevice::started() const
 
 void  miw::GenericInputDevice::enqueue(std::function<EventUPtr(EventBuilder* builder)> const& event)
 {
-    action_queue->enqueue([=]
+    action_queue->enqueue([=, this]
           {
               std::lock_guard<decltype(mutex)> lock{mutex};
               if (started())
@@ -146,14 +146,14 @@ miw::KeyboardInputDevice::KeyboardInputDevice(std::shared_ptr<dispatch::ActionQu
 {
 }
 
-void miw::KeyboardInputDevice::key_press(std::chrono::nanoseconds event_time, xkb_keysym_t key_sym, int32_t key_code)
+void miw::KeyboardInputDevice::key_press(std::chrono::nanoseconds event_time, xkb_keysym_t keysym, int32_t scan_code)
 {
-    enqueue([=](EventBuilder* b) { return b->key_event(event_time, mir_keyboard_action_down, key_sym, key_code); });
+    enqueue([=](EventBuilder* b) { return b->key_event(event_time, mir_keyboard_action_down, keysym, scan_code); });
 }
 
-void miw::KeyboardInputDevice::key_release(std::chrono::nanoseconds event_time, xkb_keysym_t key_sym, int32_t key_code)
+void miw::KeyboardInputDevice::key_release(std::chrono::nanoseconds event_time, xkb_keysym_t keysym, int32_t scan_code)
 {
-    enqueue([=](EventBuilder* b) { return b->key_event(event_time, mir_keyboard_action_up, key_sym, key_code); });
+    enqueue([=](EventBuilder* b) { return b->key_event(event_time, mir_keyboard_action_up, keysym, scan_code); });
 }
 
 miw::PointerInputDevice::PointerInputDevice(std::shared_ptr<dispatch::ActionQueue> const& action_queue) :
@@ -167,7 +167,7 @@ void miw::PointerInputDevice::pointer_press(
     geom::PointF const& pos,
     geom::DisplacementF const& scroll)
 {
-    enqueue([=](EventBuilder* b)
+    enqueue([=, this](EventBuilder* b)
     {
         button_state |= to_pointer_button(button, mir_pointer_handedness_right);
 
@@ -193,7 +193,7 @@ void miw::PointerInputDevice::pointer_release(
     geom::PointF const& pos,
     geom::DisplacementF const& scroll)
 {
-    enqueue([=](EventBuilder* b)
+    enqueue([=, this](EventBuilder* b)
     {
         button_state &= ~to_pointer_button(button, mir_pointer_handedness_right);
 
@@ -218,7 +218,7 @@ void miw::PointerInputDevice::pointer_motion(
     geom::PointF const& pos,
     geom::DisplacementF const& scroll)
 {
-    enqueue([=](EventBuilder* b)
+    enqueue([=, this](EventBuilder* b)
     {
         auto const movement = pos - cached_pos;
         cached_pos = pos;
@@ -236,6 +236,31 @@ void miw::PointerInputDevice::pointer_motion(
     });
 }
 
+void miw::PointerInputDevice::pointer_axis_motion(
+    MirPointerAxisSource pointer_axis_source,
+    std::chrono::nanoseconds event_time,
+    mir::geometry::PointF const& pos,
+    mir::geometry::DisplacementF const& scroll)
+{
+    enqueue([=, this](EventBuilder* b)
+    {
+        auto const movement = pos - cached_pos;
+        cached_pos = pos;
+        return b->pointer_axis_event(
+            pointer_axis_source,
+            event_time,
+            mir_pointer_action_motion,
+            button_state,
+            cached_pos.x.as_value(),
+            cached_pos.y.as_value(),
+            scroll.dx.as_value(),
+            scroll.dy.as_value(),
+            movement.dx.as_value(),
+            movement.dy.as_value()
+        );
+    });
+}
+
 miw::TouchInputDevice::TouchInputDevice(std::shared_ptr<dispatch::ActionQueue> const& action_queue) :
     GenericInputDevice{InputDeviceInfo{"touch-device", "touch-dev-1", DeviceCapability::touchscreen}, action_queue}
 {
