@@ -86,8 +86,8 @@ public:
     explicit KeyboardInputDevice(std::shared_ptr<dispatch::ActionQueue> const& action_queue);
 
 private:
-    void key_press(std::chrono::nanoseconds event_time, xkb_keysym_t key_sym, int32_t key_code) override;
-    void key_release(std::chrono::nanoseconds event_time, xkb_keysym_t key_sym, int32_t key_code) override;
+    void key_press(std::chrono::nanoseconds event_time, xkb_keysym_t keysym, int32_t scan_code) override;
+    void key_release(std::chrono::nanoseconds event_time, xkb_keysym_t keysym, int32_t scan_code) override;
 };
 
 class PointerInputDevice : public GenericInputDevice, public PointerInput
@@ -113,6 +113,11 @@ private:
         std::chrono::nanoseconds event_time,
         geometry::PointF const& pos,
         geometry::DisplacementF const& scroll) override;
+
+public:
+    void pointer_axis_motion(
+        MirPointerAxisSource pointer_axis_source, std::chrono::nanoseconds event_time, geometry::PointF const& pos,
+        geometry::DisplacementF const& scroll) override;
 };
 
 class TouchInputDevice : public GenericInputDevice, public TouchInput
