@@ -22,7 +22,6 @@
 #include "mir/graphics/graphic_buffer_allocator.h"
 #include "mir/graphics/display.h"
 #include "mir/fd.h"
-#include "mir/renderer/gl/egl_platform.h"
 
 #include "displayclient.h"
 
@@ -37,25 +36,27 @@ namespace graphics
 {
 namespace wayland
 {
-class Platform : public graphics::Platform,
-                 public mir::renderer::gl::EGLPlatform
+class Platform : public graphics::DisplayPlatform
 {
 public:
     Platform(struct wl_display* const wl_display, std::shared_ptr<DisplayReport> const& report);
     ~Platform() = default;
 
-    UniqueModulePtr<GraphicBufferAllocator> create_buffer_allocator(Display const& output) override;
 
     UniqueModulePtr<Display> create_display(
         std::shared_ptr<DisplayConfigurationPolicy> const& initial_conf_policy,
         std::shared_ptr<GLConfig> const& gl_config) override;
 
-    EGLNativeDisplayType egl_native_display() const override;
-
 private:
     struct wl_display* const wl_display;
     std::shared_ptr<DisplayReport> const report;
 };
+
+class RenderingPlatform : public graphics::RenderingPlatform
+{
+public:
+    auto create_buffer_allocator(Display const& output) -> UniqueModulePtr<GraphicBufferAllocator> override;
+};
 }
 }
 }
