@@ -17,7 +17,6 @@
  */
 
 #include "mir/c_memory.h"
-#include "mir/graphics/platform.h"
 #include "mir/graphics/display_report.h"
 #include "mir/graphics/display_configuration.h"
 #include <mir/graphics/display_configuration_policy.h>
@@ -26,12 +25,10 @@
 #include "mir/renderer/gl/context.h"
 #include "mir/graphics/gl_config.h"
 #include "mir/graphics/atomic_frame.h"
-#include "mir/graphics/transformation.h"
 #include "display_configuration.h"
 #include "display.h"
 #include "platform.h"
 #include "display_buffer.h"
-#include "../x11_resources.h"
 
 #include <boost/throw_exception.hpp>
 #include <algorithm>
@@ -249,7 +246,19 @@ void mgx::Display::configure(mg::DisplayConfiguration const& new_configuration)
             {
                 *output->config = conf_output;
                 output->display_buffer->set_view_area(output->config->extents());
-                output->display_buffer->set_transformation(output->config->transformation());
+                switch (output->config->power_mode)
+                {
+                case mir_power_mode_on:
+                    output->display_buffer->set_transformation(output->config->transformation());
+                    break;
+
+                case mir_power_mode_standby:
+                case mir_power_mode_suspend:
+                case mir_power_mode_off:
+                    // Simulate an off display by setting a zeroed-out transform
+                    output->display_buffer->set_transformation(glm::mat2{0});
+                    break;
+                }
                 found_info = true;
                 break;
             }
