@@ -22,13 +22,14 @@
 #include "mir/graphics/display_report.h"
 #include "mir/graphics/platform.h"
 #include "mir/geometry/size.h"
-#include "mir/renderer/gl/egl_platform.h"
-
-#include <X11/Xlib.h>
-#include <X11/Xutil.h>
 
 namespace mir
 {
+namespace X
+{
+class X11Resources;
+}
+
 namespace graphics
 {
 namespace X
@@ -53,33 +54,31 @@ struct X11OutputConfig
     float scale;
 };
 
-class Platform : public graphics::Platform,
-                 public mir::renderer::gl::EGLPlatform
+class Platform : public graphics::DisplayPlatform
 {
 public:
     // Parses colon separated list of sizes in the form WIDTHxHEIGHT^SCALE (^SCALE is optional)
     static auto parse_output_sizes(std::string output_sizes) -> std::vector<X11OutputConfig>;
 
-    explicit Platform(std::shared_ptr<::Display> const& conn,
+    explicit Platform(std::shared_ptr<mir::X::X11Resources> const& x11_resources,
                       std::vector<X11OutputConfig> output_sizes,
                       std::shared_ptr<DisplayReport> const& report);
     ~Platform() = default;
 
     /* From Platform */
-    UniqueModulePtr<GraphicBufferAllocator>
-        create_buffer_allocator(graphics::Display const& output) override;
-
     UniqueModulePtr<graphics::Display> create_display(
         std::shared_ptr<DisplayConfigurationPolicy> const& initial_conf_policy,
         std::shared_ptr<GLConfig> const& gl_config) override;
-
-    EGLNativeDisplayType egl_native_display() const override;
 private:
-    std::shared_ptr<::Display> const x11_connection;
+    std::shared_ptr<mir::X::X11Resources> const x11_resources;
     std::shared_ptr<DisplayReport> const report;
     std::vector<X11OutputConfig> const output_sizes;
 };
 
+class RenderingPlatform : public graphics::RenderingPlatform
+{
+    auto create_buffer_allocator(graphics::Display const& output) -> UniqueModulePtr<graphics::GraphicBufferAllocator> override;
+};
 }
 }
 }
