@@ -29,10 +29,8 @@
 #define MIR_LOG_COMPONENT "x11-input"
 #include "mir/log.h"
 
-#include <linux/input.h>
 #include <inttypes.h>
 #include <signal.h>
-#include <stdio.h>
 #include <chrono>
 
 #include <xcb/xfixes.h>
@@ -152,6 +150,11 @@ void window_resized(mir::X::X11Resources* x11_resources, xcb_window_t x11_window
             }
         });
 }
+
+auto xcb_keycode_get_scan_code(xcb_keycode_t xcb_keycode) -> int
+{
+    return xcb_keycode - 8;
+}
 }
 
 mix::XInputPlatform::XInputPlatform(std::shared_ptr<mi::InputDeviceRegistry> const& input_device_registry,
@@ -235,7 +238,7 @@ void mix::XInputPlatform::process_input_events()
             bool consumed = false;
             if (next_pending_event_callback)
             {
-                (*next_pending_event_callback)(event.get());
+                consumed = (*next_pending_event_callback)(event.get());
                 next_pending_event_callback = {};
             }
             if (!consumed)
@@ -313,7 +316,8 @@ void mix::XInputPlatform::process_input_event(xcb_generic_event_t* event)
             // Only release keys that aren't modifiers
             if (modifiers.find(key) == modifiers.end())
             {
-                key_released(key, last_timestamp);
+                // FOCUS_OUT doesn't have a timestamp
+                key_released(std::nullopt, key);
             }
         }
 
@@ -331,7 +335,6 @@ void mix::XInputPlatform::process_input_event(xcb_generic_event_t* event)
     case XCB_ENTER_NOTIFY:
     {
         auto const enter_ev = reinterpret_cast<xcb_enter_notify_event_t*>(event);
-        last_timestamp = enter_ev->time;
 
         if (!ptr_grabbed && kbd_grabbed)
         {
@@ -364,7 +367,6 @@ void mix::XInputPlatform::process_input_event(xcb_generic_event_t* event)
     case XCB_LEAVE_NOTIFY:
     {
         auto const leave_ev = reinterpret_cast<xcb_leave_notify_event_t*>(event);
-        last_timestamp = leave_ev->time;
 
         if (ptr_grabbed)
         {
@@ -377,31 +379,29 @@ void mix::XInputPlatform::process_input_event(xcb_generic_event_t* event)
     case XCB_KEY_PRESS:
     {
         auto const press_ev = reinterpret_cast<xcb_key_press_event_t*>(event);
-        last_timestamp = press_ev->time;
-        key_pressed(press_ev->detail, press_ev->time);
+        key_pressed(std::chrono::milliseconds{press_ev->time}, press_ev->detail);
     }   break;
 
     case XCB_KEY_RELEASE:
     {
         auto const release_ev = reinterpret_cast<xcb_key_release_event_t*>(event);
-        last_timestamp = release_ev->time;
 
         // Key repeats look like a release and an immediate press with the same timestamp. The only way to detect and
         // discard them is by peaking at the next event.
 
-        next_pending_event_callback = [this, keycode = release_ev->detail, time = release_ev->time](auto next_event)
+        next_pending_event_callback = [this, xcb_keycode = release_ev->detail, time = release_ev->time](auto next_event)
             {
                 if (next_event && (next_event.value()->response_type & ~0x80) == XCB_KEY_PRESS)
                 {
                     auto const press_ev = reinterpret_cast<xcb_key_press_event_t*>(next_event.value());
-                    if (press_ev->detail == keycode && press_ev->time == time)
+                    if (press_ev->detail == xcb_keycode && press_ev->time == time)
                     {
                         // This event is a key repeat, so ignore it. Also consume the next event by returning true.
                         return true;
                     }
                 }
 
-                key_released(keycode, time);
+                key_released(std::chrono::milliseconds{time}, xcb_keycode);
                 return false; // do not consume next event, process it normally
             };
     }   break;
@@ -409,40 +409,36 @@ void mix::XInputPlatform::process_input_event(xcb_generic_event_t* event)
     case XCB_BUTTON_PRESS:
     {
         auto const press_ev = reinterpret_cast<xcb_button_press_event_t*>(event);
-        last_timestamp = press_ev->time;
 
-        auto const event_time = std::chrono::duration_cast<std::chrono::nanoseconds>(
-            std::chrono::milliseconds{press_ev->time});
+        auto const event_time = std::chrono::milliseconds{press_ev->time};
         auto const pos = get_pos_on_output(x11_resources.get(), press_ev->event, press_ev->event_x, press_ev->event_y);
         core_pointer->update_button_state(press_ev->state);
 
         switch (press_ev->detail)
         {
         case button_scroll_up:
-            core_pointer->pointer_motion(event_time, pos, {0, -scroll_factor});
+            core_pointer->pointer_axis_motion(mir_pointer_axis_source_wheel, event_time, pos, {0, -scroll_factor});
             break;
 
         case button_scroll_down:
-            core_pointer->pointer_motion(event_time, pos, {0, scroll_factor});
+            core_pointer->pointer_axis_motion(mir_pointer_axis_source_wheel, event_time, pos, {0, scroll_factor});
             break;
 
         case button_scroll_left:
-            core_pointer->pointer_motion(event_time, pos, {-scroll_factor, 0});
+            core_pointer->pointer_axis_motion(mir_pointer_axis_source_wheel, event_time, pos, {-scroll_factor, 0});
             break;
 
         case button_scroll_right:
-            core_pointer->pointer_motion(event_time, pos, {scroll_factor, 0});
+            core_pointer->pointer_axis_motion(mir_pointer_axis_source_wheel, event_time, pos, {scroll_factor, 0});
             break;
 
-        default:
-            core_pointer->pointer_press(event_time, press_ev->detail, pos, {});
+        default:core_pointer->pointer_press(event_time, press_ev->detail, pos);
         }
     }   break;
 
     case XCB_BUTTON_RELEASE:
     {
         auto const release_ev = reinterpret_cast<xcb_button_release_event_t*>(event);
-        last_timestamp = release_ev->time;
 
         core_pointer->update_button_state(release_ev->state);
 
@@ -455,26 +451,23 @@ void mix::XInputPlatform::process_input_event(xcb_generic_event_t* event)
             break;
 
         default:
-            auto const event_time = std::chrono::duration_cast<std::chrono::nanoseconds>(
-                std::chrono::milliseconds{release_ev->time});
+            auto const event_time = std::chrono::milliseconds{release_ev->time};
             auto const pos = get_pos_on_output(
                 x11_resources.get(),
                 release_ev->event,
                 release_ev->event_x,
                 release_ev->event_y);
-            core_pointer->pointer_release(event_time, release_ev->detail, pos, {});
+            core_pointer->pointer_release(event_time, release_ev->detail, pos);
         }
     }   break;
 
     case XCB_MOTION_NOTIFY:
     {
         auto const motion_ev = reinterpret_cast<xcb_motion_notify_event_t*>(event);
-        last_timestamp = motion_ev->time;
         core_pointer->update_button_state(motion_ev->state);
-        auto const event_time = std::chrono::duration_cast<std::chrono::nanoseconds>(
-                std::chrono::milliseconds{motion_ev->time});
+        auto const event_time = std::chrono::milliseconds{motion_ev->time};
         auto pos = get_pos_on_output(x11_resources.get(), motion_ev->event, motion_ev->event_x, motion_ev->event_y);
-        core_pointer->pointer_motion(event_time, pos, {});
+        core_pointer->pointer_motion(event_time, pos);
     }   break;
 
     case XCB_CONFIGURE_NOTIFY:
@@ -546,14 +539,15 @@ void mix::XInputPlatform::process_xkb_event(xcb_generic_event_t* event)
         {
             modifiers.insert(state_ev->keycode);
         }
+        auto const event_time = std::chrono::milliseconds{state_ev->time};
         switch (state_ev->eventType)
         {
         case XCB_KEY_PRESS:
-            key_pressed(state_ev->keycode, state_ev->time);
+            key_pressed(event_time, state_ev->keycode);
             break;
 
         case XCB_KEY_RELEASE:
-            key_released(state_ev->keycode, state_ev->time);
+            key_released(event_time, state_ev->keycode);
             break;
 
         default:;
@@ -564,27 +558,23 @@ void mix::XInputPlatform::process_xkb_event(xcb_generic_event_t* event)
     }
 }
 
-void mix::XInputPlatform::key_pressed(xcb_keycode_t keycode, xcb_timestamp_t timestamp)
+void mix::XInputPlatform::key_pressed(std::optional<std::chrono::nanoseconds> event_time, xcb_keycode_t xcb_keycode)
 {
-    if (pressed_keys.insert(keycode).second)
+    if (pressed_keys.insert(xcb_keycode).second)
     {
-        auto const event_time = std::chrono::duration_cast<std::chrono::nanoseconds>(
-            std::chrono::milliseconds{timestamp});
-        xkb_keysym_t keysym = xkb_state_key_get_one_sym(key_state, keycode);
-        // Why keycode - 8? Unclear.
-        core_keyboard->key_press(event_time, keysym, keycode - 8);
+        xkb_keysym_t const keysym = xkb_state_key_get_one_sym(key_state, xcb_keycode);
+        auto const scan_code = xcb_keycode_get_scan_code(xcb_keycode);
+        core_keyboard->key_press(event_time, keysym, scan_code);
     }
 }
 
-void mix::XInputPlatform::key_released(xcb_keycode_t keycode, xcb_timestamp_t timestamp)
+void mix::XInputPlatform::key_released(std::optional<std::chrono::nanoseconds> event_time, xcb_keycode_t xcb_keycode)
 {
-    if (pressed_keys.erase(keycode))
+    if (pressed_keys.erase(xcb_keycode))
     {
-        auto const event_time = std::chrono::duration_cast<std::chrono::nanoseconds>(
-            std::chrono::milliseconds{timestamp});
-        xkb_keysym_t keysym = xkb_state_key_get_one_sym(key_state, keycode);
-        // Why keycode - 8? Unclear.
-        core_keyboard->key_release(event_time, keysym, keycode - 8);
+        xkb_keysym_t keysym = xkb_state_key_get_one_sym(key_state, xcb_keycode);
+        auto const scan_code = xcb_keycode_get_scan_code(xcb_keycode);
+        core_keyboard->key_release(event_time, keysym, scan_code);
     }
 }
 
