@@ -31,6 +31,7 @@
 #include "mir/raii.h"
 #include "mir/unwind_helpers.h"
 #include "mir/thread_name.h"
+#include "mir/system_executor.h"
 
 #include <thread>
 #include <chrono>
@@ -66,7 +67,8 @@ public:
         force_sleep{fixed_composite_delay},
         display_listener{display_listener},
         report{report},
-        started_future{started.get_future()}
+        started_future{started.get_future()},
+        stopped_future{stopped.get_future()}
     {
     }
 
@@ -74,6 +76,12 @@ public:
     try
     {
         mir::set_thread_name("Mir/Comp");
+        auto const signal_when_stopped = mir::raii::paired_calls(
+            [](){},
+            [this]()
+            {
+                stopped.set_value();
+            });
 
         std::vector<std::tuple<mg::DisplayBuffer*, std::unique_ptr<mc::DisplayBufferCompositor>>> compositors;
         group.for_each_display_buffer(
@@ -230,6 +238,15 @@ public:
         started_future.get();
     }
 
+    void wait_until_stopped()
+    {
+        stop();
+        if (stopped_future.wait_for(10s) != std::future_status::ready)
+            BOOST_THROW_EXCEPTION(std::runtime_error("Compositor thread failed to stop"));
+
+        stopped_future.get();
+    }
+
 private:
     std::shared_ptr<mc::DisplayBufferCompositorFactory> const compositor_factory;
     mg::DisplaySyncGroup& group;
@@ -243,6 +260,8 @@ private:
     std::shared_ptr<CompositorReport> const report;
     std::promise<void> started;
     std::future<void> started_future;
+    std::promise<void> stopped;
+    std::future<void> stopped_future;
     bool not_posted_yet = true;
 };
 
@@ -264,8 +283,7 @@ mc::MultiThreadedCompositor::MultiThreadedCompositor(
       report{compositor_report},
       state{CompositorState::stopped},
       fixed_composite_delay{fixed_composite_delay},
-      compose_on_start{compose_on_start},
-      thread_pool{1}
+      compose_on_start{compose_on_start}
 {
     observer = std::make_shared<ms::LegacySceneChangeNotification>(
     [this]()
@@ -361,12 +379,10 @@ void mc::MultiThreadedCompositor::create_compositing_threads()
             display_buffer_compositor_factory, group, scene, display_listener,
             fixed_composite_delay, report);
 
-        futures.push_back(thread_pool.run(std::ref(*thread_functor), &group));
+        mir::system_executor.spawn(std::ref(*thread_functor));
         thread_functors.push_back(std::move(thread_functor));
     });
 
-    thread_pool.shrink();
-
     for (auto& functor : thread_functors)
         functor->wait_until_started();
 }
@@ -376,9 +392,8 @@ void mc::MultiThreadedCompositor::destroy_compositing_threads()
     for (auto& f : thread_functors)
         f->stop();
 
-    for (auto& f : futures)
-        f.wait();
+    for (auto& f : thread_functors)
+        f->wait_until_stopped();
 
     thread_functors.clear();
-    futures.clear();
 }
