@@ -34,31 +34,6 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 
-// Older versions of libdrm do not provide drmIsMaster()
-#ifndef MIR_LIBDRM_HAS_IS_MASTER
-#include <drm.h>
-
-bool drmIsMaster(int fd)
-{
-    struct drm_mode_mode_cmd cmd;
-
-    ::memset(&cmd, 0, sizeof cmd);
-    /* Set an invalid connector_id to ensure that ATTACHMODE errors with
-     * EINVAL in the unlikely event someone feels like calling this on a
-     * kernel prior to 3.9. */
-    cmd.connector_id = -1;
-
-    if (drmIoctl(fd, DRM_IOCTL_MODE_ATTACHMODE, &cmd) != -1)
-    {
-        /* On 3.9 ATTACHMODE was changed to drm_noop, and so will succeed
-         * iff we've got a master fd */
-        return true;
-    }
-
-    return errno == EINVAL;
-}
-#endif
-
 mir::MinimalConsoleDevice::MinimalConsoleDevice(std::unique_ptr<mir::Device::Observer> observer)
     : observer{std::move(observer)}
 {
