@@ -19,8 +19,9 @@
 #ifndef MIR_FRONTEND_FOREIGN_TOPLEVEL_MANAGER_V1_H
 #define MIR_FRONTEND_FOREIGN_TOPLEVEL_MANAGER_V1_H
 
+#include "wlr-foreign-toplevel-management-unstable-v1_wrapper.h"
+
 #include <memory>
-struct wl_display;
 
 namespace mir
 {
@@ -32,13 +33,13 @@ class Shell;
 namespace frontend
 {
 class SurfaceStack;
-class ForeignToplevelManagerV1Global;
 
 auto create_foreign_toplevel_manager_v1(
     wl_display* display,
     std::shared_ptr<shell::Shell> const& shell,
     std::shared_ptr<Executor> const& wayland_executor,
-    std::shared_ptr<SurfaceStack> const& surface_stack) -> std::shared_ptr<ForeignToplevelManagerV1Global>;
+    std::shared_ptr<SurfaceStack> const& surface_stack)
+-> std::shared_ptr<wayland::ForeignToplevelManagerV1::Global>;
 }
 }
 
