@@ -68,7 +68,7 @@ class LayerShellV1::Instance : wayland::LayerShellV1
 {
 public:
     Instance(wl_resource* new_resource, mf::LayerShellV1* shell)
-        : LayerShellV1{new_resource, Version<3>()},
+        : LayerShellV1{new_resource, Version<4>()},
           shell{shell}
     {
     }
@@ -77,7 +77,7 @@ private:
     void get_layer_surface(
         wl_resource* new_layer_surface,
         wl_resource* surface,
-        std::experimental::optional<wl_resource*> const& output,
+        std::optional<wl_resource*> const& output,
         uint32_t layer,
         std::string const& namespace_) override;
 
@@ -90,13 +90,13 @@ public:
     LayerSurfaceV1(
         wl_resource* new_resource,
         WlSurface* surface,
-        std::experimental::optional<graphics::DisplayConfigurationOutputId> output_id,
+        std::optional<graphics::DisplayConfigurationOutputId> output_id,
         LayerShellV1 const& layer_shell,
         MirDepthLayer layer);
 
     ~LayerSurfaceV1() = default;
 
-    static auto from(wl_resource* surface) -> std::experimental::optional<LayerSurfaceV1*>;
+    static auto from(wl_resource* surface) -> std::optional<LayerSurfaceV1*>;
 
 private:
     template<typename T>
@@ -118,18 +118,18 @@ private:
             {
                 _committed = _pending.value();
             }
-            _pending = std::experimental::nullopt;
+            _pending = std::nullopt;
         }
 
     private:
-        std::experimental::optional<T> _pending;
+        std::optional<T> _pending;
         T _committed;
     };
 
     struct OptionalSize
     {
-        std::experimental::optional<geom::Width> width;
-        std::experimental::optional<geom::Height> height;
+        std::optional<geom::Width> width;
+        std::optional<geom::Height> height;
     };
 
     struct Margin
@@ -156,7 +156,7 @@ private:
     auto get_anchored_edge() const -> MirPlacementGravity;
 
     /// Returns the rectangele in surface coords that this surface is exclusive for (if any)
-    auto get_exclusive_rect() const -> std::experimental::optional<geom::Rectangle>;
+    auto get_exclusive_rect() const -> std::optional<geom::Rectangle>;
 
     static auto horiz_padding(Anchors const& anchors, Margin const& margin) -> geom::DeltaX;
     static auto vert_padding(Anchors const& anchors, Margin const& margin) -> geom::DeltaY;
@@ -185,9 +185,10 @@ private:
     void handle_state_change(MirWindowState /*new_state*/) override {};
     void handle_active_change(bool /*is_now_active*/) override {};
     void handle_resize(
-        std::experimental::optional<geometry::Point> const& /*new_top_left*/,
+        std::optional<geometry::Point> const& /*new_top_left*/,
         geometry::Size const& /*new_size*/) override;
     void handle_close_request() override;
+    void surface_destroyed() override;
 
     DoubleBuffered<uint32_t> exclusive_zone{0};
     DoubleBuffered<Anchors> anchors;
@@ -199,6 +200,7 @@ private:
     DoubleBuffered<geometry::Size> client_size;
     DoubleBuffered<geometry::Displacement> offset;
     bool configure_on_next_commit{true}; ///< If to send a .configure event at the end of the next or current commit
+    MirFocusMode current_focus_mode{mir_focus_mode_disabled};
     std::deque<std::pair<uint32_t, OptionalSize>> inflight_configures;
     std::vector<wayland::Weak<XdgPopupStable>> popups; ///< We have to keep track of popups to adjust their offset
 };
@@ -214,7 +216,7 @@ mf::LayerShellV1::LayerShellV1(
     std::shared_ptr<msh::Shell> shell,
     WlSeat& seat,
     OutputManager* output_manager)
-    : Global(display, Version<3>()),
+    : Global(display, Version<4>()),
       wayland_executor{wayland_executor},
       shell{shell},
       seat{seat},
@@ -250,20 +252,16 @@ void mf::LayerShellV1::bind(wl_resource* new_resource)
 void mf::LayerShellV1::Instance::get_layer_surface(
     wl_resource* new_layer_surface,
     wl_resource* surface,
-    std::experimental::optional<wl_resource*> const& output,
+    std::optional<wl_resource*> const& output,
     uint32_t layer,
     std::string const& namespace_)
 {
-    (void)namespace_; // Can be ignored if no special behavior is required
-
-    auto const output_id = output ?
-        shell->output_manager->output_id_for(client, output.value()) :
-        std::experimental::nullopt;
+    (void)namespace_; // Can be ignored if no special behavior is required;
 
     new LayerSurfaceV1(
         new_layer_surface,
         WlSurface::from(surface),
-        output_id,
+        shell->output_manager->output_id_for(client, output.value_or(nullptr)),
         *shell,
         layer_shell_layer_to_mir_depth_layer(layer));
 }
@@ -273,10 +271,10 @@ void mf::LayerShellV1::Instance::get_layer_surface(
 mf::LayerSurfaceV1::LayerSurfaceV1(
     wl_resource* new_resource,
     WlSurface* surface,
-    std::experimental::optional<graphics::DisplayConfigurationOutputId> output_id,
+    std::optional<graphics::DisplayConfigurationOutputId> output_id,
     LayerShellV1 const& layer_shell,
     MirDepthLayer layer)
-    : mw::LayerSurfaceV1(new_resource, Version<3>()),
+    : mw::LayerSurfaceV1(new_resource, Version<4>()),
       WindowWlSurfaceRole(
           layer_shell.wayland_executor,
           &layer_shell.seat,
@@ -289,21 +287,22 @@ mf::LayerSurfaceV1::LayerSurfaceV1(
     shell::SurfaceSpecification spec;
     spec.state = mir_window_state_attached;
     spec.depth_layer = layer;
+    spec.focus_mode = current_focus_mode;
     if (output_id)
         spec.output_id = output_id.value();
     apply_spec(spec);
 }
 
-auto mf::LayerSurfaceV1::from(wl_resource* surface) -> std::experimental::optional<LayerSurfaceV1*>
+auto mf::LayerSurfaceV1::from(wl_resource* surface) -> std::optional<LayerSurfaceV1*>
 {
     if (!mw::LayerSurfaceV1::is_instance(surface))
-        return std::experimental::nullopt;
+        return std::nullopt;
     auto const mw_surface = mw::LayerSurfaceV1::from(surface);
     auto const mf_surface = dynamic_cast<mf::LayerSurfaceV1*>(mw_surface);
     if (mf_surface)
         return mf_surface;
     else
-        return std::experimental::nullopt;
+        return std::nullopt;
 }
 
 auto mf::LayerSurfaceV1::get_placement_gravity() const -> MirPlacementGravity
@@ -354,11 +353,11 @@ auto mf::LayerSurfaceV1::get_anchored_edge() const -> MirPlacementGravity
         return mir_placement_gravity_center;
 }
 
-auto mf::LayerSurfaceV1::get_exclusive_rect() const -> std::experimental::optional<geom::Rectangle>
+auto mf::LayerSurfaceV1::get_exclusive_rect() const -> std::optional<geom::Rectangle>
 {
     auto zone = exclusive_zone.pending();
     if (zone <= 0)
-        return std::experimental::nullopt;
+        return std::nullopt;
 
     auto edge = get_anchored_edge();
     auto size = pending_size(); // includes margin padding
@@ -386,7 +385,7 @@ auto mf::LayerSurfaceV1::get_exclusive_rect() const -> std::experimental::option
             {size.width, geom::Height{zone} + margin.pending().bottom}};
 
     default:
-        return std::experimental::nullopt;
+        return std::nullopt;
     }
 }
 
@@ -437,7 +436,7 @@ void mf::LayerSurfaceV1::configure()
 {
     // TODO: Error if told to configure on an axis the window is not streatched along
 
-    OptionalSize configure_size{std::experimental::nullopt, std::experimental::nullopt};
+    OptionalSize configure_size{std::nullopt, std::nullopt};
     auto requested = unpadded_requested_size();
 
     if (anchors.committed().left && anchors.committed().right)
@@ -517,7 +516,30 @@ void mf::LayerSurfaceV1::set_margin(int32_t top, int32_t right, int32_t bottom,
 
 void mf::LayerSurfaceV1::set_keyboard_interactivity(uint32_t keyboard_interactivity)
 {
-    (void)keyboard_interactivity;
+    switch (keyboard_interactivity)
+    {
+    case KeyboardInteractivity::none:
+        current_focus_mode = mir_focus_mode_disabled;
+        break;
+
+    case KeyboardInteractivity::exclusive:
+        current_focus_mode = mir_focus_mode_grabbing;
+        break;
+
+    case KeyboardInteractivity::on_demand:
+        current_focus_mode = mir_focus_mode_focusable;
+        break;
+
+    default:
+        BOOST_THROW_EXCEPTION(mw::ProtocolError(
+            resource,
+            Error::invalid_keyboard_interactivity,
+            "Invalid keyboard interactivity %d",
+            keyboard_interactivity));
+    }
+    msh::SurfaceSpecification spec;
+    spec.focus_mode = current_focus_mode;
+    apply_spec(spec);
 }
 
 void mf::LayerSurfaceV1::get_popup(struct wl_resource* popup)
@@ -629,7 +651,7 @@ void mf::LayerSurfaceV1::handle_commit()
 }
 
 void mf::LayerSurfaceV1::handle_resize(
-    std::experimental::optional<geom::Point> const& /*new_top_left*/,
+    std::optional<geom::Point> const& /*new_top_left*/,
     geom::Size const& /*new_size*/)
 {
     configure();
@@ -639,3 +661,18 @@ void mf::LayerSurfaceV1::handle_close_request()
 {
     send_closed_event();
 }
+
+void mf::LayerSurfaceV1::surface_destroyed()
+{
+    // Squeekboard (and possibly other purism apps) violate the protocol by destroying the surface before the role.
+    // Until it gets fixed we ignore this error for layer shell specifically.
+    // See: https://gitlab.gnome.org/World/Phosh/squeekboard/-/issues/285
+    try
+    {
+        WindowWlSurfaceRole::surface_destroyed();
+    }
+    catch (std::exception const& err)
+    {
+        log_warning("Ignoring layer shell protocol violation: %s", err.what());
+    }
+}
