@@ -15,7 +15,6 @@
  */
 
 #include "pointer_constraints_unstable_v1.h"
-#include "pointer-constraints-unstable-v1_wrapper.h"
 #include "wl_region.h"
 #include "wl_surface.h"
 
@@ -62,14 +61,14 @@ private:
         wl_resource* id,
         wl_resource* surface,
         wl_resource* pointer,
-        const std::experimental::optional<wl_resource*>& region,
+        const std::optional<wl_resource*>& region,
         uint32_t lifetime) override;
 
     void confine_pointer(
         wl_resource* id,
         wl_resource* surface,
         wl_resource* pointer,
-        const std::experimental::optional<wl_resource*>& region,
+        const std::optional<wl_resource*>& region,
         uint32_t lifetime) override;
 };
 
@@ -81,7 +80,7 @@ public:
         Executor& wayland_executor,
         std::shared_ptr<shell::Shell> shell,
         std::shared_ptr<scene::Surface> const& scene_surface,
-        std::experimental::optional<wl_resource*> const& region,
+        std::optional<wl_resource*> const& region,
         PointerConstraintsV1::Lifetime lifetime);
     ~LockedPointerV1();
 
@@ -94,7 +93,7 @@ private:
     std::shared_ptr<MyWaylandSurfaceObserver> const my_surface_observer;
 
     void set_cursor_position_hint(double /*surface_x*/, double /*surface_y*/) override;
-    void set_region(const std::experimental::optional<wl_resource*>& /*region*/) override;
+    void set_region(const std::optional<wl_resource*>& /*region*/) override;
 };
 
 class ConfinedPointerV1 : public wayland::ConfinedPointerV1
@@ -105,7 +104,7 @@ public:
         Executor& wayland_executor,
         std::shared_ptr<shell::Shell> shell,
         std::shared_ptr<scene::Surface> const& scene_surface,
-        std::experimental::optional<wl_resource*> const& region,
+        std::optional<wl_resource*> const& region,
         PointerConstraintsV1::Lifetime lifetime);
     ~ConfinedPointerV1();
 
@@ -117,7 +116,7 @@ private:
 
     std::shared_ptr<SurfaceObserver> const my_surface_observer;
 
-    void set_region(const std::experimental::optional<wl_resource*>& /*region*/) override;
+    void set_region(const std::optional<wl_resource*>& /*region*/) override;
 };
 
 struct LockedPointerV1::MyWaylandSurfaceObserver : ms::NullSurfaceObserver
@@ -141,7 +140,7 @@ void LockedPointerV1::MyWaylandSurfaceObserver::attrib_changed(
         {
         case mir_pointer_locked_persistent:
         case mir_pointer_locked_oneshot:
-            if (value)
+            if (value != mir_window_focus_state_unfocused)
             {
                 wayland_executor.spawn([self=self]()
                     {
@@ -192,7 +191,7 @@ void ConfinedPointerV1::SurfaceObserver::attrib_changed(
         {
         case mir_pointer_confined_persistent:
         case mir_pointer_confined_oneshot:
-            if (value)
+            if (value != mir_window_focus_state_unfocused)
             {
                 wayland_executor.spawn([self=self]()
                     {
@@ -224,8 +223,11 @@ void ConfinedPointerV1::SurfaceObserver::attrib_changed(
 }
 }
 
-auto mir::frontend::create_pointer_constraints_unstable_v1(wl_display* display, Executor& wayland_executor, std::shared_ptr<shell::Shell> shell)
-    -> std::shared_ptr<void>
+auto mir::frontend::create_pointer_constraints_unstable_v1(
+    wl_display* display,
+    Executor& wayland_executor,
+    std::shared_ptr<shell::Shell> shell)
+-> std::shared_ptr<mw::PointerConstraintsV1::Global>
 {
     return std::make_shared<PointerConstraintsV1::Global>(display, wayland_executor, std::move(shell));
 }
@@ -253,7 +255,7 @@ void mir::frontend::PointerConstraintsV1::lock_pointer(
     wl_resource* id,
     wl_resource* surface,
     wl_resource* /*pointer*/,
-    std::experimental::optional<wl_resource*> const& region,
+    std::optional<wl_resource*> const& region,
     uint32_t lifetime)
 {
     if (auto const s = WlSurface::from(surface)->scene_surface())
@@ -270,7 +272,7 @@ void mir::frontend::PointerConstraintsV1::confine_pointer(
     wl_resource* id,
     wl_resource* surface,
     wl_resource* /*pointer*/,
-    std::experimental::optional<wl_resource*> const& region,
+    std::optional<wl_resource*> const& region,
     uint32_t lifetime)
 {
     if (auto const s = WlSurface::from(surface)->scene_surface())
@@ -288,7 +290,7 @@ mir::frontend::LockedPointerV1::LockedPointerV1(
     Executor& wayland_executor,
     std::shared_ptr<shell::Shell> shell,
     std::shared_ptr<scene::Surface> const& scene_surface,
-    std::experimental::optional<wl_resource*> const& region,
+    std::optional<wl_resource*> const& region,
     PointerConstraintsV1::Lifetime lifetime) :
     wayland::LockedPointerV1{id, Version<1>{}},
     shell{std::move(shell)},
@@ -346,7 +348,7 @@ void mir::frontend::LockedPointerV1::set_cursor_position_hint(double /*surface_x
 {
 }
 
-void mir::frontend::LockedPointerV1::set_region(const std::experimental::optional<wl_resource*>& /*region*/)
+void mir::frontend::LockedPointerV1::set_region(const std::optional<wl_resource*>& /*region*/)
 {
 }
 
@@ -355,7 +357,7 @@ mir::frontend::ConfinedPointerV1::ConfinedPointerV1(
     Executor& wayland_executor,
     std::shared_ptr<shell::Shell> shell,
     std::shared_ptr<scene::Surface> const& scene_surface,
-    std::experimental::optional<wl_resource*> const& region,
+    std::optional<wl_resource*> const& region,
     PointerConstraintsV1::Lifetime lifetime) :
     wayland::ConfinedPointerV1{id, Version<1>{}},
     shell{std::move(shell)},
@@ -408,6 +410,6 @@ mir::frontend::ConfinedPointerV1::~ConfinedPointerV1()
     }
 }
 
-void mir::frontend::ConfinedPointerV1::set_region(const std::experimental::optional<wl_resource*>& /*region*/)
+void mir::frontend::ConfinedPointerV1::set_region(const std::optional<wl_resource*>& /*region*/)
 {
 }
