@@ -17,9 +17,9 @@
 #ifndef MIR_FRONTEND_RELATIVE_POINTER_UNSTABLE_V1_H
 #define MIR_FRONTEND_RELATIVE_POINTER_UNSTABLE_V1_H
 
-#include <memory>
+#include "relative-pointer-unstable-v1_wrapper.h"
 
-struct wl_display;
+#include <memory>
 
 namespace mir
 {
@@ -27,7 +27,10 @@ namespace shell { class Shell; }
 
 namespace frontend
 {
-auto create_relative_pointer_unstable_v1(wl_display* display, std::shared_ptr<shell::Shell> shell) -> std::shared_ptr<void>;
+auto create_relative_pointer_unstable_v1(
+    wl_display* display,
+    std::shared_ptr<shell::Shell> shell)
+-> std::shared_ptr<wayland::RelativePointerManagerV1::Global>;
 }
 }
 
