@@ -32,17 +32,14 @@
 #include "output_manager.h"
 #include "wayland_executor.h"
 
-#include "wayland_wrapper.h"
-
-#include "mir/frontend/surface.h"
 #include "mir/frontend/wayland.h"
 
 #include "mir/main_loop.h"
 
 #include "mir/compositor/buffer_stream.h"
 
-#include "mir/scene/surface_creation_parameters.h"
 #include "mir/shell/shell.h"
+#include "mir/shell/surface_specification.h"
 #include "mir/scene/surface.h"
 #include <mir/thread_name.h>
 
@@ -50,11 +47,8 @@
 #include "mir/graphics/buffer.h"
 #include "mir/graphics/graphic_buffer_allocator.h"
 
-#include "mir/renderer/gl/texture_target.h"
 #include "mir/frontend/buffer_stream_id.h"
 
-#include "mir/client/event.h"
-
 #include "mir/input/seat.h"
 #include "mir/input/device.h"
 #include "mir/input/mir_keyboard_config.h"
@@ -82,11 +76,6 @@
 #include <unordered_set>
 #include "mir/anonymous_shm_file.h"
 
-
-#if (WAYLAND_VERSION_MAJOR == 1) && (WAYLAND_VERSION_MINOR < 14)
-#define MIR_NO_WAYLAND_FILTER
-#endif
-
 namespace mf = mir::frontend;
 namespace mg = mir::graphics;
 namespace mc = mir::compositor;
@@ -94,7 +83,6 @@ namespace ms = mir::scene;
 namespace msh = mir::shell;
 namespace msh = mir::shell;
 namespace geom = mir::geometry;
-namespace mcl = mir::client;
 namespace mi = mir::input;
 namespace mw = mir::wayland;
 
@@ -244,8 +232,9 @@ protected:
     void handle_state_change(MirWindowState /*new_state*/) override {};
     void handle_active_change(bool /*is_now_active*/) override {};
 
-    void handle_resize(std::experimental::optional<geometry::Point> const& /*new_top_left*/,
-                       geometry::Size const& new_size) override
+    void handle_resize(
+        std::optional<geometry::Point> const& /*new_top_left*/,
+        geometry::Size const& new_size) override
     {
         wl_shell_surface_send_configure(resource, WL_SHELL_SURFACE_RESIZE_NONE, new_size.width.as_int(),
                                         new_size.height.as_int());
@@ -259,7 +248,7 @@ protected:
     void set_fullscreen(
         uint32_t /*method*/,
         uint32_t /*framerate*/,
-        std::experimental::optional<struct wl_resource*> const& output) override
+        std::optional<struct wl_resource*> const& output) override
     {
         WindowWlSurfaceRole::set_fullscreen(output);
     }
@@ -290,7 +279,7 @@ protected:
         apply_spec(mods);
     }
 
-    void set_maximized(std::experimental::optional<struct wl_resource*> const& output) override
+    void set_maximized(std::optional<struct wl_resource*> const& output) override
     {
         (void)output;
         WindowWlSurfaceRole::add_state_now(mir_window_state_maximized);
@@ -466,7 +455,7 @@ auto mf::create_wl_shell(
     std::shared_ptr<msh::Shell> const& shell,
     WlSeat* seat,
     OutputManager* const output_manager)
--> std::shared_ptr<void>
+-> std::shared_ptr<mw::Shell::Global>
 {
     return std::make_shared<mf::WlShell>(display, wayland_executor, shell, *seat, output_manager);
 }
@@ -501,12 +490,16 @@ void mf::WaylandExtensions::run_builders(wl_display*, std::function<void(std::fu
 mf::WaylandConnector::WaylandConnector(
     std::shared_ptr<msh::Shell> const& shell,
     std::shared_ptr<MirDisplay> const& display_config,
+    std::shared_ptr<time::Clock> const& clock,
     std::shared_ptr<mi::InputDeviceHub> const& input_hub,
     std::shared_ptr<mi::Seat> const& seat,
+    std::shared_ptr<mi::InputDeviceRegistry> const& input_device_registry,
+    std::shared_ptr<mi::CompositeEventFilter> const& composite_event_filter,
     std::shared_ptr<mg::GraphicBufferAllocator> const& allocator,
     std::shared_ptr<mf::SessionAuthorizer> const& session_authorizer,
     std::shared_ptr<SurfaceStack> const& surface_stack,
     std::shared_ptr<ms::Clipboard> const& clipboard,
+    std::shared_ptr<ms::TextInputHub> const& text_input_hub,
     std::shared_ptr<MainLoop> const& main_loop,
     bool arw_socket,
     std::unique_ptr<WaylandExtensions> extensions_,
@@ -533,13 +526,7 @@ mf::WaylandConnector::WaylandConnector(
         BOOST_THROW_EXCEPTION(std::runtime_error{"Failed to create wl_display"});
     }
 
-#ifndef MIR_NO_WAYLAND_FILTER
     wl_display_set_global_filter(display.get(), &wl_display_global_filter_func_thunk, this);
-#else
-    log_warning("Cannot set Wayland protocol filter: "
-        "wl_display_set_global_filter() is unavailable in libwayland-dev "
-        WAYLAND_VERSION);
-#endif
 
     // Run the builders before creating the seat (because that's what GTK3 expects)
     extensions->run_builders(
@@ -561,7 +548,7 @@ mf::WaylandConnector::WaylandConnector(
         std::make_shared<FrameExecutor>(*main_loop),
         this->allocator);
     subcompositor_global = std::make_unique<mf::WlSubcompositor>(display.get());
-    seat_global = std::make_unique<mf::WlSeat>(display.get(), input_hub, seat, enable_key_repeat);
+    seat_global = std::make_unique<mf::WlSeat>(display.get(), clock, input_hub, seat, enable_key_repeat);
     output_manager = std::make_unique<mf::OutputManager>(
         display.get(),
         display_config,
@@ -574,9 +561,12 @@ mf::WaylandConnector::WaylandConnector(
         executor,
         shell,
         clipboard,
+        text_input_hub,
         seat_global.get(),
         output_manager.get(),
-        surface_stack});
+        surface_stack,
+        input_device_registry,
+        composite_event_filter});
 
     wl_display_init_shm(display.get());
 
@@ -658,8 +648,6 @@ void mf::WaylandConnector::start()
             wl_display_run(d);
         },
         display.get()};
-
-    executor->spawn([this]{ seat_global->server_restart(); });
 }
 
 void mf::WaylandConnector::stop()
@@ -780,14 +768,9 @@ bool mf::WaylandConnector::wl_display_global_filter_func_thunk(wl_client const*
 
 bool mf::WaylandConnector::wl_display_global_filter_func(wl_client const* client, wl_global const* global) const
 {
-#ifndef MIR_NO_WAYLAND_FILTER
     auto const* const interface = wl_global_get_interface(global);
     auto const session = get_session(const_cast<wl_client*>(client));
     return extension_filter(session, interface->name);
-#else
-    (void)client, (void)global;
-    return true;
-#endif
 }
 
 auto mir::frontend::get_session(wl_client* wl_client) -> std::shared_ptr<scene::Session>
