@@ -24,10 +24,6 @@
 #include "wl_touch.h"
 
 #include <mir/input/keymap.h>
-#include <mir/log.h>
-
-#include <linux/input-event-codes.h>
-#include <boost/throw_exception.hpp>
 
 namespace mf = mir::frontend;
 namespace ms = mir::scene;
@@ -44,19 +40,6 @@ mf::WaylandInputDispatcher::WaylandInputDispatcher(
 {
 }
 
-void mf::WaylandInputDispatcher::set_keymap(mi::Keymap const& keymap)
-{
-    if (!wl_surface)
-    {
-        return;
-    }
-
-    seat->for_each_listener(client, [&](WlKeyboard* keyboard)
-        {
-            keyboard->set_keymap(keymap);
-        });
-}
-
 void mf::WaylandInputDispatcher::set_focus(bool has_focus)
 {
     if (!wl_surface)
@@ -64,13 +47,8 @@ void mf::WaylandInputDispatcher::set_focus(bool has_focus)
         return;
     }
 
-    if (has_focus)
-        seat->notify_focus(client);
-
-    seat->for_each_listener(client, [&](WlKeyboard* keyboard)
-        {
-            keyboard->focussed(wl_surface.value(), has_focus);
-        });
+    auto const surface = &wl_surface.value();
+    seat->notify_focus(*surface, has_focus);
 }
 
 void mf::WaylandInputDispatcher::handle_event(MirInputEvent const* event)
@@ -89,11 +67,11 @@ void mf::WaylandInputDispatcher::handle_event(MirInputEvent const* event)
     switch (mir_input_event_get_type(event))
     {
     case mir_input_event_type_key:
+    case mir_input_event_type_keyboard_resync:
     {
-        auto const keyboard_event = mir_input_event_get_keyboard_event(event);
         seat->for_each_listener(client, [&](WlKeyboard* keyboard)
             {
-                keyboard->event(keyboard_event, wl_surface.value());
+                keyboard->handle_event(event, wl_surface.value());
             });
     }   break;
 
