@@ -26,7 +26,6 @@
 
 #include <memory>
 #include <chrono>
-#include <experimental/optional>
 
 struct wl_client;
 
@@ -51,7 +50,6 @@ public:
         WlSurface* wl_surface);
     ~WaylandInputDispatcher() = default;
 
-    void set_keymap(input::Keymap const& keymap);
     void set_focus(bool has_focus);
     void handle_event(MirInputEvent const* event);
 
