@@ -23,7 +23,6 @@
 
 #include <mir/executor.h>
 #include <mir/events/event_builders.h>
-#include <mir/input/keymap.h>
 #include <mir/log.h>
 
 namespace mf = mir::frontend;
@@ -57,9 +56,9 @@ void mf::WaylandSurfaceObserver::attrib_changed(ms::Surface const*, MirWindowAtt
         run_on_wayland_thread_unless_window_destroyed(
             [value](Impl* impl, WindowWlSurfaceRole* window)
             {
-                auto has_focus = static_cast<bool>(value);
-                impl->input_dispatcher->set_focus(has_focus);
-                window->handle_active_change(has_focus);
+                auto state = static_cast<MirWindowFocusState>(value);
+                impl->input_dispatcher->set_focus(state == mir_window_focus_state_focused);
+                window->handle_active_change(state != mir_window_focus_state_unfocused);
             });
         break;
 
@@ -84,7 +83,7 @@ void mf::WaylandSurfaceObserver::content_resized_to(ms::Surface const*, geom::Si
             if (content_size != impl->window_size)
             {
                 impl->requested_size = content_size;
-                window->handle_resize(std::experimental::nullopt, content_size);
+                window->handle_resize(std::nullopt, content_size);
             }
         });
 }
@@ -98,24 +97,6 @@ void mf::WaylandSurfaceObserver::client_surface_close_requested(ms::Surface cons
         });
 }
 
-void mf::WaylandSurfaceObserver::keymap_changed(
-        ms::Surface const*,
-        MirInputDeviceId /* id */,
-        std::string const& model,
-        std::string const& layout,
-        std::string const& variant,
-        std::string const& options)
-{
-    // shared pointer instead of unique so it can be owned by the lambda
-    auto const keymap = std::make_shared<mi::Keymap>(model, layout, variant, options);
-
-    run_on_wayland_thread_unless_window_destroyed(
-        [keymap](Impl* impl, WindowWlSurfaceRole*)
-        {
-            impl->input_dispatcher->set_keymap(*keymap);
-        });
-}
-
 void mf::WaylandSurfaceObserver::placed_relative(ms::Surface const*, geometry::Rectangle const& placement)
 {
     run_on_wayland_thread_unless_window_destroyed(
