@@ -24,7 +24,7 @@
 #include <mir/scene/null_surface_observer.h>
 
 #include <memory>
-#include <experimental/optional>
+#include <optional>
 #include <chrono>
 #include <functional>
 
@@ -51,13 +51,6 @@ public:
     void attrib_changed(scene::Surface const*, MirWindowAttrib attrib, int value) override;
     void content_resized_to(scene::Surface const*, geometry::Size const& content_size) override;
     void client_surface_close_requested(scene::Surface const*) override;
-    void keymap_changed(
-        scene::Surface const*,
-        MirInputDeviceId id,
-        std::string const& model,
-        std::string const& layout,
-        std::string const& variant,
-        std::string const& options) override;
     void placed_relative(scene::Surface const*, geometry::Rectangle const& placement) override;
     void input_consumed(scene::Surface const*, MirEvent const* event) override;
     ///@}
@@ -69,7 +62,7 @@ public:
     }
 
     /// Should only be called from the Wayland thread
-    std::experimental::optional<geometry::Size> requested_window_size()
+    std::optional<geometry::Size> requested_window_size()
     {
         return impl->requested_size;
     }
@@ -98,7 +91,7 @@ private:
         std::unique_ptr<WaylandInputDispatcher> const input_dispatcher;
 
         geometry::Size window_size{};
-        std::experimental::optional<geometry::Size> requested_size{};
+        std::optional<geometry::Size> requested_size{};
         MirWindowState current_state{mir_window_state_unknown};
     };
 
