@@ -32,7 +32,6 @@
 
 #include "mir/log.h"
 #include "mir/scene/surface.h"
-#include "mir/scene/surface_creation_parameters.h"
 
 #include <boost/throw_exception.hpp>
 
@@ -75,18 +74,20 @@ mf::WindowWlSurfaceRole::WindowWlSurfaceRole(
       session{weak_client.value().client_session()},
       output_manager{output_manager},
       observer{std::make_shared<WaylandSurfaceObserver>(wayland_executor, seat, surface, this)},
-      params{std::make_unique<scene::SurfaceCreationParameters>(
-          scene::SurfaceCreationParameters().of_type(mir_window_type_freestyle))},
       committed_min_size{0, 0},
       committed_max_size{max_possible_size}
 {
+    spec().type = mir_window_type_freestyle;
     surface->set_role(this);
 }
 
 mf::WindowWlSurfaceRole::~WindowWlSurfaceRole()
 {
     mark_destroyed();
-    surface->clear_role();
+    if (surface)
+    {
+        surface.value().clear_role();
+    }
     if (auto const scene_surface = weak_scene_surface.lock())
     {
         shell->destroy_surface(session, scene_surface);
@@ -94,20 +95,23 @@ mf::WindowWlSurfaceRole::~WindowWlSurfaceRole()
     }
 }
 
-auto mf::WindowWlSurfaceRole::scene_surface() const -> std::experimental::optional<std::shared_ptr<scene::Surface>>
+auto mf::WindowWlSurfaceRole::scene_surface() const -> std::optional<std::shared_ptr<scene::Surface>>
 {
     auto shared = weak_scene_surface.lock();
     if (shared)
         return shared;
     else
-        return std::experimental::nullopt;
+        return std::nullopt;
 }
 
 void mf::WindowWlSurfaceRole::populate_spec_with_surface_data(shell::SurfaceSpecification& spec)
 {
     spec.streams = std::vector<shell::StreamSpecification>();
     spec.input_shape = std::vector<geom::Rectangle>();
-    surface->populate_surface_data(spec.streams.value(), spec.input_shape.value(), {});
+    if (surface)
+    {
+        surface.value().populate_surface_data(spec.streams.value(), spec.input_shape.value(), {});
+    }
 }
 
 void mf::WindowWlSurfaceRole::refresh_surface_data_now()
@@ -127,53 +131,35 @@ void mf::WindowWlSurfaceRole::apply_spec(mir::shell::SurfaceSpecification const&
     if (new_spec.height.is_set())
         pending_explicit_height = new_spec.height.value();
 
-    if (weak_scene_surface.lock())
-    {
-        spec().update_from(new_spec);
-    }
-    else
-    {
-        params->update_from(new_spec);
-    }
+    spec().update_from(new_spec);
 }
 
-void mf::WindowWlSurfaceRole::set_pending_offset(std::experimental::optional<geom::Displacement> const& offset)
+void mf::WindowWlSurfaceRole::set_pending_offset(std::optional<geom::Displacement> const& offset)
 {
-    surface->set_pending_offset(offset);
+    if (surface)
+    {
+        surface.value().set_pending_offset(offset);
+    }
 }
 
-void mf::WindowWlSurfaceRole::set_pending_width(std::experimental::optional<geometry::Width> const& width)
+void mf::WindowWlSurfaceRole::set_pending_width(std::optional<geometry::Width> const& width)
 {
     pending_explicit_width = width;
 }
 
-void mf::WindowWlSurfaceRole::set_pending_height(std::experimental::optional<geometry::Height> const& height)
+void mf::WindowWlSurfaceRole::set_pending_height(std::optional<geometry::Height> const& height)
 {
     pending_explicit_height = height;
 }
 
 void mf::WindowWlSurfaceRole::set_title(std::string const& title)
 {
-    if (weak_scene_surface.lock())
-    {
-        spec().name = title;
-    }
-    else
-    {
-        params->name = title;
-    }
+    spec().name = title;
 }
 
 void mf::WindowWlSurfaceRole::set_application_id(std::string const& application_id)
 {
-    if (weak_scene_surface.lock())
-    {
-        spec().application_id = application_id;
-    }
-    else
-    {
-        params->application_id = application_id;
-    }
+    spec().application_id = application_id;
 }
 
 void mf::WindowWlSurfaceRole::initiate_interactive_move()
@@ -192,118 +178,75 @@ void mf::WindowWlSurfaceRole::initiate_interactive_resize(MirResizeEdge edge)
     }
 }
 
-void mf::WindowWlSurfaceRole::set_parent(std::experimental::optional<std::shared_ptr<scene::Surface>> const& parent)
+void mf::WindowWlSurfaceRole::set_parent(std::optional<std::shared_ptr<scene::Surface>> const& parent)
 {
-    if (weak_scene_surface.lock())
+    auto& mods = spec();
+    if (parent)
     {
-        if (parent)
-            spec().parent = parent.value();
-        else if (spec().parent)
-            spec().parent.consume();
+        mods.parent = parent.value();
     }
-    else
+    else if (mods.parent)
     {
-        if (parent)
-            params->parent = parent.value();
-        else
-            params->parent = {};
+        mods.parent.consume();
     }
 }
 
 void mf::WindowWlSurfaceRole::set_max_size(int32_t width, int32_t height)
 {
-    if (weak_scene_surface.lock())
-    {
-        if (width == 0) width = max_possible_size.width.as_int();
-        if (height == 0) height = max_possible_size.height.as_int();
-
-        auto& mods = spec();
-        mods.max_width = geom::Width{width};
-        mods.max_height = geom::Height{height};
-    }
-    else
-    {
-        if (width == 0)
-        {
-            if (params->max_width.is_set())
-                params->max_width.consume();
-        }
-        else
-            params->max_width = geom::Width{width};
-
-        if (height == 0)
-        {
-            if (params->max_height.is_set())
-                params->max_height.consume();
-        }
-        else
-            params->max_height = geom::Height{height};
-    }
+    auto& mods = spec();
+    mods.max_width = width ? geom::Width{width} : max_possible_size.width;
+    mods.max_height = height ? geom::Height{height} : max_possible_size.height;
 }
 
 void mf::WindowWlSurfaceRole::set_min_size(int32_t width, int32_t height)
 {
-    if (weak_scene_surface.lock())
-    {
-        auto& mods = spec();
-        mods.min_width = geom::Width{width};
-        mods.min_height = geom::Height{height};
-    }
-    else
-    {
-        params->min_width = geom::Width{width};
-        params->min_height = geom::Height{height};
-    }
+    auto& mods = spec();
+    mods.min_width = geom::Width{width};
+    mods.min_height = geom::Height{height};
 }
 
-void mf::WindowWlSurfaceRole::set_fullscreen(std::experimental::optional<struct wl_resource*> const& output)
+void mf::WindowWlSurfaceRole::set_fullscreen(std::optional<struct wl_resource*> const& output)
 {
     // We must process this request immediately (i.e. don't defer until commit())
     if (auto const scene_surface = weak_scene_surface.lock())
     {
         shell::SurfaceSpecification mods;
         mods.state = scene_surface->state_tracker().with(mir_window_state_fullscreen).active_state();
-        auto const output_id = output ?
-            output_manager->output_id_for(weak_client.value().raw_client(), output.value()) :
-            std::experimental::nullopt;
+        auto const output_id = output_manager->output_id_for(
+            weak_client.value().raw_client(),
+            output.value_or(nullptr));
         if (output_id)
+        {
             mods.output_id = output_id.value();
+        }
         shell->modify_surface(session, scene_surface, mods);
     }
     else
     {
-        params->state = mir_window_state_fullscreen;
-        auto const output_id = output ?
-            output_manager->output_id_for(weak_client.value().raw_client(), output.value()) :
-            std::experimental::nullopt;
+        spec().state = mir_window_state_fullscreen;
+        auto const output_id = output_manager->output_id_for(
+            weak_client.value().raw_client(),
+            output.value_or(nullptr));
         if (output_id)
-            params->output_id = output_id.value();
+        {
+            spec().output_id = output_id.value();
+        }
         create_scene_surface();
     }
 }
 
 void mf::WindowWlSurfaceRole::set_server_side_decorated(bool server_side_decorated)
 {
+    spec().server_side_decorated = server_side_decorated;
     if (weak_scene_surface.lock())
     {
         log_warning("Changing server_side_decorated property after surface created not yet possible");
     }
-    else
-    {
-        params->server_side_decorated = server_side_decorated;
-    }
 }
 
 void mir::frontend::WindowWlSurfaceRole::set_type(MirWindowType type)
 {
-    if (weak_scene_surface.lock())
-    {
-        spec().type = type;
-    }
-    else
-    {
-        params->type = type;
-    }
+    spec().type = type;
 }
 
 void mf::WindowWlSurfaceRole::add_state_now(MirWindowState state)
@@ -316,7 +259,7 @@ void mf::WindowWlSurfaceRole::add_state_now(MirWindowState state)
     }
     else
     {
-        params->state = state;
+        spec().state = state;
         create_scene_surface();
     }
 }
@@ -348,17 +291,24 @@ auto mf::WindowWlSurfaceRole::pending_size() const -> geom::Size
 auto mf::WindowWlSurfaceRole::current_size() const -> geom::Size
 {
     auto size = committed_size.value_or(geom::Size{640, 480});
-    if (surface->buffer_size())
+    if ((!committed_width_set_explicitly || !committed_height_set_explicitly) && surface)
     {
-        if (!committed_width_set_explicitly)
-            size.width = surface->buffer_size().value().width;
-        if (!committed_height_set_explicitly)
-            size.height = surface->buffer_size().value().height;
+        if (auto const buffer_size = surface.value().buffer_size())
+        {
+            if (!committed_width_set_explicitly)
+            {
+                size.width = buffer_size->width;
+            }
+            if (!committed_height_set_explicitly)
+            {
+                size.height = buffer_size->height;
+            }
+        }
     }
     return size;
 }
 
-auto mf::WindowWlSurfaceRole::requested_window_size() const -> std::experimental::optional<geom::Size>
+auto mf::WindowWlSurfaceRole::requested_window_size() const -> std::optional<geom::Size>
 {
     return observer->requested_window_size();
 }
@@ -371,9 +321,14 @@ auto mf::WindowWlSurfaceRole::window_state() const -> MirWindowState
 auto mf::WindowWlSurfaceRole::is_active() const -> bool
 {
     if (auto const scene_surface = weak_scene_surface.lock())
-        return scene_surface->focus_state() == mir_window_focus_state_focused;
+    {
+        auto const state = scene_surface->focus_state();
+        return state != mir_window_focus_state_unfocused;
+    }
     else
+    {
         return false;
+    }
 }
 
 auto mf::WindowWlSurfaceRole::latest_timestamp() const -> std::chrono::nanoseconds
@@ -383,8 +338,12 @@ auto mf::WindowWlSurfaceRole::latest_timestamp() const -> std::chrono::nanosecon
 
 void mf::WindowWlSurfaceRole::commit(WlSurfaceState const& state)
 {
-    surface->commit(state);
+    if (!surface)
+    {
+        return;
+    }
 
+    surface.value().commit(state);
     handle_commit();
 
     auto size = pending_size();
@@ -393,7 +352,7 @@ void mf::WindowWlSurfaceRole::commit(WlSurfaceState const& state)
     if (auto const scene_surface = weak_scene_surface.lock())
     {
         bool const is_mapped = scene_surface->visible();
-        bool const should_be_mapped = static_cast<bool>(surface->buffer_size());
+        bool const should_be_mapped = static_cast<bool>(surface.value().buffer_size());
         if (!is_mapped && should_be_mapped && scene_surface->state() == mir_window_state_hidden)
         {
             spec().state = mir_window_state_restored;
@@ -437,18 +396,20 @@ void mf::WindowWlSurfaceRole::commit(WlSurfaceState const& state)
         committed_width_set_explicitly = true;
     if (pending_explicit_height)
         committed_height_set_explicitly = true;
-    pending_explicit_width = std::experimental::nullopt;
-    pending_explicit_height = std::experimental::nullopt;
+    pending_explicit_width = std::nullopt;
+    pending_explicit_height = std::nullopt;
 }
 
 void mf::WindowWlSurfaceRole::surface_destroyed()
 {
     if (weak_client)
     {
-        // "When a client wants to destroy a wl_surface, they must destroy this 'role object' wl_surface"
-        // NOTE: the wl_shell_surface specification seems contradictory, so this method is overridden in it's implementation
+        // "When a client wants to destroy a wl_surface, they must destroy this 'role object' before the wl_surface"
+        // NOTE: the wl_shell_surface specification seems contradictory, so this method is overridden in its implementation
+        // NOTE: it's also overridden in layer shell, for reasons explained there
         BOOST_THROW_EXCEPTION(std::runtime_error{
-            "wl_surface@" + std::to_string(wl_resource_get_id(surface->resource)) +
+            "wl_surface@" +
+            (surface ? std::to_string(wl_resource_get_id(surface.value().resource)) : "?") +
             " destroyed before associated role"});
     }
     else
@@ -469,29 +430,37 @@ mir::shell::SurfaceSpecification& mf::WindowWlSurfaceRole::spec()
 
 void mf::WindowWlSurfaceRole::create_scene_surface()
 {
-    if (weak_scene_surface.lock())
+    if (weak_scene_surface.lock() || !surface)
         return;
 
-    params->size = pending_size();
-    params->streams = std::vector<shell::StreamSpecification>{};
-    params->input_shape = std::vector<geom::Rectangle>{};
-    surface->populate_surface_data(params->streams.value(), params->input_shape.value(), {});
+    auto& mods = spec();
+    auto const request_size = pending_size();
+    mods.width = request_size.width;
+    mods.height = request_size.height;
+    mods.streams = std::vector<shell::StreamSpecification>{};
+    mods.input_shape = std::vector<geom::Rectangle>{};
+    surface.value().populate_surface_data(mods.streams.value(), mods.input_shape.value(), {});
 
-    auto const scene_surface = shell->create_surface(session, *params, observer);
+    auto const scene_surface = shell->create_surface(session, mods, observer);
     weak_scene_surface = scene_surface;
 
-    if (params->min_width)  committed_min_size.width  = params->min_width.value();
-    if (params->min_height) committed_min_size.height = params->min_height.value();
-    if (params->max_width)  committed_max_size.width  = params->max_width.value();
-    if (params->max_height) committed_max_size.height = params->max_height.value();
+    if (mods.min_width)  committed_min_size.width  = mods.min_width.value();
+    if (mods.min_height) committed_min_size.height = mods.min_height.value();
+    if (mods.max_width)  committed_max_size.width  = mods.max_width.value();
+    if (mods.max_height) committed_max_size.height = mods.max_height.value();
 
     // The shell isn't guaranteed to respect the requested size
     // TODO: make initial updates atomic somehow
     auto const content_size = scene_surface->content_size();
-    if (content_size != params->size)
+    if (content_size != request_size)
+    {
         observer->content_resized_to(scene_surface.get(), content_size);
-    if (is_active())
-        observer->attrib_changed(scene_surface.get(), mir_window_attrib_focus, 1);
+    }
+    auto const focus_state = scene_surface->focus_state();
+    if (focus_state != mir_window_focus_state_unfocused)
+    {
+        observer->attrib_changed(scene_surface.get(), mir_window_attrib_focus, focus_state);
+    }
 
     // Send wl_surface.enter events for every output
     // TODO: send enter/leave when the surface actually enters and leaves outputs
@@ -504,8 +473,11 @@ void mf::WindowWlSurfaceRole::create_scene_surface()
                     weak_client.value().raw_client(),
                     [&](wl_resource* resource)
                     {
-                        surface->send_enter_event(resource);
+                        surface.value().send_enter_event(resource);
                     });
             }
         });
+
+    // Invalidates mods
+    pending_changes.reset();
 }
