@@ -33,7 +33,7 @@ class ClipboardSource;
 
 namespace frontend
 {
-class WlDataDevice : public wayland::DataDevice, public WlSeat::ListenerTracker
+class WlDataDevice : public wayland::DataDevice, public WlSeat::FocusListener
 {
 public:
     WlDataDevice(
@@ -46,20 +46,20 @@ public:
     /// Wayland requests
     /// @{
     void start_drag(
-        std::experimental::optional<struct wl_resource*> const& source, struct wl_resource* origin,
-        std::experimental::optional<struct wl_resource*> const& icon, uint32_t serial) override
+        std::optional<wl_resource*> const& source, wl_resource* origin,
+        std::optional<wl_resource*> const& icon, uint32_t serial) override
     {
         (void)source, (void)origin, (void)icon, (void)serial;
     }
-    void set_selection(std::experimental::optional<struct wl_resource*> const& source, uint32_t serial) override;
+    void set_selection(std::optional<wl_resource*> const& source, uint32_t serial) override;
     /// @}
 
 private:
     class ClipboardObserver;
     class Offer;
 
-    /// Override from WlSeat::ListenerTracker
-    void focus_on(wl_client *client) override;
+    /// Override from WlSeat::FocusListener
+    void focus_on(WlSurface* surface) override;
 
     /// Called by the clipboard observer
     void paste_source_set(std::shared_ptr<scene::ClipboardSource> const& source);
