@@ -52,20 +52,18 @@ class BufferCursorImage : public mg::CursorImage
 {
 public:
     BufferCursorImage(std::shared_ptr<mg::Buffer> buffer, geom::Displacement const& hotspot)
-        : buffer{mrs::as_read_mappable_buffer(std::move(buffer))},
-          mapping{this->buffer->map_readable()},
-          hotspot_(hotspot)
+        : BufferCursorImage(buffer_to_mapping_if_possible(buffer), hotspot)
     {
     }
 
     auto as_argb_8888() const -> void const* override
     {
-        return mapping->data();
+        return data.get();
     }
 
     auto size() const -> geom::Size override
     {
-        return mapping->size();
+        return size_;
     }
 
     auto hotspot() const -> geom::Displacement override
@@ -74,8 +72,29 @@ public:
     }
 
 private:
-    std::shared_ptr<mrs::ReadMappableBuffer> const buffer;
-    std::unique_ptr<mrs::Mapping<unsigned char const>> const mapping;
+    BufferCursorImage(std::unique_ptr<mrs::Mapping<unsigned char const>> mapping, geom::Displacement const& hotspot)
+        : size_{mapping->size()},
+          data{std::make_unique<unsigned char[]>(mapping->len())},
+          hotspot_{hotspot}
+    {
+        ::memcpy(data.get(), mapping->data(), mapping->len());
+    }
+
+    static auto buffer_to_mapping_if_possible(std::shared_ptr<mg::Buffer> const& buffer)
+        -> std::unique_ptr<mrs::Mapping<unsigned char const>>
+    {
+        auto const mappable_buffer = mrs::as_read_mappable_buffer(buffer);
+        if (!mappable_buffer)
+        {
+            BOOST_THROW_EXCEPTION(
+                std::runtime_error{
+                    "Attempt to create cursor from non-CPU-readable buffer. Rendering will be incomplete"});
+        }
+        return mappable_buffer->map_readable();
+    }
+
+    geom::Size const size_;
+    std::unique_ptr<unsigned char[]> const data;
     geom::Displacement const hotspot_;
 };
 
@@ -94,13 +113,37 @@ auto timestamp_of(MirPointerEvent const* event) -> uint32_t
 {
     return mir_input_event_get_wayland_timestamp(mir_pointer_event_input_event(event));
 }
+
+auto wayland_axis_source(MirPointerAxisSource mir_source) -> std::optional<uint32_t>
+{
+    switch (mir_source)
+    {
+    case mir_pointer_axis_source_none:
+        return std::nullopt;
+
+    case mir_pointer_axis_source_wheel:
+        return mw::Pointer::AxisSource::wheel;
+
+    case mir_pointer_axis_source_finger:
+        return mw::Pointer::AxisSource::finger;
+
+    case mir_pointer_axis_source_continuous:
+        return mw::Pointer::AxisSource::continuous;
+
+    case mir_pointer_axis_source_wheel_tilt:
+        return mw::Pointer::AxisSource::wheel_tilt;
+    }
+
+    mir::fatal_error("Invalid MirPointerAxisSource %d", mir_source);
+    return std::nullopt;
+}
 }
 
 struct mf::WlPointer::Cursor
 {
     virtual void apply_to(WlSurface* surface) = 0;
     virtual void set_hotspot(geom::Displacement const& new_hotspot) = 0;
-    virtual auto cursor_surface() const -> std::experimental::optional<WlSurface*> = 0;
+    virtual auto cursor_surface() const -> std::optional<WlSurface*> = 0;
 
     virtual ~Cursor() = default;
     Cursor() = default;
@@ -115,7 +158,7 @@ struct NullCursor : mf::WlPointer::Cursor
 {
     void apply_to(mf::WlSurface*) override {}
     void set_hotspot(geom::Displacement const&) override {};
-    auto cursor_surface() const -> std::experimental::optional<mf::WlSurface*> override { return {}; };
+    auto cursor_surface() const -> std::optional<mf::WlSurface*> override { return {}; };
 };
 }
 
@@ -174,9 +217,9 @@ void mf::WlPointer::leave(std::optional<MirPointerEvent const*> event)
     send_leave_event(
         serial,
         surface_under_cursor.value().raw_resource());
-    current_position = std::experimental::nullopt;
+    current_position = std::nullopt;
     // Don't clear current_buttons, their state can survive leaving and entering surfaces (note we currently have logic
-    // to prevent changing surfaces while buttons are pressed, we wouln't need to clear current_buttons regardless)
+    // to prevent changing surfaces while buttons are pressed, we wouldn't need to clear current_buttons regardless)
     needs_frame = true;
     surface_under_cursor = {};
     destroy_listener_id = {};
@@ -206,8 +249,37 @@ void mf::WlPointer::axis(MirPointerEvent const* event)
 {
     auto const h_scroll = mir_pointer_event_axis_value(event, mir_pointer_axis_hscroll);
     auto const v_scroll = mir_pointer_event_axis_value(event, mir_pointer_axis_vscroll);
+    auto const h_scroll_stop = mir_pointer_event_axis_stop(event, mir_pointer_axis_hscroll);
+    auto const v_scroll_stop = mir_pointer_event_axis_stop(event, mir_pointer_axis_vscroll);
+    auto const h_scroll_discrete = mir_pointer_event_axis_value(event, mir_pointer_axis_hscroll_discrete);
+    auto const v_scroll_discrete = mir_pointer_event_axis_value(event, mir_pointer_axis_vscroll_discrete);
+    auto const axis_source = wayland_axis_source(mir_pointer_event_axis_source(event));
 
-    if (h_scroll)
+    // Don't send an axis source unless we have one and we're also sending some sort of axis event.
+    if (axis_source &&
+        version_supports_axis_source() &&
+        (h_scroll || v_scroll || h_scroll_stop || v_scroll_stop || h_scroll_discrete || v_scroll_discrete))
+    {
+        send_axis_source_event(axis_source.value());
+        needs_frame = true;
+    }
+
+    if (h_scroll_discrete && version_supports_axis_discrete())
+    {
+        send_axis_discrete_event(Axis::horizontal_scroll, h_scroll_discrete);
+        needs_frame = true;
+    }
+
+    if (v_scroll_discrete && version_supports_axis_discrete())
+    {
+        send_axis_discrete_event(Axis::vertical_scroll, v_scroll_discrete);
+        needs_frame = true;
+    }
+
+    // If we sent discrete scroll events, we're required to also send corresponding non-discrete ones (even if their
+    // values are 0 for some reason)
+
+    if (h_scroll || h_scroll_discrete)
     {
         send_axis_event(
             timestamp_of(event),
@@ -216,7 +288,7 @@ void mf::WlPointer::axis(MirPointerEvent const* event)
         needs_frame = true;
     }
 
-    if (v_scroll)
+    if (v_scroll || v_scroll_discrete)
     {
         send_axis_event(
             timestamp_of(event),
@@ -224,6 +296,18 @@ void mf::WlPointer::axis(MirPointerEvent const* event)
             v_scroll);
         needs_frame = true;
     }
+
+    if (h_scroll_stop && version_supports_axis_stop())
+    {
+        send_axis_stop_event(timestamp_of(event), Axis::horizontal_scroll);
+        needs_frame = true;
+    }
+
+    if (v_scroll_stop && version_supports_axis_stop())
+    {
+        send_axis_stop_event(timestamp_of(event), Axis::vertical_scroll);
+        needs_frame = true;
+    }
 }
 
 void mf::WlPointer::enter_or_motion(MirPointerEvent const* event, WlSurface& root_surface)
@@ -265,10 +349,10 @@ void mf::WlPointer::enter_or_motion(MirPointerEvent const* event, WlSurface& roo
         needs_frame = true;
         destroy_listener_id = target_surface->add_destroy_listener(
             [this]()
-            {
+                {
                 leave(std::nullopt);
                 maybe_frame();
-            });
+                });
         surface_under_cursor = mw::make_weak(target_surface);
     }
     else if (position_on_target != current_position)
@@ -321,23 +405,48 @@ void mf::WlPointer::maybe_frame()
 
 namespace
 {
+struct CursorSurfaceRole : mf::NullWlSurfaceRole
+{
+    mw::Weak<mf::WlSurface> const surface;
+    mf::CommitHandler* const commit_handler;
+    explicit CursorSurfaceRole(mf::WlSurface* surface, mf::CommitHandler* commit_handler) :
+        NullWlSurfaceRole(surface),
+        surface{surface},
+        commit_handler{commit_handler} {}
+
+    ~CursorSurfaceRole()
+    {
+        if (surface)
+        {
+            surface.value().clear_role();
+        }
+    }
+
+    void commit(mir::frontend::WlSurfaceState const& state) override
+    {
+        NullWlSurfaceRole::commit(state);
+        commit_handler->on_commit(&surface.value());
+    }
+};
+
 struct WlSurfaceCursor : mf::WlPointer::Cursor
 {
     WlSurfaceCursor(
         mf::WlSurface* surface,
-        geom::Displacement hotspot);
+        geom::Displacement hotspot,
+        mf::CommitHandler* commit_handler);
     ~WlSurfaceCursor();
 
     void apply_to(mf::WlSurface* surface) override;
     void set_hotspot(geom::Displacement const& new_hotspot) override;
-    auto cursor_surface() const -> std::experimental::optional<mf::WlSurface*> override;
+    auto cursor_surface() const -> std::optional<mf::WlSurface*> override;
 
 private:
     void apply_latest_buffer();
 
     mw::Weak<mf::WlSurface> const surface;
     std::shared_ptr<mc::BufferStream> const stream;
-    mf::NullWlSurfaceRole surface_role; // Used only to assert unique ownership
+    CursorSurfaceRole surface_role;
 
     std::weak_ptr<ms::Surface> surface_under_cursor;
     geom::Displacement hotspot;
@@ -345,36 +454,43 @@ private:
 
 struct WlHiddenCursor : mf::WlPointer::Cursor
 {
+    WlHiddenCursor(
+        mf::WlSurface* surface,
+        mf::CommitHandler* commit_handler);
     void apply_to(mf::WlSurface* surface) override;
     void set_hotspot(geom::Displacement const&) override {};
-    auto cursor_surface() const -> std::experimental::optional<mf::WlSurface*> override { return {}; };
+    auto cursor_surface() const -> std::optional<mf::WlSurface*> override { return {}; };
+
+private:
+    CursorSurfaceRole surface_role;
 };
 }
 
 void mf::WlPointer::set_cursor(
     uint32_t serial,
-    std::experimental::optional<wl_resource*> const& surface,
+    std::optional<wl_resource*> const& surface,
     int32_t hotspot_x, int32_t hotspot_y)
 {
+    // We need an explicit conversion before calling make_unique
+    // (the compiler should elide this variable)
+    CommitHandler* const commit_handler = this;
+
     if (surface)
     {
         auto const wl_surface = WlSurface::from(*surface);
-        geom::Displacement const cursor_hotspot{hotspot_x, hotspot_y};
-        if (wl_surface == cursor->cursor_surface())
-        {
-            cursor->set_hotspot(cursor_hotspot);
-        }
-        else
+        cursor_hotspot = {hotspot_x, hotspot_y};
+        if (!cursor->cursor_surface() || wl_surface != *cursor->cursor_surface())
         {
             cursor.reset(); // clean up old cursor before creating new one
-            cursor = std::make_unique<WlSurfaceCursor>(wl_surface, cursor_hotspot);
+            cursor = std::make_unique<WlSurfaceCursor>(wl_surface, cursor_hotspot, commit_handler);
             if (surface_under_cursor)
                 cursor->apply_to(&surface_under_cursor.value());
         }
+        // If surface is unchanged hotspot will be applied on next commit
     }
     else
     {
-        cursor = std::make_unique<WlHiddenCursor>();
+        cursor = std::make_unique<WlHiddenCursor>(nullptr, commit_handler);
         if (surface_under_cursor)
             cursor->apply_to(&surface_under_cursor.value());
     }
@@ -382,10 +498,40 @@ void mf::WlPointer::set_cursor(
     (void)serial;
 }
 
-WlSurfaceCursor::WlSurfaceCursor(mf::WlSurface* surface, geom::Displacement hotspot)
+void mf::WlPointer::on_commit(WlSurface* surface)
+{
+    // We need an explicit conversion before calling make_unique
+    // (the compiler should elide this variable)
+    CommitHandler* const commit_handler = this;
+
+    if (!surface->buffer_size())
+    {
+        // No buffer: We should be unmapping the cursor
+
+        cursor = std::make_unique<WlHiddenCursor>(surface, commit_handler);
+        if (surface_under_cursor)
+            cursor->apply_to(&surface_under_cursor.value());
+    }
+    else
+    {
+        if (cursor->cursor_surface() && surface == *cursor->cursor_surface())
+        {
+            cursor->set_hotspot(cursor_hotspot);
+        }
+        else
+        {
+            cursor.reset(); // clean up old cursor before creating new one
+            cursor = std::make_unique<WlSurfaceCursor>(surface, cursor_hotspot, commit_handler);
+            if (surface_under_cursor)
+                cursor->apply_to(&surface_under_cursor.value());
+        }
+    }
+}
+
+WlSurfaceCursor::WlSurfaceCursor(mf::WlSurface* surface, geom::Displacement hotspot, mf::CommitHandler* commit_handler)
     : surface{surface},
       stream{surface->stream},
-      surface_role{surface},
+      surface_role{surface, commit_handler},
       hotspot{hotspot}
 {
     surface->set_role(&surface_role);
@@ -427,7 +573,7 @@ void WlSurfaceCursor::set_hotspot(geom::Displacement const& new_hotspot)
     apply_latest_buffer();
 }
 
-auto WlSurfaceCursor::cursor_surface() const -> std::experimental::optional<mf::WlSurface*>
+auto WlSurfaceCursor::cursor_surface() const -> std::optional<mf::WlSurface*>
 {
     if (surface)
     {
@@ -457,6 +603,11 @@ void WlSurfaceCursor::apply_latest_buffer()
     }
 }
 
+WlHiddenCursor::WlHiddenCursor(mf::WlSurface* surface, mf::CommitHandler* commit_handler) :
+    surface_role{surface, std::move(commit_handler)}
+{
+}
+
 void WlHiddenCursor::apply_to(mf::WlSurface* surface)
 {
     if (auto scene_surface = surface->scene_surface())
