@@ -45,7 +45,19 @@ namespace frontend
 {
 class WlSurface;
 
-class WlPointer : public wayland::Pointer
+class CommitHandler
+{
+public:
+    virtual void on_commit(WlSurface* surface) = 0;
+
+protected:
+    CommitHandler() = default;
+    ~CommitHandler() = default;
+    CommitHandler(CommitHandler const&) = delete;
+    CommitHandler& operator=(CommitHandler const&) = delete;
+};
+
+class WlPointer : public wayland::Pointer, private CommitHandler
 {
 public:
 
@@ -74,12 +86,14 @@ private:
     void relative_motion(MirPointerEvent const* event);
     /// Sends a frame event only if needed, leaves needs_frame false
     void maybe_frame();
+    /// The cursor surface has committed
+    void on_commit(WlSurface* surface) override;
 
     /// Wayland request handlers
     ///@{
     void set_cursor(
         uint32_t serial,
-        std::experimental::optional<wl_resource*> const& surface,
+        std::optional<wl_resource*> const& surface,
         int32_t hotspot_x,
         int32_t hotspot_y) override;
     ///@}
@@ -88,9 +102,10 @@ private:
     wayland::DestroyListenerId destroy_listener_id; ///< ID of this pointer's destroy listener on surface_under_cursor
     bool needs_frame{false};
     MirPointerButtons current_buttons{0};
-    std::experimental::optional<std::pair<float, float>> current_position;
+    std::optional<std::pair<float, float>> current_position;
     std::unique_ptr<Cursor> cursor;
     wayland::Weak<wayland::RelativePointerV1> relative_pointer;
+    geometry::Displacement cursor_hotspot;
 };
 
 }
