@@ -26,17 +26,13 @@
 #include "wl_pointer.h"
 #include "wl_touch.h"
 
-#include "mir/client/event.h"
-
 #include "mir/input/input_device_observer.h"
 #include "mir/input/input_device_hub.h"
-#include "mir/input/seat.h"
 #include "mir/input/device.h"
-#include "mir/input/keymap.h"
+#include "mir/input/parameter_keymap.h"
 #include "mir/input/mir_keyboard_config.h"
 
 #include <mutex>
-#include <unordered_set>
 #include <algorithm>
 
 namespace mf = mir::frontend;
@@ -85,10 +81,11 @@ class mf::WlSeat::ConfigObserver : public mi::InputDeviceObserver
 {
 public:
     ConfigObserver(
-        mi::Keymap const& keymap,
-        std::function<void(mi::Keymap const&)> const& on_keymap_commit)
+        std::shared_ptr<mi::Keymap> const& keymap,
+        std::function<void(std::shared_ptr<mi::Keymap> const&)> const& on_keymap_commit)
         : current_keymap{keymap},
-            on_keymap_commit{on_keymap_commit}
+          pending_keymap{nullptr},
+          on_keymap_commit{on_keymap_commit}
     {
     }
 
@@ -98,19 +95,16 @@ public:
     void changes_complete() override;
 
 private:
-    mi::Keymap const& current_keymap;
-    mi::Keymap pending_keymap;
-    std::function<void(mi::Keymap const&)> const on_keymap_commit;
+    std::shared_ptr<mi::Keymap> current_keymap;
+    std::shared_ptr<mi::Keymap> pending_keymap;
+    std::function<void(std::shared_ptr<mi::Keymap> const&)> const on_keymap_commit;
 };
 
 void mf::WlSeat::ConfigObserver::device_added(std::shared_ptr<input::Device> const& device)
 {
     if (auto keyboard_config = device->keyboard_configuration())
     {
-        if (current_keymap != keyboard_config.value().device_keymap())
-        {
-            pending_keymap = keyboard_config.value().device_keymap();
-        }
+        pending_keymap = keyboard_config.value().device_keymap();
     }
 }
 
@@ -118,10 +112,7 @@ void mf::WlSeat::ConfigObserver::device_changed(std::shared_ptr<input::Device> c
 {
     if (auto keyboard_config = device->keyboard_configuration())
     {
-        if (current_keymap != keyboard_config.value().device_keymap())
-        {
-            pending_keymap = keyboard_config.value().device_keymap();
-        }
+        pending_keymap = keyboard_config.value().device_keymap();
     }
 }
 
@@ -131,18 +122,23 @@ void mf::WlSeat::ConfigObserver::device_removed(std::shared_ptr<input::Device> c
 
 void mf::WlSeat::ConfigObserver::changes_complete()
 {
-    on_keymap_commit(pending_keymap);
+    if (pending_keymap && !pending_keymap->matches(*current_keymap))
+    {
+        current_keymap = std::move(pending_keymap);
+        on_keymap_commit(current_keymap);
+    }
+
+    pending_keymap.reset();
 }
 
 class mf::WlSeat::Instance : public wayland::Seat
 {
 public:
-    Instance(wl_resource* new_resource, mf::WlSeat* seat, bool enable_key_repeat);
+    Instance(wl_resource* new_resource, mf::WlSeat* seat);
 
     mf::WlSeat* const seat;
 
 private:
-    bool const enable_key_repeat;
     void get_pointer(wl_resource* new_pointer) override;
     void get_keyboard(wl_resource* new_keyboard) override;
     void get_touch(wl_resource* new_touch) override;
@@ -150,37 +146,44 @@ private:
 
 mf::WlSeat::WlSeat(
     wl_display* display,
+    std::shared_ptr<time::Clock> const& clock,
     std::shared_ptr<mi::InputDeviceHub> const& input_hub,
     std::shared_ptr<mi::Seat> const& seat,
     bool enable_key_repeat)
     :   Global(display, Version<6>()),
-        keymap{std::make_unique<input::Keymap>()},
+        keymap{std::make_shared<input::ParameterKeymap>()},
         config_observer{
             std::make_shared<ConfigObserver>(
-                *keymap,
-                [this](mi::Keymap const& new_keymap)
+                keymap,
+                [this](std::shared_ptr<mi::Keymap> const& new_keymap)
                 {
-                    *keymap = new_keymap;
+                    keymap = new_keymap;
                 })},
+        focus_listeners{std::make_shared<ListenerList<FocusListener>>()},
         pointer_listeners{std::make_shared<ListenerList<WlPointer>>()},
         keyboard_listeners{std::make_shared<ListenerList<WlKeyboard>>()},
         touch_listeners{std::make_shared<ListenerList<WlTouch>>()},
+        clock{clock},
         input_hub{input_hub},
         seat{seat},
         enable_key_repeat{enable_key_repeat}
 {
     input_hub->add_observer(config_observer);
-    add_focus_listener(&focus);
 }
 
 mf::WlSeat::~WlSeat()
 {
     input_hub->remove_observer(config_observer);
+    if (focused_surface)
+    {
+        focused_surface.value().remove_destroy_listener(focused_surface_destroy_listener_id);
+    }
 }
 
-auto mf::WlSeat::from(struct wl_resource* seat) -> WlSeat*
+auto mf::WlSeat::from(struct wl_resource* resource) -> WlSeat*
 {
-    return static_cast<mf::WlSeat::Instance*>(wayland::Seat::from(seat))->seat;
+    auto const instance = static_cast<mf::WlSeat::Instance*>(wayland::Seat::from(resource));
+    return instance ? instance->seat : nullptr;
 }
 
 void mf::WlSeat::for_each_listener(wl_client* client, std::function<void(WlPointer*)> func)
@@ -198,25 +201,67 @@ void mf::WlSeat::for_each_listener(wl_client* client, std::function<void(WlTouch
     touch_listeners->for_each(client, func);
 }
 
-void mf::WlSeat::notify_focus(wl_client *focus)
+auto mf::WlSeat::make_keyboard_helper(KeyboardCallbacks* callbacks) -> std::unique_ptr<KeyboardHelper>
 {
-    if (focus != focused_client)
+    return std::make_unique<KeyboardHelper>(callbacks, keymap, seat, enable_key_repeat);
+}
+
+void mf::WlSeat::notify_focus(WlSurface& surface, bool has_focus)
+{
+    if (has_focus && !focused_surface.is(surface))
     {
-        focused_client = focus;
-        for (auto const listener : focus_listeners)
-            listener->focus_on(focus);
+        // give focus to any surface other than the current one
+        set_focus_to(&surface);
+    }
+    else if (!has_focus && focused_surface.is(surface))
+    {
+        // only take focus away if the newly unfocused surface is the current one
+        set_focus_to(nullptr);
     }
 }
 
 void mf::WlSeat::bind(wl_resource* new_wl_seat)
 {
-    new Instance{new_wl_seat, this, enable_key_repeat};
+    new Instance{new_wl_seat, this};
 }
 
-mf::WlSeat::Instance::Instance(wl_resource* new_resource, mf::WlSeat* seat, bool enable_key_repeat)
+void mf::WlSeat::set_focus_to(WlSurface* new_surface)
+{
+    auto const new_client = new_surface ? new_surface->client : nullptr;
+    if (new_client != focused_client)
+    {
+        focus_listeners->for_each(focused_client, [](FocusListener* listener)
+            {
+                listener->focus_on(nullptr);
+            });
+    }
+    if (focused_surface)
+    {
+        focused_surface.value().remove_destroy_listener(focused_surface_destroy_listener_id);
+    }
+    focused_client = new_client;
+    focused_surface = mw::make_weak(new_surface);
+    if (new_surface)
+    {
+        // This listener will be removed when either the focus changes or the seat is destroyed
+        focused_surface_destroy_listener_id = new_surface->add_destroy_listener([this]()
+            {
+                set_focus_to(nullptr);
+            });
+    }
+    else
+    {
+        focused_surface_destroy_listener_id = {};
+    }
+    focus_listeners->for_each(new_client, [&](FocusListener* listener)
+        {
+            listener->focus_on(new_surface);
+        });
+}
+
+mf::WlSeat::Instance::Instance(wl_resource* new_resource, mf::WlSeat* seat)
     : mw::Seat(new_resource, Version<6>()),
-      seat{seat},
-      enable_key_repeat{enable_key_repeat}
+      seat{seat}
 {
     // TODO: Read the actual capabilities. Do we have a keyboard? Mouse? Touch?
     send_capabilities_event(Capability::pointer | Capability::keyboard | Capability::touch);
@@ -237,37 +282,7 @@ void mf::WlSeat::Instance::get_pointer(wl_resource* new_pointer)
 
 void mf::WlSeat::Instance::get_keyboard(wl_resource* new_keyboard)
 {
-    auto const keyboard = new WlKeyboard{
-        new_keyboard,
-        *seat->keymap,
-        [seat = seat->seat]()
-        {
-            std::unordered_set<uint32_t> pressed_keys;
-
-            auto const ev = seat->create_device_state();
-            auto const state_event = mir_event_get_input_device_state_event(ev.get());
-            for (
-                auto dev = 0u;
-                dev < mir_input_device_state_event_device_count(state_event);
-                ++dev)
-            {
-                for (
-                    auto idx = 0u;
-                    idx < mir_input_device_state_event_device_pressed_keys_count(state_event, dev);
-                    ++idx)
-                {
-                    pressed_keys.insert(
-                        mir_input_device_state_event_device_pressed_keys_for_index(
-                            state_event,
-                            dev,
-                            idx));
-                }
-            }
-
-            return std::vector<uint32_t>{pressed_keys.begin(), pressed_keys.end()};
-        },
-        enable_key_repeat
-    };
+    auto const keyboard = new WlKeyboard{new_keyboard, *seat};
 
     seat->keyboard_listeners->register_listener(client, keyboard);
     keyboard->add_destroy_listener(
@@ -279,7 +294,7 @@ void mf::WlSeat::Instance::get_keyboard(wl_resource* new_keyboard)
 
 void mf::WlSeat::Instance::get_touch(wl_resource* new_touch)
 {
-    auto const touch = new WlTouch{new_touch};
+    auto const touch = new WlTouch{new_touch, seat->clock};
     seat->touch_listeners->register_listener(client, touch);
     touch->add_destroy_listener(
         [listeners = seat->touch_listeners, listener = touch, client = client]()
@@ -288,23 +303,20 @@ void mf::WlSeat::Instance::get_touch(wl_resource* new_touch)
         });
 }
 
-auto mf::WlSeat::current_focused_client() const -> wl_client*
+void mf::WlSeat::add_focus_listener(wl_client* client, FocusListener* listener)
 {
-    return focused_client;
+    focus_listeners->register_listener(client, listener);
+    if (focused_client == client)
+    {
+        listener->focus_on(mw::as_nullable_ptr(focused_surface));
+    }
+    else
+    {
+        listener->focus_on(nullptr);
+    }
 }
 
-void mf::WlSeat::add_focus_listener(ListenerTracker* listener)
+void mf::WlSeat::remove_focus_listener(wl_client* client, FocusListener* listener)
 {
-    focus_listeners.push_back(listener);
-}
-
-void mf::WlSeat::remove_focus_listener(ListenerTracker* listener)
-{
-    focus_listeners.erase(remove(begin(focus_listeners), end(focus_listeners), listener), end(focus_listeners));
-}
-
-void mf::WlSeat::server_restart()
-{
-    if (focus.client)
-        for_each_listener(focus.client, [](WlKeyboard* keyboard) { keyboard->resync_keyboard(); });
+    focus_listeners->unregister_listener(client, listener);
 }
