@@ -38,7 +38,6 @@
 #include "mir/shell/surface_specification.h"
 #include "mir/log.h"
 
-#include <algorithm>
 #include <chrono>
 #include <boost/throw_exception.hpp>
 #include <wayland-server-protocol.h>
@@ -122,12 +121,12 @@ bool mf::WlSurface::synchronized() const
     return role->synchronized();
 }
 
-auto mf::WlSurface::subsurface_at(geom::Point point) -> std::experimental::optional<WlSurface*>
+auto mf::WlSurface::subsurface_at(geom::Point point) -> std::optional<WlSurface*>
 {
     if (!buffer_size_)
     {
         // surface not mapped
-        return std::experimental::nullopt;
+        return std::nullopt;
     }
     point = point - offset_;
     // loop backwards so the first subsurface we find that accepts the input is the topmost one
@@ -142,10 +141,10 @@ auto mf::WlSurface::subsurface_at(geom::Point point) -> std::experimental::optio
         if (rect.intersection_with(surface_rect).contains(point))
             return this;
     }
-    return std::experimental::nullopt;
+    return std::nullopt;
 }
 
-auto mf::WlSurface::scene_surface() const -> std::experimental::optional<std::shared_ptr<scene::Surface>>
+auto mf::WlSurface::scene_surface() const -> std::optional<std::shared_ptr<scene::Surface>>
 {
     return role->scene_surface();
 }
@@ -162,7 +161,7 @@ void mf::WlSurface::clear_role()
     role = &null_role;
 }
 
-void mf::WlSurface::set_pending_offset(std::experimental::optional<geom::Displacement> const& offset)
+void mf::WlSurface::set_pending_offset(std::optional<geom::Displacement> const& offset)
 {
     pending.offset = offset;
 }
@@ -251,7 +250,7 @@ void mf::WlSurface::send_frame_callbacks()
     frame_callbacks.clear();
 }
 
-void mf::WlSurface::attach(std::experimental::optional<wl_resource*> const& buffer, int32_t x, int32_t y)
+void mf::WlSurface::attach(std::optional<wl_resource*> const& buffer, int32_t x, int32_t y)
 {
     if (x != 0 || y != 0)
     {
@@ -285,13 +284,13 @@ void mf::WlSurface::frame(wl_resource* new_callback)
     pending.frame_callbacks.push_back(wayland::make_weak(callback));
 }
 
-void mf::WlSurface::set_opaque_region(std::experimental::optional<wl_resource*> const& region)
+void mf::WlSurface::set_opaque_region(std::optional<wl_resource*> const& region)
 {
     (void)region;
     // This isn't essential, but could enable optimizations
 }
 
-void mf::WlSurface::set_input_region(std::experimental::optional<wl_resource*> const& region)
+void mf::WlSurface::set_input_region(std::optional<wl_resource*> const& region)
 {
     if (region)
     {
@@ -370,7 +369,7 @@ void mf::WlSurface::commit(WlSurfaceState const& state)
         if (buffer == nullptr)
         {
             // TODO: unmap surface, and unmap all subsurfaces
-            buffer_size_ = std::experimental::nullopt;
+            buffer_size_ = std::nullopt;
             send_frame_callbacks();
         }
         else
@@ -428,7 +427,7 @@ void mf::WlSurface::commit(WlSurfaceState const& state)
             stream->submit_buffer(mir_buffer);
             auto const new_buffer_size = stream->stream_size();
 
-            if (!input_shape && std::experimental::make_optional(new_buffer_size) != buffer_size_)
+            if (!input_shape && std::make_optional(new_buffer_size) != buffer_size_)
             {
                 state.invalidate_surface_data(); // input shape needs to be recalculated for the new size
             }
@@ -450,13 +449,13 @@ void mf::WlSurface::commit(WlSurfaceState const& state)
 void mf::WlSurface::commit()
 {
     if (pending.offset && *pending.offset == offset_)
-        pending.offset = std::experimental::nullopt;
+        pending.offset = std::nullopt;
 
     // The same input shape could be represented by the same rectangles in a different order, or even
     // different rectangles. We don't check for that, however, because it would only cause an unnecessary
     // update and not do any real harm. Checking for identical vectors should cover most cases.
     if (pending.input_shape && *pending.input_shape == input_shape)
-        pending.input_shape = std::experimental::nullopt;
+        pending.input_shape = std::nullopt;
 
     // order is important
     auto const state = std::move(pending);
@@ -493,9 +492,9 @@ mf::NullWlSurfaceRole::NullWlSurfaceRole(WlSurface* surface) :
 {
 }
 
-auto mf::NullWlSurfaceRole::scene_surface() const -> std::experimental::optional<std::shared_ptr<scene::Surface>>
+auto mf::NullWlSurfaceRole::scene_surface() const -> std::optional<std::shared_ptr<scene::Surface>>
 {
-    return std::experimental::nullopt;
+    return std::nullopt;
 }
 void mf::NullWlSurfaceRole::refresh_surface_data_now() {}
 void mf::NullWlSurfaceRole::commit(WlSurfaceState const& state) { surface->commit(state); }
