@@ -19,6 +19,7 @@
 #ifndef MIR_FRONTEND_XDG_OUTPUT_V1_H
 #define MIR_FRONTEND_XDG_OUTPUT_V1_H
 
+#include "xdg-output-unstable-v1_wrapper.h"
 #include <memory>
 
 struct wl_display;
@@ -27,11 +28,10 @@ namespace mir
 {
 namespace frontend
 {
-class XdgOutputManagerV1;
 class OutputManager;
 
 auto create_xdg_output_manager_v1(struct wl_display* display, OutputManager* const output_manager)
-    -> std::shared_ptr<XdgOutputManagerV1>;
+    -> std::shared_ptr<wayland::XdgOutputManagerV1::Global>;
 
 }
 }
