@@ -30,7 +30,7 @@ namespace ms = mir::scene;
 mf::XWaylandClientManager::Session::Session(XWaylandClientManager* manager, pid_t client_pid)
     : manager{manager},
       client_pid{client_pid},
-      _session{manager->shell->open_session(client_pid, "", std::make_shared<NullEventSink>())}
+      _session{manager->shell->open_session(client_pid, Fd{Fd::invalid}, "", std::make_shared<NullEventSink>())}
 {
 }
 
