@@ -25,7 +25,7 @@
 #include <mutex>
 #include <chrono>
 #include <functional>
-#include <experimental/optional>
+#include <optional>
 
 struct wl_client;
 
@@ -58,13 +58,6 @@ public:
     void content_resized_to(scene::Surface const*, geometry::Size const& content_size) override;
     void moved_to(scene::Surface const*, geometry::Point const& top_left) override;
     void client_surface_close_requested(scene::Surface const*) override;
-    void keymap_changed(
-        scene::Surface const*,
-        MirInputDeviceId id,
-        std::string const& model,
-        std::string const& layout,
-        std::string const& variant,
-        std::string const& options) override;
     void input_consumed(scene::Surface const*, MirEvent const* event) override;
     ///@}
 
@@ -81,7 +74,7 @@ private:
 
         // Innter value should only be used from the Wayland thread and while the mutex is locked
         // Can be nullified from any thread as long as the mutex is locked
-        std::experimental::optional<std::unique_ptr<WaylandInputDispatcher>> dispatcher;
+        std::optional<std::unique_ptr<WaylandInputDispatcher>> dispatcher;
     };
 
     XWaylandSurfaceObserverSurface* const wm_surface;
