@@ -35,9 +35,6 @@
 #include "mir/scene/null_observer.h"
 
 #include <cstring>
-#include <poll.h>
-#include <sys/socket.h>
-#include <unistd.h>
 #include <boost/throw_exception.hpp>
 
 namespace mf = mir::frontend;
@@ -298,18 +295,18 @@ void mf::XWaylandWM::handle_events()
 }
 
 auto mf::XWaylandWM::get_wm_surface(
-    xcb_window_t xcb_window) -> std::experimental::optional<std::shared_ptr<XWaylandSurface>>
+    xcb_window_t xcb_window) -> std::optional<std::shared_ptr<XWaylandSurface>>
 {
     std::lock_guard<std::mutex> lock{mutex};
 
     auto const surface = surfaces.find(xcb_window);
     if (surface == surfaces.end())
-        return std::experimental::nullopt;
+        return std::nullopt;
     else
         return surface->second;
 }
 
-auto mf::XWaylandWM::get_focused_window() -> std::experimental::optional<xcb_window_t>
+auto mf::XWaylandWM::get_focused_window() -> std::optional<xcb_window_t>
 {
     std::lock_guard<std::mutex> lock{mutex};
     return focused_window;
@@ -336,7 +333,7 @@ void mf::XWaylandWM::set_focus(xcb_window_t xcb_window, bool should_be_focused)
         if (should_be_focused)
             focused_window = xcb_window;
         else
-            focused_window = std::experimental::nullopt;
+            focused_window = std::nullopt;
     }
 
     if (should_be_focused)
@@ -436,8 +433,8 @@ void mf::XWaylandWM::restack_surfaces()
 
             connection->configure_window(
                 window,
-                std::experimental::nullopt,
-                std::experimental::nullopt,
+                std::nullopt,
+                std::nullopt,
                 window_below,
                 XCB_STACK_MODE_ABOVE);
         }
@@ -669,7 +666,7 @@ void mf::XWaylandWM::handle_property_notify(xcb_property_notify_event_t *event)
         clipboard_provider->property_deleted_event(event->window, event->atom);
     }
 
-    // Inform the clipboard source, in case it's new data for an incremental send
+    // Inform the clipboard source, in case its new data for an incremental send
     if (event->state == XCB_PROPERTY_NEW_VALUE && connection->is_ours(event->window))
     {
         clipboard_source->property_notify_event(event->window, event->atom);
