@@ -23,13 +23,19 @@
 
 namespace mir
 {
+class Executor;
 namespace shell
 {
 class Shell;
 }
+namespace scene
+{
+class Clipboard;
+}
 namespace frontend
 {
 class OutputManager;
+class SurfaceStack;
 class WlSeat;
 class WlSurface;
 class XWaylandSurface;
@@ -38,13 +44,24 @@ class XWaylandWMShell
 {
 public:
     XWaylandWMShell(
+        std::shared_ptr<Executor> const& wayland_executor,
         std::shared_ptr<shell::Shell> const& shell,
+        std::shared_ptr<scene::Clipboard> const& clipboard,
         WlSeat& seat,
-        OutputManager* const output_manager);
+        std::shared_ptr<SurfaceStack> const& surface_stack)
+        : wayland_executor{wayland_executor},
+          shell{shell},
+          clipboard{clipboard},
+          seat{seat},
+          surface_stack{surface_stack}
+    {
+    }
 
+    std::shared_ptr<Executor> const wayland_executor;
     std::shared_ptr<shell::Shell> const shell;
+    std::shared_ptr<scene::Clipboard> const clipboard;
     WlSeat& seat;
-    OutputManager* const output_manager;
+    std::shared_ptr<SurfaceStack> const surface_stack;
 };
 
 } /* frontend*/
