@@ -18,7 +18,6 @@
 
 #include "mir/default_server_configuration.h"
 #include "mir/options/configuration.h"
-#include "mir/options/option.h"
 
 #include "mir/graphics/default_display_configuration_policy.h"
 #include "mir/graphics/graphic_buffer_allocator.h"
@@ -37,20 +36,14 @@
 #include "mir/abnormal_exit.h"
 #include "mir/emergency_cleanup.h"
 #include "mir/log.h"
-#include "mir/main_loop.h"
 #include "mir/report_exception.h"
 
-#include "mir_toolkit/common.h"
-
 #include <boost/throw_exception.hpp>
 
-#include <map>
 #include <sstream>
-#include <unordered_set>
 
 namespace mg = mir::graphics;
 namespace ml = mir::logging;
-namespace mgn = mir::graphics::nested;
 
 std::shared_ptr<mg::DisplayConfigurationPolicy>
 mir::DefaultServerConfiguration::the_display_configuration_policy()
@@ -214,8 +207,7 @@ auto mir::DefaultServerConfiguration::the_display_platforms() -> std::vector<std
                         the_options(),
                         the_emergency_cleanup(),
                         the_console_services(),
-                        the_display_report(),
-                        the_logger()));
+                        the_display_report()));
                 // Add this module to the list searched by the input stack later
                 // TODO: Come up with a more principled solution for combined input/rendering/output platforms
                 platform_libraries.push_back(platform);
@@ -305,8 +297,7 @@ auto mir::DefaultServerConfiguration::the_rendering_platforms() ->
                 rendering_platforms.push_back(
                     create_rendering_platform(
                         *the_options(),
-                        *the_emergency_cleanup(),
-                        the_logger()));
+                        *the_emergency_cleanup()));
                 // Add this module to the list searched by the input stack later
                 // TODO: Come up with a more principled solution for combined input/rendering/output platforms
                 platform_libraries.push_back(platform);
