@@ -22,10 +22,7 @@
 #include "mir/input/input_sink.h"
 #include "mir/graphics/display_configuration_observer.h"
 #include "mir/graphics/display_configuration.h"
-#include "mir/graphics/transformation.h"
 #include "mir/geometry/rectangle.h"
-#include "mir/geometry/point.h"
-#include "mir/geometry/size.h"
 #include "mir_toolkit/common.h"
 
 #include <algorithm>
