@@ -19,6 +19,7 @@
 #include "mir/default_server_configuration.h"
 
 #include "key_repeat_dispatcher.h"
+#include "keyboard_resync_dispatcher.h"
 #include "event_filter_chain_dispatcher.h"
 #include "config_changer.h"
 #include "cursor_controller.h"
@@ -32,6 +33,7 @@
 #include "surface_input_dispatcher.h"
 #include "basic_seat.h"
 #include "seat_observer_multiplexer.h"
+#include "idle_poking_dispatcher.h"
 
 #include "mir/input/touch_visualizer.h"
 #include "mir/input/input_probe.h"
@@ -58,7 +60,6 @@ namespace mi = mir::input;
 namespace mr = mir::report;
 namespace ms = mir::scene;
 namespace mg = mir::graphics;
-namespace mgn = mg::nested;
 namespace msh = mir::shell;
 namespace md = mir::dispatch;
 
@@ -140,8 +141,15 @@ mir::DefaultServerConfiguration::the_input_dispatcher()
             // lp:1675357: Disable generation of key repeat events on nested servers
             auto enable_repeat = options->get<bool>(options::enable_key_repeat_opt);
 
+            auto const idle_poking_dispatcher = std::make_shared<mi::IdlePokingDispatcher>(
+                the_event_filter_chain_dispatcher(),
+                the_idle_hub());
+
+            auto const keyboard_resync_dispatcher =
+                std::make_shared<mi::KeyboardResyncDispatcher>(idle_poking_dispatcher);
+
             return std::make_shared<mi::KeyRepeatDispatcher>(
-                the_event_filter_chain_dispatcher(), the_main_loop(), the_cookie_authority(),
+                keyboard_resync_dispatcher, the_main_loop(), the_cookie_authority(),
                 enable_repeat, key_repeat_timeout, key_repeat_delay, false);
         });
 }
@@ -317,6 +325,7 @@ std::shared_ptr<mi::DefaultInputDeviceHub> mir::DefaultServerConfiguration::the_
            auto hub = std::make_shared<mi::DefaultInputDeviceHub>(
                the_seat(),
                the_input_reading_multiplexer(),
+               the_clock(),
                the_cookie_authority(),
                the_key_mapper(),
                the_server_status_listener());
@@ -356,16 +365,3 @@ mir::DefaultServerConfiguration::the_seat_observer_registrar()
             return std::make_shared<mi::SeatObserverMultiplexer>(default_executor);
         });
 }
-
-std::shared_ptr<mir::frontend::InputConfigurationChanger>
-mir::DefaultServerConfiguration::the_input_configuration_changer()
-{
-    return input_configuration_changer(
-        [this]()
-        {
-            return std::make_shared<mi::ConfigChanger>(
-                the_input_manager(), the_default_input_device_hub(), the_session_container(),
-                the_session_event_handler_register(), the_input_device_hub());
-        }
-        );
-}
