@@ -199,12 +199,6 @@ void mi::SeatInputDeviceTracker::update_states()
                               [](auto const& acc, auto const& item) { return acc | item.second.buttons; });
 }
 
-mir::geometry::Point mi::SeatInputDeviceTracker::cursor_position() const
-{
-    std::lock_guard<std::mutex> lock(device_state_mutex);
-    return {cursor_x, cursor_y};
-}
-
 MirPointerButtons mi::SeatInputDeviceTracker::button_state() const
 {
     std::lock_guard<std::mutex> lock(device_state_mutex);
@@ -305,7 +299,7 @@ mir::EventUPtr mi::SeatInputDeviceTracker::create_device_state() const
             devices.back().pressed_keys.push_back(KEY_SCROLLLOCK);
         }
     }
-    auto out_ev = mev::make_event(
+    auto out_ev = mev::make_input_configure_event(
         clock->now().time_since_epoch(),
         buttons,
         key_mapper->modifiers(),
