@@ -22,10 +22,6 @@
 #include "mir/log.h"
 
 #include <linux/input.h>
-#include <linux/vt.h>
-#include <sys/ioctl.h>
-#include <fcntl.h>
-#include <unistd.h>
 
 mir::input::VTFilter::VTFilter(std::unique_ptr<mir::VTSwitcher> switcher)
     : switcher{std::move(switcher)}
@@ -50,12 +46,12 @@ bool mir::input::VTFilter::handle(MirEvent const& event)
         {
             switcher->switch_to(
                 vtno,
-                [](std::exception const& err)
+                [](std::exception const&)
                 {
                     mir::log(
                         mir::logging::Severity::error,
                         "VT switch key handler",
-                        std::make_exception_ptr(err),
+                        std::current_exception(),
                         "Failed to switch to requested VT");
                 });
         };
