@@ -31,9 +31,7 @@ public:
     std::shared_ptr<compositor::CompositorReport> create_compositor_report() override;
     std::shared_ptr<graphics::DisplayReport> create_display_report() override;
     std::shared_ptr<scene::SceneReport> create_scene_report() override;
-    std::shared_ptr<frontend::ConnectorReport> create_connector_report() override;
-    std::shared_ptr<frontend::SessionMediatorObserver> create_session_mediator_report() override;
-    std::shared_ptr<frontend::MessageProcessorReport> create_message_processor_report() override;
+
     std::shared_ptr<input::InputReport> create_input_report() override;
     std::shared_ptr<input::SeatObserver> create_seat_report() override;
     std::shared_ptr<SharedLibraryProberReport> create_shared_library_prober_report() override;
