@@ -33,7 +33,7 @@ class InputReport : public input::InputReport
 {
 public:
     InputReport() = default;
-    virtual ~InputReport() noexcept(true) = default;
+    virtual ~InputReport() noexcept = default;
 
     void received_event_from_kernel(int64_t when, int type, int code, int value) override;
 
