@@ -25,15 +25,12 @@
 #include "mir/frontend/connector.h"
 #include "mir/raii.h"
 #include "mir/emergency_cleanup.h"
+#include "mir/system_executor.h"
 
 #include <atomic>
-#include <exception>
 #include <mutex>
 #include <csignal>
-#include <cstdlib>
 #include <cassert>
-#include <sys/types.h>
-#include <unistd.h>
 
 namespace
 {
@@ -110,8 +107,11 @@ void mir::run_mir(
         [&]{ if (!concurrent_calls++) for (auto sig : intercepted) old_handler[sig] = signal(sig, fatal_signal_cleanup); },
         [&]{ if (!--concurrent_calls) for (auto sig : intercepted) signal(sig, old_handler[sig]); });
 
+    mir::SystemExecutor::set_unhandled_exception_handler(&terminate_with_current_exception);
+
     init(server);
     server.run();
 
+    mir::SystemExecutor::quiesce();
     check_for_termination_exception();
 }
