@@ -19,12 +19,12 @@
 #include "application_session.h"
 
 #include "mir/scene/surface.h"
-#include "mir/scene/surface_creation_parameters.h"
 #include "mir/scene/session_container.h"
 #include "mir/scene/session_listener.h"
 #include "mir/scene/surface_factory.h"
 #include "mir/scene/buffer_stream_factory.h"
 #include "mir/shell/surface_stack.h"
+#include "mir/shell/surface_specification.h"
 #include "mir/compositor/buffer_stream.h"
 #include "mir/events/event_builders.h"
 #include "mir/frontend/event_sink.h"
@@ -51,6 +51,7 @@ ms::ApplicationSession::ApplicationSession(
     std::shared_ptr<SurfaceFactory> const& surface_factory,
     std::shared_ptr<ms::BufferStreamFactory> const& buffer_stream_factory,
     pid_t pid,
+    Fd socket_fd,
     std::string const& session_name,
     std::shared_ptr<SessionListener> const& session_listener,
     std::shared_ptr<mf::EventSink> const& sink,
@@ -59,6 +60,7 @@ ms::ApplicationSession::ApplicationSession(
     surface_factory(surface_factory),
     buffer_stream_factory(buffer_stream_factory),
     pid(pid),
+    socket_fd_(socket_fd),
     session_name(session_name),
     session_listener(session_listener),
     event_sink(sink),
@@ -79,47 +81,34 @@ ms::ApplicationSession::~ApplicationSession()
 
 auto ms::ApplicationSession::create_surface(
     std::shared_ptr<Session> const& session,
-    SurfaceCreationParameters const& the_params,
+    shell::SurfaceSpecification const& the_params,
     std::shared_ptr<ms::SurfaceObserver> const& observer) -> std::shared_ptr<Surface>
 {
     if (session && session.get() != this)
         fatal_error("Incorrect session");
 
-    //TODO: we take either the content or the first stream's content for now.
-    //      Once the surface factory interface takes more than one stream,
+    //TODO: we take the first stream's content for now. Once the surface factory interface takes more than one stream,
     //      we can take all the streams as content.
-    if (!((the_params.content.lock()) ||
-          (the_params.streams.is_set() && the_params.streams.value().size() > 0)))
+    if (!the_params.streams.is_set() || the_params.streams.value().empty())
     {
         BOOST_THROW_EXCEPTION(std::logic_error("surface must have content"));
     }
 
     auto params = the_params;
 
-    std::shared_ptr<mc::BufferStream> buffer_stream;
-    if (auto const stream = params.content.lock())
-    {
-        buffer_stream = std::dynamic_pointer_cast<mc::BufferStream>(stream);
-    }
-    else
-    {
-        buffer_stream = std::dynamic_pointer_cast<mc::BufferStream>(params.streams.value()[0].stream.lock());
-    }
+    std::shared_ptr<mc::BufferStream> const buffer_stream =
+        std::dynamic_pointer_cast<mc::BufferStream>(params.streams.value()[0].stream.lock());
 
     std::list<StreamInfo> streams;
-    if (auto const stream = the_params.content.lock())
+    for (auto& stream : params.streams.value())
     {
-        streams.push_back({std::dynamic_pointer_cast<mc::BufferStream>(stream), {0,0}, the_params.size});
-    }
-    else
-    {
-        for (auto& stream : params.streams.value())
-            streams.push_back({std::dynamic_pointer_cast<mc::BufferStream>(stream.stream.lock()), stream.displacement, stream.size});
+        streams.push_back({std::dynamic_pointer_cast<mc::BufferStream>(stream.stream.lock()), stream.displacement, stream.size});
     }
 
     auto surface = surface_factory->create_surface(session, streams, params);
 
-    surface_stack->add_surface(surface, params.input_mode);
+    auto const input_mode = params.input_mode.is_set() ? params.input_mode.value() : input::InputReceptionMode::normal;
+    surface_stack->add_surface(surface, input_mode);
 
     if (observer)
         surface->add_observer(observer);
@@ -147,6 +136,8 @@ auto ms::ApplicationSession::create_surface(
         surface->set_depth_layer(params.depth_layer.value());
     if (params.application_id.is_set())
         surface->set_application_id(params.application_id.value());
+    if (params.focus_mode.is_set())
+        surface->set_focus_mode(params.focus_mode.value());
 
     return surface;
 }
@@ -236,6 +227,11 @@ pid_t ms::ApplicationSession::process_id() const
     return pid;
 }
 
+mir::Fd ms::ApplicationSession::socket_fd() const
+{
+    return socket_fd_;
+}
+
 void ms::ApplicationSession::hide()
 {
     std::unique_lock<std::mutex> lock(surfaces_and_streams_mutex);
@@ -267,17 +263,17 @@ void ms::ApplicationSession::set_lifecycle_state(MirLifecycleState state)
 void ms::ApplicationSession::start_prompt_session()
 {
     // All sessions which are part of the prompt session get this event.
-    event_sink->handle_event(mev::make_event(mir_prompt_session_state_started));
+    event_sink->handle_event(mev::make_prompt_session_state_event(mir_prompt_session_state_started));
 }
 
 void ms::ApplicationSession::stop_prompt_session()
 {
-    event_sink->handle_event(mev::make_event(mir_prompt_session_state_stopped));
+    event_sink->handle_event(mev::make_prompt_session_state_event(mir_prompt_session_state_stopped));
 }
 
 void ms::ApplicationSession::suspend_prompt_session()
 {
-    event_sink->handle_event(mev::make_event(mir_prompt_session_state_suspended));
+    event_sink->handle_event(mev::make_prompt_session_state_event(mir_prompt_session_state_suspended));
 }
 
 void ms::ApplicationSession::resume_prompt_session()
