@@ -119,16 +119,6 @@ void ms::SurfaceObservers::client_surface_close_requested(Surface const* surf)
         { observer->client_surface_close_requested(surf); });
 }
 
-void ms::SurfaceObservers::keymap_changed(
-    Surface const* surf, MirInputDeviceId id, std::string const& model,
-    std::string const& layout,
-    std::string const& variant,
-    std::string const& options)
-{
-    for_each([&](std::shared_ptr<SurfaceObserver> const& observer)
-        { observer->keymap_changed(surf, id, model, layout, variant, options); });
-}
-
 void ms::SurfaceObservers::renamed(Surface const* surf, char const* name)
 {
     for_each([&surf, name](std::shared_ptr<SurfaceObserver> const& observer)
@@ -171,12 +161,6 @@ void ms::SurfaceObservers::application_id_set_to(Surface const* surf, std::strin
                  { observer->application_id_set_to(surf, application_id); });
 }
 
-ms::BasicSurface::ProofOfMutexLock::ProofOfMutexLock(std::unique_lock<std::mutex> const& lock)
-{
-    if (!lock.owns_lock())
-        fatal_error("ProofOfMutexLock created with unlocked unique_lock");
-}
-
 struct ms::CursorStreamImageAdapter
 {
     CursorStreamImageAdapter(ms::BasicSurface &surface)
@@ -879,12 +863,6 @@ void ms::BasicSurface::consume(MirEvent const* event)
     observers->input_consumed(this, event);
 }
 
-void ms::BasicSurface::set_keymap(MirInputDeviceId id, std::string const& model, std::string const& layout,
-                                  std::string const& variant, std::string const& options)
-{
-    observers->keymap_changed(this, id, model, layout, variant, options);
-}
-
 void ms::BasicSurface::rename(std::string const& title)
 {
     std::unique_lock<std::mutex> lock(guard);
@@ -1010,6 +988,7 @@ auto mir::scene::BasicSurface::focus_state() const -> MirWindowFocusState
 void mir::scene::BasicSurface::set_focus_state(MirWindowFocusState new_state)
 {
     if (new_state != mir_window_focus_state_focused &&
+        new_state != mir_window_focus_state_active &&
         new_state != mir_window_focus_state_unfocused)
     {
         BOOST_THROW_EXCEPTION(std::logic_error("Invalid focus state."));
@@ -1078,6 +1057,18 @@ void mir::scene::BasicSurface::set_window_margins(
     }
 }
 
+auto mir::scene::BasicSurface::focus_mode() const -> MirFocusMode
+{
+    std::lock_guard<std::mutex> lock(guard);
+    return focus_mode_;
+}
+
+void mir::scene::BasicSurface::set_focus_mode(MirFocusMode focus_mode)
+{
+    std::lock_guard<std::mutex> lock(guard);
+    focus_mode_ = focus_mode;
+}
+
 auto mir::scene::BasicSurface::content_size(ProofOfMutexLock const&) const -> geometry::Size
 {
     return geom::Size{
