@@ -21,6 +21,7 @@
 
 #include "mir/scene/surface.h"
 #include "mir/basic_observers.h"
+#include "mir/proof_of_mutex_lock.h"
 #include "mir/scene/surface_observers.h"
 
 #include "mir/geometry/rectangle.h"
@@ -38,7 +39,6 @@ namespace mir
 {
 namespace compositor
 {
-struct BufferIPCPackage;
 class BufferStream;
 }
 namespace frontend { class EventSink; }
@@ -138,9 +138,6 @@ public:
 
     int dpi() const;
 
-    void set_keymap(MirInputDeviceId id, std::string const& model, std::string const& layout,
-                    std::string const& variant, std::string const& options) override;
-
     void rename(std::string const& title) override;
 
     void set_confine_pointer_state(MirPointerConfinementState state) override;
@@ -168,15 +165,10 @@ public:
         geometry::DeltaY bottom,
         geometry::DeltaX right) override;
 
-private:
-    struct ProofOfMutexLock
-    {
-        ProofOfMutexLock(std::lock_guard<std::mutex> const&) {}
-        ProofOfMutexLock(std::unique_lock<std::mutex> const& lock);
-        ProofOfMutexLock(ProofOfMutexLock const&) = delete;
-        ProofOfMutexLock operator=(ProofOfMutexLock const&) = delete;
-    };
+    auto focus_mode() const -> MirFocusMode override;
+    void set_focus_mode(MirFocusMode focus_mode) override;
 
+private:
     bool visible(ProofOfMutexLock const&) const;
     MirWindowType set_type(MirWindowType t);  // Use configure() to make public changes
     MirWindowState set_state(MirWindowState s);
@@ -227,6 +219,8 @@ private:
         geometry::DeltaY bottom;
         geometry::DeltaX right;
     } margins;
+
+    MirFocusMode focus_mode_ = mir_focus_mode_focusable;
 };
 
 }
