@@ -26,7 +26,6 @@
 #include "mir/scene/session_event_sink.h"
 #include "mir/graphics/display.h"
 #include "mir/compositor/compositor.h"
-#include "mir/geometry/rectangles.h"
 #include "mir/graphics/display_configuration_policy.h"
 #include "mir/graphics/display_configuration.h"
 #include "mir/graphics/display_configuration_observer.h"
@@ -64,25 +63,6 @@ public:
     }
 };
 
-class DisplayConfigurationNotInProgressError : public mir::ClientVisibleError
-{
-public:
-    DisplayConfigurationNotInProgressError()
-        : ClientVisibleError("No base display configuration preview in progress")
-    {
-    }
-
-    MirErrorDomain domain() const noexcept override
-    {
-        return mir_error_domain_display_configuration;
-    }
-
-    uint32_t code() const noexcept override
-    {
-        return mir_display_configuration_error_no_preview_in_progress;
-    }
-};
-
 class DisplayConfigurationFailedError : public mir::ClientVisibleError
 {
 public:
@@ -163,7 +143,6 @@ struct ms::MediatingDisplayChanger::SessionObserver : ms::SessionEventSink
     ms::MediatingDisplayChanger* const self;
 };
 
-
 ms::MediatingDisplayChanger::MediatingDisplayChanger(
     std::shared_ptr<mg::Display> const& display,
     std::shared_ptr<mc::Compositor> const& compositor,
@@ -238,43 +217,6 @@ void ms::MediatingDisplayChanger::configure(
         });
 }
 
-void ms::MediatingDisplayChanger::remove_session_configuration(
-    std::shared_ptr<ms::Session> const& session)
-{
-    {
-        std::lock_guard<std::mutex> lg{configuration_mutex};
-        if (config_map.find(session) != config_map.end())
-        {
-            config_map.erase(session);
-            observer->session_configuration_removed(session);
-        }
-
-        if (session != focused_session.lock())
-            return;
-    }
-
-    std::weak_ptr<ms::Session> const weak_session{session};
-
-    server_action_queue->enqueue(
-        this,
-        [this, weak_session]
-        {
-            if (auto const session = weak_session.lock())
-            {
-                std::lock_guard<std::mutex> lg{configuration_mutex};
-
-                try
-                {
-                    apply_base_config();
-                }
-                catch (std::exception const&)
-                {
-                    session->send_error(DisplayConfigurationFailedError{});
-                }
-            }
-        });
-}
-
 void
 ms::MediatingDisplayChanger::preview_base_configuration(
     std::weak_ptr<ms::Session> const& session,
@@ -340,47 +282,6 @@ ms::MediatingDisplayChanger::confirm_base_configuration(
     set_base_configuration(confirmed_conf);
 }
 
-void
-ms::MediatingDisplayChanger::cancel_base_configuration_preview(
-    std::shared_ptr<ms::Session> const& session)
-{
-    std::unique_ptr<mt::Alarm> previously_set_alarm;
-    {
-        std::lock_guard<std::mutex> lock{configuration_mutex};
-        if (!preview_configuration_timeout || (currently_previewing_session.lock() != session))
-        {
-            BOOST_THROW_EXCEPTION(DisplayConfigurationNotInProgressError());
-        }
-        /* We transfer the alarm out of the lock, because the alarm's callback may try
-         * to *take* the configuration_mutex lock.
-         *
-         * Since cancel() blocks until the callback will definitely not be entered,
-         * we need to call cancel() outside the configuration_mutex lock to avoid possible
-         * deadlocks
-         */
-        previously_set_alarm = std::move(preview_configuration_timeout);
-        preview_configuration_timeout = nullptr;
-        currently_previewing_session = std::weak_ptr<ms::Session>{};
-    }
-
-    if (previously_set_alarm->cancel())
-    {
-        // We cancelled the alarm, which means it had not already been triggered.
-        // Therefore we need to queue up a switch back to the base display configuration and
-        // send a notification.
-        server_action_queue->enqueue(
-            this,
-            [this, weak_session = std::weak_ptr<ms::Session>(session)]()
-            {
-                if (auto live_session = weak_session.lock())
-                {
-                    apply_base_config();
-                    observer->configuration_updated_for_session(live_session, base_configuration());
-                }
-            });
-    }
-}
-
 std::shared_ptr<mg::DisplayConfiguration>
 ms::MediatingDisplayChanger::base_configuration()
 {
@@ -552,7 +453,7 @@ void ms::MediatingDisplayChanger::focus_change_handler(
 
     /*
      * If the newly focused session has a display configuration, apply it.
-     * Otherwise if we aren't currently using the base configuration,
+     * Otherwise, if we aren't currently using the base configuration,
      * apply that.
      */
     auto const it = config_map.find(session);
@@ -615,3 +516,22 @@ void ms::MediatingDisplayChanger::set_base_configuration(std::shared_ptr<mg::Dis
         });
 }
 
+void ms::MediatingDisplayChanger::set_power_mode(MirPowerMode new_power_mode)
+{
+    std::lock_guard<std::mutex> lock{power_mode_mutex};
+    if (new_power_mode == power_mode)
+    {
+        return;
+    }
+    power_mode = new_power_mode;
+    std::shared_ptr<graphics::DisplayConfiguration> const config = display->configuration();
+    config->for_each_output([&](mg::UserDisplayConfigurationOutput& output)
+        {
+            if (output.used)
+            {
+                output.power_mode = new_power_mode;
+            }
+        });
+    apply_config(config);
+}
+
