@@ -22,7 +22,7 @@ namespace ms = mir::scene;
 
 void ms::NullObserver::surface_added(std::shared_ptr<ms::Surface> const& /* surface */) {}
 void ms::NullObserver::surface_removed(std::shared_ptr<ms::Surface> const& /* surface */) {}
-void ms::NullObserver::surfaces_reordered() {}
+void ms::NullObserver::surfaces_reordered(SurfaceSet const& /* affected_surfaces */) {}
 void ms::NullObserver::scene_changed() {}
 void ms::NullObserver::surface_exists(std::shared_ptr<ms::Surface> const& /* surface */) {}
 void ms::NullObserver::end_observation() {}
