@@ -22,7 +22,6 @@
 #include "mir/scene/surface.h"
 #include "mir/scene/session.h"
 #include "mir/scene/session_listener.h"
-#include "mir/scene/prompt_session.h"
 #include "mir/scene/application_not_responding_detector.h"
 #include "mir/shell/surface_stack.h"
 #include "mir/scene/session_event_sink.h"
@@ -35,7 +34,6 @@
 
 #include <stdexcept>
 #include <memory>
-#include <cassert>
 #include <algorithm>
 
 namespace mf = mir::frontend;
@@ -136,6 +134,7 @@ ms::SessionManager::~SessionManager() noexcept
 
 std::shared_ptr<ms::Session> ms::SessionManager::open_session(
     pid_t client_pid,
+    Fd socket_fd,
     std::string const& name,
     std::shared_ptr<mf::EventSink> const& sender)
 {
@@ -144,6 +143,7 @@ std::shared_ptr<ms::Session> ms::SessionManager::open_session(
         surface_factory,
         buffer_stream_factory,
         client_pid,
+        socket_fd,
         name,
         observers,
         sender,
