@@ -22,6 +22,7 @@
 #include "mir/scene/session_coordinator.h"
 #include "mir/scene/session_listener.h"
 #include "mir/observer_registrar.h"
+#include "mir/fd.h"
 
 #include <memory>
 #include <vector>
@@ -43,7 +44,6 @@ namespace scene
 class SessionContainer;
 class SessionEventSink;
 class SessionListener;
-class SnapshotStrategy;
 class SurfaceStack;
 class PromptSessionManager;
 class BufferStreamFactory;
@@ -69,6 +69,7 @@ public:
 
     auto open_session(
         pid_t client_pid,
+        Fd socket_fd,
         std::string const& name,
         std::shared_ptr<frontend::EventSink> const& sink) -> std::shared_ptr<Session> override;
 
