@@ -28,11 +28,11 @@
 #include "mir/scene/session_coordinator.h"
 #include "mir/scene/session.h"
 #include "mir/scene/surface.h"
-#include "mir/scene/surface_creation_parameters.h"
 #include "mir/input/seat.h"
 #include "decoration/manager.h"
 
 #include <algorithm>
+#include <iterator>
 #include <vector>
 
 namespace mf = mir::frontend;
@@ -69,6 +69,33 @@ private:
 
     msh::AbstractShell* shell;
 };
+
+auto get_non_popup_parent(std::shared_ptr<ms::Surface> surface) -> std::shared_ptr<ms::Surface>
+{
+    while (surface)
+    {
+        auto const type = surface->type();
+        if (type != mir_window_type_gloss &&
+            type != mir_window_type_tip &&
+            type != mir_window_type_menu)
+        {
+            break;
+        }
+        surface = surface->parent();
+    }
+    return surface;
+}
+
+// Returns a vector comprising the supplied surface (if not null), parent, grandparent, etc. in order
+auto get_ancestry(std::shared_ptr<ms::Surface> surface) -> std::vector<std::shared_ptr<ms::Surface>>
+{
+    std::vector<std::shared_ptr<ms::Surface>> result;
+    for (auto item = std::move(surface); item; item = item->parent())
+    {
+        result.push_back(item);
+    }
+    return result;
+}
 }
 
 msh::AbstractShell::AbstractShell(
@@ -116,10 +143,11 @@ void msh::AbstractShell::update_focused_surface_confined_region()
 
 std::shared_ptr<ms::Session> msh::AbstractShell::open_session(
     pid_t client_pid,
+    Fd socket_fd,
     std::string const& name,
     std::shared_ptr<mf::EventSink> const& sink)
 {
-    auto const result = session_coordinator->open_session(client_pid, name, sink);
+    auto const result = session_coordinator->open_session(client_pid, socket_fd, name, sink);
     window_manager->add_session(result);
     report->opened_session(*result);
     return result;
@@ -138,7 +166,7 @@ void msh::AbstractShell::close_session(
     for (auto surface = session->default_surface(); surface; surface = session->surface_after(surface))
         if (!surfaces.insert(surface).second) break;
 
-    // this is an ugly kludge to remove the each of the surfaces owned by the session
+    // this is an ugly kludge to remove each of the surfaces owned by the session
     // We could likely do this better (and atomically) within the WindowManager
     for (auto const& surface : surfaces)
     {
@@ -152,13 +180,15 @@ void msh::AbstractShell::close_session(
 
 auto msh::AbstractShell::create_surface(
     std::shared_ptr<ms::Session> const& session,
-    ms::SurfaceCreationParameters const& params,
+    SurfaceSpecification const& spec,
     std::shared_ptr<ms::SurfaceObserver> const& observer) -> std::shared_ptr<ms::Surface>
 {
     // Instead of a shared pointer, a local variable could be used and the lambda could capture a reference to it
     // This should be safe, but could be the source of nasty bugs and crashes if the wm did something unexpected
     auto const should_decorate = std::make_shared<bool>(false);
-    auto const build = [observer, should_decorate](std::shared_ptr<ms::Session> const& session, ms::SurfaceCreationParameters const& placed_params)
+    auto const build = [observer, should_decorate](
+            std::shared_ptr<ms::Session> const& session,
+            msh::SurfaceSpecification const& placed_params)
         {
             if (placed_params.server_side_decorated.is_set() && placed_params.server_side_decorated.value())
             {
@@ -167,7 +197,7 @@ auto msh::AbstractShell::create_surface(
             return session->create_surface(session, placed_params, observer);
         };
 
-    auto const result = window_manager->add_surface(session, params, build);
+    auto const result = window_manager->add_surface(session, spec, build);
     report->created_surface(*session, *result);
 
     if (*should_decorate)
@@ -402,121 +432,111 @@ void msh::AbstractShell::set_focus_to(
     std::shared_ptr<ms::Session> const& focus_session,
     std::shared_ptr<ms::Surface> const& focus_surface)
 {
-    std::vector<std::shared_ptr<ms::Surface>> new_popups;
-
-    // Don't give keyboard focus to popups
-    auto surface = focus_surface;
-    while (surface)
-    {
-        auto const type = surface->type();
-        if (type != mir_window_type_gloss &&
-            type != mir_window_type_tip &&
-            type != mir_window_type_menu)
-        {
-            break;
-        }
-        new_popups.push_back(surface);
-        surface = surface->parent();
-    }
-
     std::unique_lock<std::mutex> lock(focus_mutex);
 
-    for (auto const& old_popup_weak : popups_of_focused_surface)
+    if (last_requested_focus_surface.lock() != focus_surface)
     {
-        if (auto const old_popup = old_popup_weak.lock())
-        {
-            if (find(begin(new_popups), end(new_popups), old_popup) == end(new_popups))
-            {
-                // If the popup isn't in the set of new popups, hide it
-                old_popup->request_client_surface_close();
-                old_popup->hide();
-            }
-        }
+        last_requested_focus_surface = focus_surface;
+        auto new_active_surfaces = get_ancestry(focus_surface);
+
+        /// HACK: Grabbing popups (menus, in Mir terminology) should be given keyboard focus according to xdg-shell,
+        /// however, giving menus keyboard focus breaks Qt submenus. As of February 2022 Weston and other compositors
+        /// disobey the protocol by not giving keyboard focus to grabbing popups, so we do the same thing. The behavior
+        /// is subject change. See: https://github.com/MirServer/mir/issues/2324.
+        auto const new_keyboard_focus_surface = get_non_popup_parent(focus_surface);
+
+        notify_active_surfaces(lock, new_keyboard_focus_surface, std::move(new_active_surfaces));
+        set_keyboard_focus_surface(lock, new_keyboard_focus_surface);
     }
 
-    popups_of_focused_surface.clear();
-    for (auto const& new_popup : new_popups)
-    {
-        popups_of_focused_surface.push_back(new_popup);
-    }
-
-    notify_focus_locked(lock, focus_session, surface);
-    update_focus_locked(lock, focus_session, surface);
+    update_focus_locked(lock, focus_session, focus_surface);
 }
 
-void msh::AbstractShell::notify_focus_locked(
-    std::unique_lock<std::mutex> const& /*lock*/,
-    std::shared_ptr<ms::Session> const& /*session*/,
-    std::shared_ptr<ms::Surface> const& surface)
+void msh::AbstractShell::notify_active_surfaces(
+    std::unique_lock<std::mutex> const&,
+    std::shared_ptr<ms::Surface> const& new_keyboard_focus_surface,
+    std::vector<std::shared_ptr<ms::Surface>> new_active_surfaces)
 {
-    auto const current_focus = notified_focus_surface.lock();
+    SurfaceSet new_active_set{begin(new_active_surfaces), end(new_active_surfaces)};
 
-    std::vector<std::shared_ptr<ms::Surface>> new_focus_tree;
-
-    for (auto item = surface; item; item = item->parent())
+    for (auto const& current_active_weak: notified_active_surfaces)
     {
-        new_focus_tree.insert(begin(new_focus_tree), item);
-    }
-
-    std::vector<std::shared_ptr<ms::Surface>> current_focus_tree;
-
-    for (auto item = current_focus; item; item = item->parent())
-    {
-        current_focus_tree.push_back(item);
-    }
-
-    if (surface != current_focus)
-    {
-        notified_focus_surface = surface;
-        seat->reset_confinement_regions();
-
-        for (auto const& item : current_focus_tree)
+        if (auto const current_active = current_active_weak.lock())
         {
-            if (find(begin(new_focus_tree), end(new_focus_tree), item) == end(new_focus_tree))
+            // If this surface is not still active
+            if (new_active_set.find(current_active_weak) == end(new_active_set))
             {
-                item->set_focus_state(mir_window_focus_state_unfocused);
-            }
-        }
+                // If a surface that was previously active is not in the set of new active surfaces, notify it
+                current_active->set_focus_state(mir_window_focus_state_unfocused);
 
-        if (current_focus)
-        {
-            current_focus->remove_observer(focus_surface_observer);
-
-            switch (current_focus->confine_pointer_state())
-            {
-            case mir_pointer_confined_oneshot:
-            case mir_pointer_locked_oneshot:
-                seat->reset_confinement_regions();
-                current_focus->set_confine_pointer_state(mir_pointer_unconfined);
-                break;
-
-            default:
-                break;
-            }
-        }
-
-        if (surface)
-        {
-            update_confinement_for(surface);
-
-            // Ensure the surface has really taken the focus before notifying it that it is focused
-            input_targeter->set_focus(surface);
-            surface->consume(seat->create_device_state().get());
-            surface->add_observer(focus_surface_observer);
-
-            for (auto const& item : new_focus_tree)
-            {
-                if (find(begin(current_focus_tree), end(current_focus_tree), item) == end(current_focus_tree))
+                // When a menu loses focus we should close and unmap it
+                if (current_active->type() == mir_window_type_menu || current_active->type() == mir_window_type_gloss)
                 {
-                    item->set_focus_state(mir_window_focus_state_focused);
+                    current_active->request_client_surface_close();
+                    current_active->hide();
                 }
             }
         }
-        else
+    }
+
+    for (auto const& new_active: new_active_surfaces)
+    {
+        if (new_active != new_keyboard_focus_surface)
         {
-            input_targeter->clear_focus();
+            new_active->set_focus_state(mir_window_focus_state_active);
         }
     }
+
+    if (new_keyboard_focus_surface)
+    {
+        new_keyboard_focus_surface->set_focus_state(mir_window_focus_state_focused);
+    }
+
+    notified_active_surfaces = {begin(new_active_surfaces), end(new_active_surfaces)};
+}
+
+void msh::AbstractShell::set_keyboard_focus_surface(
+    std::unique_lock<std::mutex> const&,
+    std::shared_ptr<ms::Surface> const& new_keyboard_focus_surface)
+{
+    auto const current_keyboard_focus = notified_keyboard_focus_surface.lock();
+    if (current_keyboard_focus == new_keyboard_focus_surface)
+    {
+        return;
+    }
+
+    seat->reset_confinement_regions();
+
+    if (current_keyboard_focus)
+    {
+        current_keyboard_focus->remove_observer(focus_surface_observer);
+
+        switch (current_keyboard_focus->confine_pointer_state())
+        {
+        case mir_pointer_confined_oneshot:
+        case mir_pointer_locked_oneshot:
+            current_keyboard_focus->set_confine_pointer_state(mir_pointer_unconfined);
+            break;
+
+        default:
+            break;
+        }
+    }
+
+    if (new_keyboard_focus_surface)
+    {
+        update_confinement_for(new_keyboard_focus_surface);
+
+        input_targeter->set_focus(new_keyboard_focus_surface);
+        new_keyboard_focus_surface->consume(seat->create_device_state().get());
+        new_keyboard_focus_surface->add_observer(focus_surface_observer);
+    }
+    else
+    {
+        input_targeter->clear_focus();
+    }
+
+    notified_keyboard_focus_surface = new_keyboard_focus_surface;
 }
 
 void msh::AbstractShell::update_confinement_for(std::shared_ptr<ms::Surface> const& surface) const
@@ -596,6 +616,9 @@ bool msh::AbstractShell::handle(MirEvent const& event)
 
     case mir_input_event_type_pointer:
         return window_manager->handle_pointer_event(mir_input_event_get_pointer_event(input_event));
+
+    case mir_input_event_type_keyboard_resync:
+        return false;
     
     case mir_input_event_types:
         abort();
