@@ -34,6 +34,8 @@ struct MockCursorListener : public input::CursorListener
 {
     MOCK_METHOD2(cursor_moved_to, void(float, float));
     ~MockCursorListener() noexcept {}
+    void pointer_usable() {}
+    void pointer_unusable() {}
 };
 
 }
