@@ -20,7 +20,9 @@
 #define MIR_TEST_DOUBLES_MOCK_GL_BUFFER_H_
 
 #include "mock_buffer.h"
-#include "mir/renderer/gl/texture_source.h"
+#include "mir/graphics/texture.h"
+#include "mir/graphics/program.h"
+#include "mir/graphics/program_factory.h"
 
 namespace mir
 {
@@ -29,17 +31,17 @@ namespace test
 namespace doubles
 {
 
-struct MockGLBuffer : public MockBuffer,
-                      public renderer::gl::TextureSource
+struct MockTextureBuffer : public MockBuffer,
+                           public graphics::gl::Texture
 {
- public:
+public:
     using MockBuffer::MockBuffer;
 
-    MOCK_METHOD0(gl_bind_to_texture, void());
-    MOCK_METHOD0(secure_for_render, void());
-    MOCK_METHOD0(bind, void());
+    MOCK_METHOD(graphics::gl::Program const&, shader, (graphics::gl::ProgramFactory&), (const override));
+    MOCK_METHOD(Layout, layout, (), (const override));
+    MOCK_METHOD(void, bind, (), (override));
+    MOCK_METHOD(void, add_syncpoint, (), (override));
 };
-
 }
 }
 }
