@@ -47,10 +47,18 @@ struct MockSurface : public scene::BasicSurface
         ON_CALL(*this, primary_buffer_stream())
             .WillByDefault(testing::Invoke([this]
                 { return scene::BasicSurface::primary_buffer_stream(); }));
+        ON_CALL(*this, parent())
+            .WillByDefault(testing::Return(nullptr));
+        ON_CALL(*this, set_focus_state(testing::_))
+            .WillByDefault(testing::Invoke([this](MirWindowFocusState focus_state)
+                {
+                    BasicSurface::set_focus_state(focus_state);
+                }));
     }
 
     ~MockSurface() noexcept {}
 
+    MOCK_CONST_METHOD0(type, MirWindowType());
     MOCK_METHOD0(hide, void());
     MOCK_METHOD0(show, void());
     MOCK_CONST_METHOD0(visible, bool());
@@ -61,6 +69,8 @@ struct MockSurface : public scene::BasicSurface
     MOCK_CONST_METHOD0(size, geometry::Size());
     MOCK_CONST_METHOD0(pixel_format, MirPixelFormat());
 
+    MOCK_METHOD0(request_client_surface_close, void());
+    MOCK_CONST_METHOD0(parent, std::shared_ptr<scene::Surface>());
     MOCK_METHOD2(configure, int(MirWindowAttrib, int));
     MOCK_METHOD1(add_observer, void(std::shared_ptr<scene::SurfaceObserver> const&));
     MOCK_METHOD1(remove_observer, void(std::weak_ptr<scene::SurfaceObserver> const&));
@@ -69,6 +79,8 @@ struct MockSurface : public scene::BasicSurface
     MOCK_CONST_METHOD0(primary_buffer_stream, std::shared_ptr<frontend::BufferStream>());
     MOCK_METHOD1(set_streams, void(std::list<scene::StreamInfo> const&));
 
+    MOCK_METHOD1(set_focus_state, void(MirWindowFocusState));
+
     std::shared_ptr<MockBufferStream> const stream;
 };
 
