@@ -41,7 +41,7 @@ struct NullEventSink : public frontend::EventSink
     void handle_display_config_change(graphics::DisplayConfiguration const&) override {}
     void handle_error(ClientVisibleError const&) override {}
     void send_ping(int32_t) override {}
-    void send_buffer(frontend::BufferStreamId, graphics::Buffer&, graphics::BufferIpcMsgType) override {}
+    void send_buffer(frontend::BufferStreamId, graphics::Buffer&) override {}
     void handle_input_config_change(MirInputConfig const&) override {}
     void add_buffer(graphics::Buffer&) override {}
     void update_buffer(graphics::Buffer&) override {}
