@@ -90,11 +90,6 @@ public:
     {
         return false;
     }
-    unsigned int swap_interval() const override
-    {
-        return 1;
-    }
-
 private:
     std::shared_ptr<graphics::Buffer> make_stub_buffer(geometry::Rectangle const& rect)
     {
@@ -164,11 +159,6 @@ struct IntervalZeroRenderable : StubRenderable
         StubRenderable(buffer, rect)
     {
     }
-
-    unsigned int swap_interval() const override
-    {
-        return 0;
-    }
 };
 
 }
