@@ -99,6 +99,7 @@ struct StubShell : public shell::Shell
     /// @{
     auto open_session(
         pid_t client_pid,
+        Fd /*socket_fd*/,
         std::string const& /*name*/,
         std::shared_ptr<frontend::EventSink> const& /*sink*/) -> std::shared_ptr<scene::Session> override
     {
@@ -128,7 +129,7 @@ struct StubShell : public shell::Shell
 
     auto create_surface(
         std::shared_ptr<scene::Session> const& /*session*/,
-        scene::SurfaceCreationParameters const& /*params*/,
+        shell::SurfaceSpecification const& /*params*/,
         std::shared_ptr<scene::SurfaceObserver> const& /*observer*/) -> std::shared_ptr<scene::Surface> override
     {
         return std::make_shared<StubSurface>();
