@@ -69,7 +69,6 @@ public:
      */
     int client_socket_fd() const override { return 0; }
     int client_socket_fd(std::function<void(std::shared_ptr<ms::Session> const&)> const&) const override { return 0; }
-    void remove_endpoint() const {}
     auto socket_name() const -> mir::optional_value<std::string> override { return {}; }
 };
 
@@ -234,14 +233,6 @@ public:
         return mock_compositor;
     }
 
-    std::shared_ptr<mf::Connector> the_connector() override
-    {
-        if (!mock_connector)
-            mock_connector = std::make_shared<MockConnector>();
-
-        return mock_connector;
-    }
-
     std::shared_ptr<mi::InputManager> the_input_manager() override
     {
         if (!mock_input_manager)
@@ -270,12 +261,6 @@ public:
         return mock_compositor;
     }
 
-    std::shared_ptr<MockConnector> the_mock_connector()
-    {
-        the_connector();
-        return mock_connector;
-    }
-
     std::shared_ptr<mtd::MockInputManager> the_mock_input_manager()
     {
         the_input_manager();
@@ -321,7 +306,6 @@ public:
 private:
     std::shared_ptr<mtd::MockCompositor> mock_compositor;
     std::shared_ptr<MockDisplay> mock_display;
-    std::shared_ptr<MockConnector> mock_connector;
     std::shared_ptr<mtd::MockInputManager> mock_input_manager;
     std::shared_ptr<mtd::MockInputDispatcher> mock_input_dispatcher;
 
@@ -357,7 +341,6 @@ struct DisplayServerMainLoopEvents : testing::Test
     {
         mock_compositor = server_config.the_mock_compositor();
         mock_display = server_config.the_mock_display();
-        mock_connector = server_config.the_mock_connector();
         mock_input_manager = server_config.the_mock_input_manager();
         mock_input_dispatcher = server_config.the_mock_input_dispatcher();
     }
@@ -367,12 +350,10 @@ struct DisplayServerMainLoopEvents : testing::Test
         EXPECT_CALL(*mock_compositor, start()).Times(1);
         EXPECT_CALL(*mock_input_manager, start()).Times(1);
         EXPECT_CALL(*mock_input_dispatcher, start()).Times(1);
-        EXPECT_CALL(*mock_connector, start()).Times(1);
     }
 
     void expect_pause()
     {
-        EXPECT_CALL(*mock_connector, stop()).Times(1);
         EXPECT_CALL(*mock_input_dispatcher, stop()).Times(1);
         EXPECT_CALL(*mock_input_manager, stop()).Times(1);
         EXPECT_CALL(*mock_compositor, stop()).Times(1);
@@ -385,12 +366,10 @@ struct DisplayServerMainLoopEvents : testing::Test
         EXPECT_CALL(*mock_compositor, start()).Times(1);
         EXPECT_CALL(*mock_input_manager, start()).Times(1);
         EXPECT_CALL(*mock_input_dispatcher, start()).Times(1);
-        EXPECT_CALL(*mock_connector, start()).Times(1);
     }
 
     void expect_stop()
     {
-        EXPECT_CALL(*mock_connector, stop()).Times(1);
         EXPECT_CALL(*mock_input_dispatcher, stop()).Times(1);
         EXPECT_CALL(*mock_input_manager, stop()).Times(1);
         EXPECT_CALL(*mock_compositor, stop()).Times(1);
@@ -405,7 +384,6 @@ struct DisplayServerMainLoopEvents : testing::Test
 
     std::shared_ptr<MockDisplay> mock_display;
     std::shared_ptr<mtd::MockCompositor> mock_compositor;
-    std::shared_ptr<MockConnector> mock_connector;
     std::shared_ptr<mtd::MockInputManager> mock_input_manager;
     std::shared_ptr<mtd::MockInputDispatcher> mock_input_dispatcher;
 };
@@ -506,7 +484,6 @@ TEST_F(DisplayServerMainLoopEvents, display_server_attempts_to_continue_on_pause
         expect_start();
 
         /* Pause failure */
-        EXPECT_CALL(*mock_connector, stop()).Times(1);
         EXPECT_CALL(*mock_input_dispatcher, stop()).Times(1);
         EXPECT_CALL(*mock_input_manager, stop()).Times(1);
         EXPECT_CALL(*mock_compositor, stop()).Times(1);
@@ -517,7 +494,6 @@ TEST_F(DisplayServerMainLoopEvents, display_server_attempts_to_continue_on_pause
         EXPECT_CALL(*mock_compositor, start()).Times(1);
         EXPECT_CALL(*mock_input_manager, start()).Times(1);
         EXPECT_CALL(*mock_input_dispatcher, start()).Times(1);
-        EXPECT_CALL(*mock_connector, start()).Times(1);
 
         expect_stop();
     }
