@@ -18,25 +18,18 @@
 
 #include "mir_test_framework/async_server_runner.h"
 #include "mir_test_framework/command_line_server_configuration.h"
-#include "mir_test_framework/canonical_window_manager_policy.h"
 
-#include "mir/default_configuration.h"
 #include "mir/fd.h"
 #include "mir/main_loop.h"
-#include "mir/geometry/rectangle.h"
-#include "mir/options/configuration.h"
 #include "mir/options/option.h"
 #include <mir/report_exception.h>
 #include <mir/thread_name.h>
 #include "mir/test/doubles/null_logger.h"
-#include <miral/set_window_management_policy.h>
-#include <mir/shell/canonical_window_manager.h>
 
 #include <boost/throw_exception.hpp>
 
 #include <gtest/gtest.h>
 
-namespace geom = mir::geometry;
 namespace ml = mir::logging;
 namespace mo = mir::options;
 namespace msh = mir::shell;
@@ -49,21 +42,9 @@ namespace
 std::chrono::seconds const timeout{20};
 }
 
-mtf::AsyncServerRunner::AsyncServerRunner() :
-    set_window_management_policy{[](auto&){}}
+mtf::AsyncServerRunner::AsyncServerRunner()
 {
-    // These options are needed to test through the legacy mirclient API
-    server.add_configuration_option(mo::enable_mirclient_opt, "Enable deprecated mirclient socket", mir::OptionType::null);
-    server.add_configuration_option(mo::no_server_socket_opt,
-                                    "Do not provide a socket filename for client connections", mir::OptionType::null);
-    server.add_configuration_option(mo::prompt_socket_opt,
-                                    "Provide a \"..._trusted\" filename for prompt helper connections", mir::OptionType::null);
-    server.add_configuration_option(mo::server_socket_opt,
-                                    "Socket filename [string:default=$XDG_RUNTIME_DIR/mir_socket or /tmp/mir_socket]",
-                                    mir::default_server_socket);
-
     unsetenv("WAYLAND_DISPLAY");    // We don't want to conflict with any existing Wayland server
-    add_to_environment("MIR_SERVER_ENABLE_MIRCLIENT", "");
     configure_from_commandline(server);
 
     server.add_configuration_option(mtd::logging_opt, mtd::logging_descr, false);
@@ -76,18 +57,6 @@ mtf::AsyncServerRunner::AsyncServerRunner() :
 
             return result;
         });
-    // TODO This is here to support tests that rely on the legacy window management code
-    // once they go, then we can set set_window_management_policy appropriately, kill this
-    // and remove msh::CanonicalWindowManager
-    server.override_the_window_manager_builder([this](msh::FocusController* focus_controller)
-        {
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-            return std::make_shared<msh::CanonicalWindowManager>(
-                    focus_controller,
-                    server.the_shell_display_layout());
-#pragma GCC diagnostic pop
-        });
 }
 
 void mtf::AsyncServerRunner::add_to_environment(char const* key, char const* value)
@@ -97,31 +66,29 @@ void mtf::AsyncServerRunner::add_to_environment(char const* key, char const* val
 
 void mtf::AsyncServerRunner::start_server()
 {
-    set_window_management_policy(server);
-
-    server.add_init_callback([&]
-        {
-            auto const main_loop = server.the_main_loop();
-            // By enqueuing the notification code in the main loop, we are
-            // ensuring that the server has really and fully started before
-            // leaving start_mir_server().
-            main_loop->enqueue(
-                this,
-                [&]
-                {
-                    std::lock_guard<std::mutex> lock(mutex);
-                    server_running = true;
-                    started.notify_one();
-                });
-        });
-
-    server.apply_settings();
-
-    mt::AutoJoinThread t([&]
+    mt::AutoJoinThread t([this]
         {
             try
             {
                 mir::set_thread_name("mtf/AsyncServer");
+
+                server.add_init_callback([this]
+                    {
+                        auto const main_loop = server.the_main_loop();
+                        // By enqueuing the notification code in the main loop, we are
+                        // ensuring that the server has really and fully started before
+                        // leaving start_mir_server().
+                        main_loop->enqueue(
+                            this,
+                            [this]
+                            {
+                                std::lock_guard<std::mutex> lock(mutex);
+                                server_running = true;
+                                started.notify_one();
+                            });
+                    });
+
+                server.apply_settings();
                 server.run();
             }
             catch (std::exception const& e)
@@ -136,7 +103,7 @@ void mtf::AsyncServerRunner::start_server()
         });
 
     std::unique_lock<std::mutex> lock(mutex);
-    started.wait_for(lock, timeout, [&] { return server_running; });
+    started.wait_for(lock, timeout, [this] { return server_running; });
 
     if (!server_running)
     {
@@ -166,18 +133,3 @@ void mtf::AsyncServerRunner::wait_for_server_exit()
 mtf::AsyncServerRunner::~AsyncServerRunner() noexcept
 {
 }
-
-auto mtf::AsyncServerRunner::new_connection() -> std::string
-{
-    return connection(server.open_client_socket());
-}
-
-auto mtf::AsyncServerRunner::connection(int fd) -> std::string
-{
-    char connect_string[64] = {0};
-    // We can't have both the server and the client owning the same fd, since
-    // that will result in a double-close(). We give the client a duplicate which
-    // the client can safely own (and should close when done).
-    sprintf(connect_string, "fd://%d", dup(fd));
-    return connect_string;
-}
