@@ -117,21 +117,3 @@ std::string mir_test_framework::server_input_platform(std::string const& name)
 
     BOOST_THROW_EXCEPTION(std::runtime_error("Failed to find server input platform in standard search locations"));
 }
-
-std::string mir_test_framework::client_platform(std::string const& name)
-{
-    std::string libname{name};
-
-    if (libname.find(".so") == std::string::npos)
-        libname += ".so." MIR_CLIENT_PLATFORM_ABI_STRING;
-
-    for (auto const& option :
-         {library_path() + "/client-modules/", library_path() + "/mir/client-platform/", std::string(MIR_CLIENT_PLATFORM_PATH) + '/'})
-    {
-        auto path_to_test = option + libname;
-        if (boost::filesystem::exists(path_to_test))
-            return path_to_test;
-    }
-
-    BOOST_THROW_EXCEPTION(std::runtime_error("Failed to find client platform in standard search locations"));
-}
