@@ -37,6 +37,11 @@ pid_t mtd::StubSession::process_id() const
     return pid;
 }
 
+mir::Fd mtd::StubSession::socket_fd() const
+{
+    return {};
+}
+
 std::shared_ptr<mir::scene::Surface> mtd::StubSession::default_surface() const
 {
     return {};
@@ -77,7 +82,7 @@ void mtd::StubSession::resume_prompt_session()
 
 auto mtd::StubSession::create_surface(
     std::shared_ptr<Session> const& /*session*/,
-    mir::scene::SurfaceCreationParameters const& /*params*/,
+    mir::shell::SurfaceSpecification const& /*params*/,
     std::shared_ptr<scene::SurfaceObserver> const& /*observer*/) -> std::shared_ptr<ms::Surface>
 {
     return nullptr;
@@ -116,5 +121,5 @@ void mtd::StubSession::send_input_config(MirInputConfig const& /*config*/)
 namespace
 {
 // Ensure we don't accidentally have an abstract class
-mtd::StubSession instantiation_test;
+mtd::StubSession instantiation_test [[maybe_unused]];
 }
