@@ -17,7 +17,6 @@
  */
 
 #include "stubbed_graphics_platform.h"
-#include "mir_test_framework/stub_graphics_platform_operation.h"
 
 #include "mir_test_framework/stub_platform_native_buffer.h"
 
@@ -26,18 +25,12 @@
 #include "mir/test/doubles/fake_display.h"
 #include "mir/fd.h"
 #include "mir/assert_module_entry_point.h"
-#include "mir/test/pipe.h"
-#include "mir/libname.h"
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <unistd.h>
-
-#include <system_error>
 #include <boost/exception/errinfo_errno.hpp>
 #include <boost/throw_exception.hpp>
 
+#include <system_error>
+
 namespace geom = mir::geometry;
 namespace mg = mir::graphics;
 namespace mo = mir::options;
@@ -127,8 +120,7 @@ mir::UniqueModulePtr<mg::DisplayPlatform> create_display_platform(
     std::shared_ptr<mo::Option> const&,
     std::shared_ptr<mir::EmergencyCleanupRegistry> const&,
     std::shared_ptr<mir::ConsoleServices> const&,
-    std::shared_ptr<mg::DisplayReport> const&,
-    std::shared_ptr<mir::logging::Logger> const&)
+    std::shared_ptr<mg::DisplayReport> const&)
 {
     mir::assert_entry_point_signature<mg::CreateDisplayPlatform>(&create_display_platform);
 
@@ -145,8 +137,7 @@ mir::UniqueModulePtr<mg::DisplayPlatform> create_display_platform(
 
 mir::UniqueModulePtr<mg::RenderingPlatform> create_rendering_platform(
     mo::Option const&,
-    mir::EmergencyCleanupRegistry&,
-    std::shared_ptr<mir::logging::Logger> const&)
+    mir::EmergencyCleanupRegistry&)
 {
     mir::assert_entry_point_signature<mg::CreateRenderPlatform>(&create_rendering_platform);
 
