@@ -22,13 +22,10 @@
 #include <miral/minimal_window_manager.h>
 #include <miral/set_window_management_policy.h>
 
-#include <mir/client/connection.h>
-
 #include <mir_test_framework/executable_path.h>
 #include <mir_test_framework/headless_display_buffer_compositor_factory.h>
 #include <mir/test/doubles/null_logger.h>
 
-#include <mir/default_configuration.h>
 #include <mir/fd.h>
 #include <mir/main_loop.h>
 #include <mir/server.h>
@@ -64,9 +61,7 @@ miral::TestDisplayServer::TestDisplayServer(int argc, char const** argv) :
     add_to_environment("MIR_SERVER_PLATFORM_DISPLAY_LIBS", "mir:stub-graphics");
     add_to_environment("MIR_SERVER_PLATFORM_RENDERING_LIBS", "mir:stub-graphics");
     add_to_environment("MIR_SERVER_PLATFORM_INPUT_LIB", mtf::server_platform("input-stub.so").c_str());
-    add_to_environment("MIR_SERVER_NO_FILE", "on");
     add_to_environment("MIR_SERVER_CONSOLE_PROVIDER", "none");
-    add_to_environment("MIR_SERVER_ENABLE_MIRCLIENT", "");
 }
 
 miral::TestDisplayServer::~TestDisplayServer() = default;
@@ -92,17 +87,6 @@ void miral::TestDisplayServer::start_server()
                 {
                     server.add_configuration_option(mtd::logging_opt, mtd::logging_descr, false);
 
-                    // These options are needed to test through the legacy mirclient API
-                    server.add_configuration_option(mo::server_socket_opt,
-                                                    "Socket filename [string:default=$XDG_RUNTIME_DIR/mir_socket or /tmp/mir_socket]",
-                                                    mir::default_server_socket);
-                    server.add_configuration_option(mo::no_server_socket_opt,
-                                                    "Do not provide a socket filename for client connections", mir::OptionType::null);
-                    server.add_configuration_option(mo::prompt_socket_opt,
-                                                    "Provide a \"..._trusted\" filename for prompt helper connections", mir::OptionType::null);
-                    server.add_configuration_option(mo::enable_mirclient_opt,
-                                                    "Enable deprecated mirclient socket", mir::OptionType::null);
-
                     server.add_init_callback([&]
                         {
                             auto const main_loop = server.the_main_loop();
@@ -170,19 +154,6 @@ void miral::TestDisplayServer::stop_server()
     server_thread.stop();
 }
 
-auto miral::TestDisplayServer::connect_client(std::string name) -> mir::client::Connection
-{
-    std::lock_guard<std::mutex> lock(mutex);
-
-    if (!server_running)
-        BOOST_THROW_EXCEPTION(std::runtime_error{"Server not running"});
-
-    char connect_string[64] = {0};
-    sprintf(connect_string, "fd://%d", dup(server_running->open_client_socket()));
-
-    return mir::client::Connection{mir_connect_sync(connect_string, name.c_str())};
-}
-
 void miral::TestDisplayServer::invoke_tools(std::function<void(WindowManagerTools& tools)> const& f)
 {
     tools.invoke_under_lock([&]{f(tools); });
