@@ -42,15 +42,15 @@ struct DragActiveWindow : mt::TestWindowManagerTools, WithParamInterface<MirWind
 
     void SetUp() override
     {
-        basic_window_manager.add_display_for_testing(display_area);
+        notify_configuration_applied(create_fake_display_configuration({display_area}));
         basic_window_manager.add_session(session);
     }
 
     void create_window_of_type(MirWindowType type)
     {
-        mir::scene::SurfaceCreationParameters creation_parameters;
+        mir::shell::SurfaceSpecification creation_parameters;
         creation_parameters.type = type;
-        creation_parameters.size = initial_parent_size;
+        creation_parameters.set_size(initial_parent_size);
 
         EXPECT_CALL(*window_manager_policy, advise_new_window(_))
             .WillOnce(
@@ -107,7 +107,7 @@ TEST_P(ForUnmoveableTypes, doesnt_move)
 // Popups, glosses, and tips should not be.
 // Freestyle surfaces may or may not be, as specified by the app.
 //                              Mir and Unity: Surfaces, input, and displays (v0.3)
-INSTANTIATE_TEST_CASE_P(DragActiveWindow, ForMoveableTypes, ::testing::Values(
+INSTANTIATE_TEST_SUITE_P(DragActiveWindow, ForMoveableTypes, ::testing::Values(
     mir_window_type_normal,
     mir_window_type_utility,
     mir_window_type_dialog,
@@ -121,7 +121,7 @@ INSTANTIATE_TEST_CASE_P(DragActiveWindow, ForMoveableTypes, ::testing::Values(
 ));
 
 
-INSTANTIATE_TEST_CASE_P(DragActiveWindow, ForUnmoveableTypes, ::testing::Values(
+INSTANTIATE_TEST_SUITE_P(DragActiveWindow, ForUnmoveableTypes, ::testing::Values(
 //    mir_window_type_normal,
 //    mir_window_type_utility,
 //    mir_window_type_dialog,
@@ -150,4 +150,4 @@ TEST_F(DragWindow, can_drag_satellite)
 
     EXPECT_THAT(window.top_left(), Eq(expected_position))
                 << "Type: " << GetParam();
-}
\ No newline at end of file
+}
