@@ -48,10 +48,10 @@ struct ModifyWindowState : mt::TestWindowManagerTools, WithParamInterface<MirWin
     {
         Window window;
 
-        mir::scene::SurfaceCreationParameters creation_parameters;
+        mir::shell::SurfaceSpecification creation_parameters;
         creation_parameters.type = type;
-        creation_parameters.size = initial_parent_size;
         creation_parameters.parent = parent;
+        creation_parameters.set_size(initial_parent_size);
 
         EXPECT_CALL(*window_manager_policy, advise_new_window(_))
             .WillOnce(
@@ -79,4 +79,4 @@ TEST_F(ModifyWindowState, can_divorce_parent)
     modifications.parent = Window{};
 
     basic_window_manager.modify_surface(session, child, modifications);
-}
\ No newline at end of file
+}
