@@ -1,5 +1,5 @@
 /*
- * Copyright © 2016 Canonical Ltd.
+ * Copyright © 2016-2020 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -96,6 +96,18 @@ FILE* popen_with_pid(char const* cmd, pid_t& pid)
     }
     else if (pid == 0)
     {
+        /* Do the minimum necessary to make this work under normal circumstances.
+         *
+         * The performance tests will often be run with MIR_SERVER_LOGGING enabled,
+         * as *most* of them use our regular test infrastructure, which inhibits
+         * logging output unless MIR_SERVER_LOGGING is set.
+         *
+         * Unfortunately, this particular test does *not* use that infrastructure,
+         * and instead spawns mir_demo_server. Which does not understand the
+         * MIR_SERVER_LOGGING option, and so fails to start (as it should, when
+         * passed an unknown option).
+         */
+        unsetenv("MIR_SERVER_LOGGING");
         close(pipe_out);
         dup2(pipe_in, 1);  // Child stdout goes into pipe_in
         close(pipe_in);
@@ -110,7 +122,7 @@ FILE* popen_with_pid(char const* cmd, pid_t& pid)
     return fdopen(pipe_out, "r");
 }
 
-bool spawn_and_forget(char const* cmd)
+pid_t spawn(char const* cmd)
 {
     int pid = fork();
     if (pid == 0)
@@ -121,12 +133,12 @@ bool spawn_and_forget(char const* cmd)
         exec_cmd(cmd);
         exit(errno);
     }
-    return (pid > 0);
+    return pid;
 }
 
-bool spawn_and_forget(std::string const& cmd)
+pid_t spawn(std::string const& cmd)
 {
-    return spawn_and_forget(cmd.c_str());
+    return spawn(cmd.c_str());
 }
 
 bool wait_for_file(char const* path, std::chrono::seconds timeout)
@@ -146,24 +158,27 @@ bool wait_for_file(char const* path, std::chrono::seconds timeout)
 
 namespace mir { namespace test {
 
-SystemPerformanceTest::SystemPerformanceTest() : bin_dir{mir_bin_dir()}
+SystemPerformanceTest::SystemPerformanceTest() :
+    bin_dir{mir_bin_dir()},
+    mir_sock{"mir_test_socket_" + std::to_string(getpid())},
+    wayland_display{"WAYLAND_DISPLAY", mir_sock.c_str()}
 {
 }
 
 void SystemPerformanceTest::set_up_with(std::string const server_args)
 {
-    auto const mir_sock = "/tmp/mir_test_socket_"+std::to_string(getpid());
-    auto const server_cmd =
-        bin_dir+"/mir_demo_server -f "+mir_sock+" "+server_args;
+    auto const server_cmd = bin_dir+"/mir_demo_server "+server_args;
 
     server_output = popen_with_pid(server_cmd.c_str(), server_pid);
     ASSERT_TRUE(server_output) << server_cmd;
-    ASSERT_TRUE(wait_for_file(mir_sock.c_str(), 5s)) << server_cmd;
-    setenv("MIR_SOCKET", mir_sock.c_str(), 1);
+    ASSERT_TRUE(wait_for_file((getenv("XDG_RUNTIME_DIR") + ("/" + mir_sock)).c_str(), 5s)) << server_cmd;
 }
 
 void SystemPerformanceTest::TearDown()
 {
+    for (auto const client_pid: client_pids)
+        kill_nicely(client_pid);
+
     kill_nicely(server_pid);
     fclose(server_output);
 }
@@ -172,7 +187,7 @@ void SystemPerformanceTest::spawn_clients(std::initializer_list<std::string> cli
 {
     for (auto& client : clients)
     {
-        spawn_and_forget(bin_dir+"/"+client);
+        client_pids.push_back(spawn(bin_dir + "/" + client));
         std::this_thread::sleep_for(100ms);
     }
 }
