@@ -20,7 +20,6 @@
 #include "mir/graphics/display.h"
 #include "mir/graphics/display_buffer.h"
 #include "mir/graphics/graphic_buffer_allocator.h"
-#include "mir/graphics/platform_authentication.h"
 #include "mir/options/program_option.h"
 #include "mir/shared_library.h"
 #include "mir/renderer/gl/context_source.h"
@@ -106,32 +105,6 @@ public:
         return the_gl_config();
     }
 
-    auto render_factory() -> std::shared_ptr<mir::renderer::RendererFactory>
-    {
-        return the_renderer_factory();
-    }
-
-    auto null_platform_authentication() -> std::shared_ptr<mg::PlatformAuthentication>
-    {
-        class NullPlatformAuthentication : public mg::PlatformAuthentication
-        {
-        public:
-            mir::optional_value<std::shared_ptr<mg::MesaAuthExtension>> auth_extension() override
-            {
-                return {};
-            }
-            mir::optional_value<std::shared_ptr<mg::SetGbmExtension>> set_gbm_extension() override
-            {
-                return {};
-            }
-            mir::optional_value<mir::Fd> drm_fd() override
-            {
-                return {};
-            }
-        };
-
-        return std::make_shared<NullPlatformAuthentication>();
-    }
 private:
     std::thread main_loop_thread;
     static char const* argv[];
@@ -200,8 +173,7 @@ auto test_platform_construction(mir::SharedLibrary const& dso, MinimalServerEnvi
             env.options(),
             env.emergency_cleanup_registry(),
             env.console_services(),
-            env.display_report(),
-            env.logger());
+            env.display_report());
 
         std::cout << "Successfully constructed DisplayPlatform" << std::endl;
 
@@ -232,17 +204,6 @@ auto test_display_construction(mir::graphics::DisplayPlatform& platform, Minimal
     }
 }
 
-auto test_display_supports_gl(mg::Display& display) -> bool
-{
-    if (dynamic_cast<mir::renderer::gl::ContextSource*>(&display))
-    {
-        std::cout << "Display supports GL context creation" << std::endl;
-        return true;
-    }
-    std::cout << "Display does not support GL context creation" << std::endl;
-    return false;
-}
-
 void for_each_display_buffer(mg::Display& display, std::function<void(mg::DisplayBuffer&)> functor)
 {
     display.for_each_display_sync_group(
@@ -584,7 +545,6 @@ int main(int argc, char const** argv)
         {
             if (auto display = test_display_construction(*platform, config))
             {
-                success &= test_display_supports_gl(*display);
                 success &= dump_egl_config(*display);
                 success &= test_display_has_at_least_one_enabled_output(*display);
                 success &= test_display_buffers_support_gl(*display);
