@@ -18,7 +18,6 @@
 
 #include "src/platforms/evdev/platform.h"
 #include "src/server/report/null_report_factory.h"
-#include "mir/console_services.h"
 
 #include "mir/input/input_device_registry.h"
 #include "mir/dispatch/dispatchable.h"
@@ -27,18 +26,14 @@
 #include "mir_test_framework/udev_environment.h"
 #include "mir/test/fake_shared.h"
 #include "mir/test/doubles/mock_libinput.h"
-#include "mir/test/doubles/mock_udev.h"
 #include "mir/test/doubles/stub_console_services.h"
 #include "mir/test/fd_utils.h"
 
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
 
-#include <umockdev.h>
 #include <memory>
 #include <vector>
-#include <initializer_list>
-#include <mir_test_framework/libinput_environment.h>
 
 namespace mi = mir::input;
 namespace mie = mi::evdev;
@@ -54,7 +49,7 @@ namespace
 
 struct MockInputDeviceRegistry : public mi::InputDeviceRegistry
 {
-    MOCK_METHOD1(add_device, void(std::shared_ptr<mi::InputDevice> const&));
+    MOCK_METHOD1(add_device, std::weak_ptr<mi::Device>(std::shared_ptr<mi::InputDevice> const&));
     MOCK_METHOD1(remove_device, void(std::shared_ptr<mi::InputDevice> const&));
 };
 
