@@ -29,10 +29,9 @@
 #include "mir/geometry/point.h"
 #include "mir/geometry/rectangle.h"
 #include "mir/test/event_matchers.h"
-#include "mir/test/doubles/mock_libinput.h"
 #include "mir/test/doubles/mock_input_seat.h"
 #include "mir/test/doubles/mock_input_sink.h"
-#include "mir/test/gmock_fixes.h"
+#include "mir/test/doubles/advanceable_clock.h"
 #include "mir/test/fake_shared.h"
 #include "mir/udev/wrapper.h"
 #include "mir/cookie/authority.h"
@@ -44,6 +43,7 @@
 #include <libinput.h>
 
 #include <chrono>
+#include <gtest/internal/gtest-internal.h>
 
 namespace mi = mir::input;
 namespace mie = mi::evdev;
@@ -55,14 +55,6 @@ namespace geom = mir::geometry;
 
 namespace
 {
-
-class StubInputDeviceRegistry : public mi::InputDeviceRegistry
-{
-public:
-    void add_device(std::shared_ptr<mi::InputDevice> const&) override {}
-    void remove_device(std::shared_ptr<mi::InputDevice> const&) override {}
-};
-
 using namespace ::testing;
 using Matrix = mi::OutputInfo::Matrix;
 
@@ -70,43 +62,89 @@ struct MockEventBuilder : mi::EventBuilder
 {
     std::shared_ptr<mir::cookie::Authority> const cookie_authority = mir::cookie::Authority::create();
     mtd::MockInputSeat seat;
-    mi::DefaultEventBuilder builder{MirInputDeviceId{3}, cookie_authority, mt::fake_shared(seat)};
+    mtd::AdvanceableClock clock;
+    mi::DefaultEventBuilder builder{
+        MirInputDeviceId{3},
+        mt::fake_shared(clock),
+        cookie_authority,
+        mt::fake_shared(seat)};
     MockEventBuilder()
     {
-        ON_CALL(*this, key_event(_,_,_,_))
-            .WillByDefault(Invoke([this](Timestamp time, MirKeyboardAction action, xkb_keysym_t key, int scan_code)
-                                  {
-                                        return builder.key_event(time, action, key, scan_code);
-                                  }));
-        ON_CALL(*this, touch_event(_, _))
-            .WillByDefault(Invoke([this](Timestamp time, std::vector<mir::events::ContactState> const& contacts)
-                                  {
-                                        return builder.touch_event(time, contacts);
-                                  }));
-        ON_CALL(*this, pointer_event(_, _, _, _, _, _, _))
-            .WillByDefault(Invoke([this](Timestamp time, MirPointerAction action, MirPointerButtons buttons,
-                                         float hscroll, float vscroll, float relative_x, float relative_y)
-                                  {
-                                      return builder.pointer_event(time, action, buttons, hscroll, vscroll,
-                                                                   relative_x, relative_y);
-                                  }));
-        ON_CALL(*this, pointer_event(_, _, _, _, _, _, _, _, _))
-            .WillByDefault(Invoke([this](Timestamp time, MirPointerAction action, MirPointerButtons buttons, float x,
-                                         float y, float hscroll, float vscroll, float relative_x, float relative_y)
-                                  {
-                                       return builder.pointer_event(time, action, buttons, x, y,
-                                                                    hscroll, vscroll, relative_x, relative_y);
-                                  }));
+        ON_CALL(*this, key_event(_,_,_,_)).WillByDefault(
+            [this](std::optional<Timestamp> time, MirKeyboardAction action, xkb_keysym_t key, int scan_code)
+            {
+                return builder.key_event(time, action, key, scan_code);
+            });
+
+        ON_CALL(*this, touch_event(_, _)).WillByDefault(
+            [this](std::optional<Timestamp> time, std::vector<mir::events::ContactState> const& contacts)
+            {
+                return builder.touch_event(time, contacts);
+            });
+
+        ON_CALL(*this, pointer_event(_, _, _, _, _, _, _)).WillByDefault(
+            [this](std::optional<Timestamp> time, MirPointerAction action, MirPointerButtons buttons,
+                   float hscroll, float vscroll, float relative_x, float relative_y)
+            {
+                return builder.pointer_event(time, action, buttons, hscroll, vscroll, relative_x, relative_y);
+            });
+
+        ON_CALL(*this, pointer_event(_, _, _, _, _, _, _, _, _)).WillByDefault(
+            [this](std::optional<Timestamp> time, MirPointerAction action, MirPointerButtons buttons,
+                   float x, float y, float hscroll, float vscroll, float relative_x, float relative_y)
+            {
+                return builder.pointer_event(time, action, buttons, x, y, hscroll, vscroll, relative_x, relative_y);
+            });
+
+        ON_CALL(*this, pointer_axis_event(_, _, _, _, _, _, _, _, _, _)).WillByDefault(
+            [this](MirPointerAxisSource axis_source, std::optional<Timestamp> time, MirPointerAction action,
+                   MirPointerButtons buttons, float x, float y, float hscroll, float vscroll, float relative_x, float relative_y)
+            {
+                return builder.pointer_axis_event(
+                    axis_source, time, action, buttons, x, y, hscroll, vscroll, relative_x, relative_y);
+            });
+
+        ON_CALL(*this, pointer_axis_with_stop_event(_, _, _, _, _, _, _, _, _, _, _, _)).WillByDefault(
+            [this](MirPointerAxisSource axis_source, std::optional<Timestamp> time, MirPointerAction action,
+                   MirPointerButtons buttons, float x, float y, float hscroll, float vscroll,
+                   bool hscroll_stop, bool vscroll_stop, float relative_x, float relative_y)
+            {
+                return builder.pointer_axis_with_stop_event(
+                    axis_source, time, action, buttons, x, y, hscroll, vscroll, vscroll_stop, hscroll_stop,
+                    relative_x, relative_y);
+            });
+
+        ON_CALL(*this, pointer_axis_discrete_scroll_event(_, _, _, _, _, _, _, _)).WillByDefault(
+            [this](MirPointerAxisSource axis_source, std::optional<Timestamp> timestamp, MirPointerAction action,
+                   MirPointerButtons buttons_pressed, float hscroll_value, float vscroll_value,
+                   float hscroll_discrete, float vscroll_discrete)
+            {
+                return builder.pointer_axis_discrete_scroll_event(
+                    axis_source, timestamp, action, buttons_pressed, hscroll_value, vscroll_value,
+                    hscroll_discrete, vscroll_discrete);
+            });
     }
     using EventBuilder::Timestamp;
-    MOCK_METHOD4(key_event, mir::EventUPtr(Timestamp, MirKeyboardAction, xkb_keysym_t, int));
 
-    MOCK_METHOD2(touch_event, mir::EventUPtr(Timestamp, std::vector<mir::events::ContactState> const&));
-    MOCK_METHOD7(pointer_event,
-                 mir::EventUPtr(Timestamp, MirPointerAction, MirPointerButtons, float, float, float, float));
-    MOCK_METHOD9(
-        pointer_event,
-        mir::EventUPtr(Timestamp, MirPointerAction, MirPointerButtons, float, float, float, float, float, float));
+    MOCK_METHOD(mir::EventUPtr, key_event, (std::optional<Timestamp>, MirKeyboardAction, xkb_keysym_t, int));
+    MOCK_METHOD(mir::EventUPtr, touch_event, (std::optional<Timestamp>, std::vector<mir::events::ContactState> const&));
+    MOCK_METHOD(mir::EventUPtr, pointer_event,
+                (std::optional<Timestamp>, MirPointerAction, MirPointerButtons, float, float, float, float));
+    MOCK_METHOD(mir::EventUPtr, pointer_event,
+                (std::optional<Timestamp>, MirPointerAction, MirPointerButtons, float, float, float, float, float, float));
+    MOCK_METHOD(mir::EventUPtr, pointer_axis_event,
+                (MirPointerAxisSource axis_source, std::optional<Timestamp> timestamp, MirPointerAction action,
+                 MirPointerButtons buttons_pressed, float x_position, float y_position,
+                 float hscroll_value, float vscroll_value, float relative_x_value, float relative_y_value));
+    MOCK_METHOD(mir::EventUPtr, pointer_axis_with_stop_event,
+                (MirPointerAxisSource axis_source, std::optional<Timestamp> timestamp, MirPointerAction action,
+                 MirPointerButtons buttons_pressed, float x_position, float y_position,
+                 float hscroll_value, float vscroll_value, bool hscroll_stop, bool vscroll_stop,
+                 float relative_x_value, float relative_y_value));
+    MOCK_METHOD(mir::EventUPtr, pointer_axis_discrete_scroll_event,
+                (MirPointerAxisSource axis_source, std::optional<Timestamp> timestamp, MirPointerAction action,
+                 MirPointerButtons buttons_pressed, float hscroll_value, float vscroll_value, float hscroll_discrete,
+                 float vscroll_discrete));
 };
 
 struct LibInputDevice : public ::testing::Test
@@ -359,9 +397,9 @@ TEST_F(LibInputDevice, removal_unrefs_libinput_device)
 
 TEST_F(LibInputDeviceOnLaptopKeyboard, process_event_converts_key_event)
 {
-    EXPECT_CALL(mock_builder, key_event(time_stamp_1, mir_keyboard_action_down, _, KEY_A));
+    EXPECT_CALL(mock_builder, key_event({time_stamp_1}, mir_keyboard_action_down, _, KEY_A));
     EXPECT_CALL(mock_sink, handle_input(AllOf(mt::KeyOfScanCode(KEY_A),mt::KeyDownEvent())));
-    EXPECT_CALL(mock_builder, key_event(time_stamp_2, mir_keyboard_action_up, _, KEY_A));
+    EXPECT_CALL(mock_builder, key_event({time_stamp_2}, mir_keyboard_action_up, _, KEY_A));
     EXPECT_CALL(mock_sink, handle_input(AllOf(mt::KeyOfScanCode(KEY_A),mt::KeyUpEvent())));
 
     keyboard.start(&mock_sink, &mock_builder);
@@ -373,11 +411,11 @@ TEST_F(LibInputDeviceOnLaptopKeyboard, process_event_converts_key_event)
 TEST_F(LibInputDeviceOnLaptopKeyboard, process_event_accumulates_key_state)
 {
     InSequence seq;
-    EXPECT_CALL(mock_builder, key_event(time_stamp_1, mir_keyboard_action_down, _, KEY_C));
+    EXPECT_CALL(mock_builder, key_event({time_stamp_1}, mir_keyboard_action_down, _, KEY_C));
     EXPECT_CALL(mock_sink, handle_input(AllOf(mt::KeyOfScanCode(KEY_C),mt::KeyDownEvent())));
-    EXPECT_CALL(mock_builder, key_event(time_stamp_2, mir_keyboard_action_down, _, KEY_LEFTALT));
+    EXPECT_CALL(mock_builder, key_event({time_stamp_2}, mir_keyboard_action_down, _, KEY_LEFTALT));
     EXPECT_CALL(mock_sink, handle_input(AllOf(mt::KeyOfScanCode(KEY_LEFTALT),mt::KeyDownEvent())));
-    EXPECT_CALL(mock_builder, key_event(time_stamp_3, mir_keyboard_action_up, _, KEY_C));
+    EXPECT_CALL(mock_builder, key_event({time_stamp_3}, mir_keyboard_action_up, _, KEY_C));
     EXPECT_CALL(mock_sink, handle_input(AllOf(mt::KeyOfScanCode(KEY_C),
                                               mt::KeyUpEvent())));
 
@@ -502,16 +540,16 @@ TEST_F(LibInputDeviceOnMouse, process_event_handles_scroll)
 {
     InSequence seq;
     // expect two scroll events..
-    EXPECT_CALL(mock_builder,
-                pointer_event(time_stamp_1, mir_pointer_action_motion, 0, 0.0f, -20.0f, 0.0f, 0.0f));
+    EXPECT_CALL(mock_builder, pointer_axis_discrete_scroll_event(
+        mir_pointer_axis_source_wheel, {time_stamp_1}, mir_pointer_action_motion, 0, 0.0f, -20.0f, 0.0f, 2.0f));
     EXPECT_CALL(mock_sink, handle_input(mt::PointerAxisChange(mir_pointer_axis_vscroll, -20.0f)));
-    EXPECT_CALL(mock_builder,
-                pointer_event(time_stamp_2, mir_pointer_action_motion, 0, 5.0f, 0.0f, 0.0f, 0.0f));
+    EXPECT_CALL(mock_builder, pointer_axis_discrete_scroll_event(
+        mir_pointer_axis_source_wheel, {time_stamp_2}, mir_pointer_action_motion, 0, 5.0f, 0.0f, 1.0f, 0.0f));
     EXPECT_CALL(mock_sink, handle_input(mt::PointerAxisChange(mir_pointer_axis_hscroll, 5.0f)));
 
     mouse.start(&mock_sink, &mock_builder);
-    env.mock_libinput.setup_axis_event(fake_device, event_time_1, 0.0, -20.0);
-    env.mock_libinput.setup_axis_event(fake_device, event_time_2, 5.0, 0.0);
+    env.mock_libinput.setup_axis_event(fake_device, event_time_1, {}, -20.0, 0, 2);
+    env.mock_libinput.setup_axis_event(fake_device, event_time_2, 5.0, {}, 1, 0);
     process_events(mouse);
 }
 
@@ -530,7 +568,7 @@ TEST_F(LibInputDeviceOnTouchScreen, process_event_handles_touch_down_events)
             major, minor, orientation}};
 
     InSequence seq;
-    EXPECT_CALL(mock_builder, touch_event(time_stamp_1, contacts));
+    EXPECT_CALL(mock_builder, touch_event({time_stamp_1}, contacts));
     EXPECT_CALL(mock_sink, handle_input(mt::TouchEvent(x, y)));
 
     touch_screen.start(&mock_sink, &mock_builder);
@@ -555,7 +593,7 @@ TEST_F(LibInputDeviceOnTouchScreen, process_event_handles_touch_move_events)
          pressure, major, minor, orientation}};
 
     InSequence seq;
-    EXPECT_CALL(mock_builder, touch_event(time_stamp_1, contacts));
+    EXPECT_CALL(mock_builder, touch_event({time_stamp_1}, contacts));
     EXPECT_CALL(mock_sink, handle_input(mt::TouchMovementEvent()));
 
     touch_screen.start(&mock_sink, &mock_builder);
@@ -581,10 +619,10 @@ TEST_F(LibInputDeviceOnTouchScreen, process_event_handles_touch_up_events_withou
 
 
     InSequence seq;
-    EXPECT_CALL(mock_builder, touch_event(time_stamp_1, contact_down));
+    EXPECT_CALL(mock_builder, touch_event({time_stamp_1}, contact_down));
     EXPECT_CALL(mock_sink, handle_input(mt::TouchEvent(x, y)));
 
-    EXPECT_CALL(mock_builder, touch_event(time_stamp_2, contact_up));
+    EXPECT_CALL(mock_builder, touch_event({time_stamp_2}, contact_up));
     EXPECT_CALL(mock_sink, handle_input(mt::TouchUpEvent(x, y)));
 
     touch_screen.start(&mock_sink, &mock_builder);
@@ -708,8 +746,8 @@ TEST_F(LibInputDeviceOnMouse, scroll_speed_scales_scroll_events)
     settings.horizontal_scroll_scale = 5.0;
     mouse.apply_settings(settings);
 
-    env.mock_libinput.setup_axis_event(fake_device, event_time_1, 0.0, -3.0);
-    env.mock_libinput.setup_axis_event(fake_device, event_time_2, -2.0, 0.0);
+    env.mock_libinput.setup_axis_event(fake_device, event_time_1, {}, -3.0);
+    env.mock_libinput.setup_axis_event(fake_device, event_time_2, -2.0, {});
 
     mouse.start(&mock_sink, &mock_builder);
     process_events(mouse);
@@ -727,18 +765,38 @@ TEST_F(LibInputDeviceOnTouchpad, process_event_handles_scroll)
 {
     InSequence seq;
     // expect two scroll events..
-    EXPECT_CALL(mock_builder,
-                pointer_event(time_stamp_1, mir_pointer_action_motion, 0, 0.0f, -10.0f, 0.0f, 0.0f));
+    EXPECT_CALL(mock_builder, pointer_axis_with_stop_event(
+        mir_pointer_axis_source_finger, {time_stamp_1}, mir_pointer_action_motion, 0,
+        0, 0, 0.0f, -10.0f, false, false, 0.0f, 0.0f));
     EXPECT_CALL(mock_sink, handle_input(mt::PointerAxisChange(mir_pointer_axis_vscroll, -10.0f)));
-    EXPECT_CALL(mock_builder,
-                pointer_event(time_stamp_2, mir_pointer_action_motion, 0, 1.0f, 0.0f, 0.0f, 0.0f));
+    EXPECT_CALL(mock_builder, pointer_axis_with_stop_event(
+        mir_pointer_axis_source_finger, {time_stamp_2}, mir_pointer_action_motion, 0,
+        0, 0, 1.0f, 0.0f, false, false, 0.0f, 0.0f));
     EXPECT_CALL(mock_sink, handle_input(mt::PointerAxisChange(mir_pointer_axis_hscroll, 1.0f)));
 
-    env.mock_libinput.setup_finger_axis_event(fake_device, event_time_1, 0.0, -10.0);
-    env.mock_libinput.setup_finger_axis_event(fake_device, event_time_2, 1.0, 0.0);
+    env.mock_libinput.setup_finger_axis_event(fake_device, event_time_1, {}, -10.0);
+    env.mock_libinput.setup_finger_axis_event(fake_device, event_time_2, 1.0, {});
     touchpad.start(&mock_sink, &mock_builder);
     process_events(touchpad);
+}
 
+TEST_F(LibInputDeviceOnTouchpad, process_event_handles_stop)
+{
+    InSequence seq;
+    // expect two scroll events..
+    EXPECT_CALL(mock_builder, pointer_axis_with_stop_event(
+        mir_pointer_axis_source_finger, {time_stamp_1}, mir_pointer_action_motion, 0,
+        0, 0, 0.0f, -10.0f, false, false, 0.0f, 0.0f));
+    EXPECT_CALL(mock_sink, handle_input(mt::PointerAxisChange(mir_pointer_axis_vscroll, -10.0f)));
+    EXPECT_CALL(mock_builder, pointer_axis_with_stop_event(
+        mir_pointer_axis_source_finger, {time_stamp_2}, mir_pointer_action_motion, 0,
+        0, 0, 0.0f, 0.0f, false, true, 0.0f, 0.0f));
+    EXPECT_CALL(mock_sink, handle_input(mt::PointerAxisChange(mir_pointer_axis_vscroll, 0.0f)));
+
+    env.mock_libinput.setup_finger_axis_event(fake_device, event_time_1, {}, -10.0);
+    env.mock_libinput.setup_finger_axis_event(fake_device, event_time_2, {}, 0.0);
+    touchpad.start(&mock_sink, &mock_builder);
+    process_events(touchpad);
 }
 
 TEST_F(LibInputDeviceOnTouchpad, reads_touchpad_settings_from_libinput)
