@@ -18,12 +18,10 @@
 
 #include "src/server/input/default_input_manager.h"
 
-#include "mir/test/fd_utils.h"
 #include "mir/test/signal_actions.h"
 #include "mir/test/fake_shared.h"
 #include "mir/test/doubles/mock_input_platform.h"
 
-#include "mir/input/platform.h"
 #include "mir/dispatch/multiplexing_dispatchable.h"
 #include "mir/dispatch/action_queue.h"
 
@@ -33,7 +31,6 @@
 #include <gmock/gmock.h>
 #include <chrono>
 #include <list>
-#include <memory>
 
 namespace mt = mir::test;
 namespace md = mir::dispatch;
