@@ -20,7 +20,6 @@
 #include "src/server/input/default_event_builder.h"
 
 #include "mir/input/xkb_mapper.h"
-#include "mir/test/doubles/mock_input_device.h"
 #include "mir/test/doubles/mock_input_dispatcher.h"
 #include "mir/test/doubles/mock_cursor_listener.h"
 #include "mir/test/doubles/mock_touch_visualizer.h"
@@ -62,9 +61,21 @@ struct SeatInputDeviceTracker : ::testing::Test
     std::shared_ptr<mir::cookie::Authority> cookie_factory = mir::cookie::Authority::create();
     mtd::AdvanceableClock clock;
 
-    mi::DefaultEventBuilder some_device_builder{some_device, cookie_factory, mt::fake_shared(mock_seat)};
-    mi::DefaultEventBuilder another_device_builder{another_device, cookie_factory, mt::fake_shared(mock_seat)};
-    mi::DefaultEventBuilder third_device_builder{third_device, cookie_factory, mt::fake_shared(mock_seat)};
+    mi::DefaultEventBuilder some_device_builder{
+        some_device,
+        mt::fake_shared(clock),
+        cookie_factory,
+        mt::fake_shared(mock_seat)};
+    mi::DefaultEventBuilder another_device_builder{
+        another_device,
+        mt::fake_shared(clock),
+        cookie_factory,
+        mt::fake_shared(mock_seat)};
+    mi::DefaultEventBuilder third_device_builder{
+        third_device,
+        mt::fake_shared(clock),
+        cookie_factory,
+        mt::fake_shared(mock_seat)};
     mi::receiver::XKBMapper mapper;
     mi::SeatInputDeviceTracker tracker{
         mt::fake_shared(mock_dispatcher), mt::fake_shared(mock_visualizer), mt::fake_shared(mock_cursor_listener),
