@@ -138,13 +138,15 @@ struct FakeKeyboard
     }
     mir::EventUPtr press(int scan_code = 7)
     {
-        return mev::make_event(id, std::chrono::nanoseconds(0), std::vector<uint8_t>{},
-	    mir_keyboard_action_down, 0, scan_code, mir_input_event_modifier_alt);
+        return mev::make_key_event(
+            id, std::chrono::nanoseconds(0), std::vector<uint8_t>{},
+            mir_keyboard_action_down, 0, scan_code, mir_input_event_modifier_alt);
     }
     mir::EventUPtr release(int scan_code = 7)
     {
-        return mev::make_event(id, std::chrono::nanoseconds(0), std::vector<uint8_t>{},
-	    mir_keyboard_action_up, 0, scan_code, mir_input_event_modifier_alt);
+        return mev::make_key_event(
+            id, std::chrono::nanoseconds(0), std::vector<uint8_t>{},
+            mir_keyboard_action_up, 0, scan_code, mir_input_event_modifier_alt);
     }
     MirInputDeviceId const id;
 };
@@ -159,7 +161,8 @@ struct FakePointer
 
     mir::EventUPtr move_to(geom::Point const& location)
     {
-        return mev::make_event(id, std::chrono::nanoseconds(0), std::vector<uint8_t>{},
+        return mev::make_pointer_event(
+            id, std::chrono::nanoseconds(0), std::vector<uint8_t>{},
             0, mir_pointer_action_motion, buttons,
             location.x.as_int(), location.y.as_int(),
             0, 0, 0, 0);
@@ -168,7 +171,8 @@ struct FakePointer
     {
         buttons &= ~button;
 
-        return mev::make_event(id, std::chrono::nanoseconds(0), std::vector<uint8_t>{},
+        return mev::make_pointer_event(
+            id, std::chrono::nanoseconds(0), std::vector<uint8_t>{},
             0, mir_pointer_action_button_up, buttons,
             location.x.as_int(), location.y.as_int(),
             0, 0, 0, 0);
@@ -177,7 +181,8 @@ struct FakePointer
     {
         buttons |= button;
         
-        return mev::make_event(id, std::chrono::nanoseconds(0), std::vector<uint8_t>{},
+        return mev::make_pointer_event(
+            id, std::chrono::nanoseconds(0), std::vector<uint8_t>{},
             0, mir_pointer_action_button_down, buttons,
             location.x.as_int(), location.y.as_int(),
             0, 0, 0, 0);
@@ -196,7 +201,7 @@ struct FakeToucher
     
     mir::EventUPtr move_to(geom::Point const& point)
     {
-        auto ev = mev::make_event(id, std::chrono::nanoseconds(0), std::vector<uint8_t>{}, 0);
+        auto ev = mev::make_touch_event(id, std::chrono::nanoseconds(0), std::vector<uint8_t>{}, 0);
         mev::add_touch(*ev, 0, mir_touch_action_change,
                        mir_touch_tooltype_finger, point.x.as_int(), point.y.as_int(),
                        touched ? 1.0 : 0.0,
@@ -209,7 +214,7 @@ struct FakeToucher
     {
         touched = true;
         
-        auto ev = mev::make_event(id, std::chrono::nanoseconds(0), std::vector<uint8_t>{}, 0);
+        auto ev = mev::make_touch_event(id, std::chrono::nanoseconds(0), std::vector<uint8_t>{}, 0);
         mev::add_touch(*ev, 0, mir_touch_action_down,
                        mir_touch_tooltype_finger, point.x.as_int(), point.y.as_int(),
                        1.0, 1.0, 1.0, 1.0);
@@ -219,7 +224,7 @@ struct FakeToucher
     {
         touched = true;
 
-        auto ev = mev::make_event(id, std::chrono::nanoseconds(0), std::vector<uint8_t>{}, 0);
+        auto ev = mev::make_touch_event(id, std::chrono::nanoseconds(0), std::vector<uint8_t>{}, 0);
         mev::add_touch(*ev, 0, mir_touch_action_down,
                        mir_touch_tooltype_finger, point1.x.as_int(), point1.y.as_int(),
                        1.0, 1.0, 1.0, 1.0);
@@ -232,7 +237,7 @@ struct FakeToucher
     {
         touched = false;
         
-        auto ev = mev::make_event(id, std::chrono::nanoseconds(0), std::vector<uint8_t>{}, 0);
+        auto ev = mev::make_touch_event(id, std::chrono::nanoseconds(0), std::vector<uint8_t>{}, 0);
         mev::add_touch(*ev, 0, mir_touch_action_up,
                        mir_touch_tooltype_finger, point.x.as_int(), point.y.as_int(),
                        0.0, 0.0, 0.0, 0.0);
@@ -242,7 +247,7 @@ struct FakeToucher
     {
         touched = false;
 
-        auto ev = mev::make_event(id, std::chrono::nanoseconds(0), std::vector<uint8_t>{}, 0);
+        auto ev = mev::make_touch_event(id, std::chrono::nanoseconds(0), std::vector<uint8_t>{}, 0);
         mev::add_touch(*ev, 0, mir_touch_action_up,
                        mir_touch_tooltype_finger, point1.x.as_int(), point1.y.as_int(),
                        1.0, 1.0, 1.0, 1.0);
