@@ -25,7 +25,6 @@
 
 #include "mir/events/event_private.h"
 #include "mir/dispatch/dispatchable.h"
-#include "mir_toolkit/event.h"
 #include "mir_toolkit/events/input/input_event.h"
 #include "mir/test/doubles/mock_input_sink.h"
 #include "mir/test/doubles/mock_input_seat.h"
@@ -33,6 +32,7 @@
 #include "mir/test/doubles/mock_x11.h"
 #include "mir/test/doubles/mock_xkb.h"
 #include "mir/test/doubles/mock_x11_resources.h"
+#include "mir/test/doubles/advanceable_clock.h"
 #include "mir/test/fake_shared.h"
 #include "mir/cookie/authority.h"
 #include "mir/test/event_matchers.h"
@@ -55,7 +55,12 @@ struct X11PlatformTest : ::testing::Test
     NiceMock<mtd::MockX11> mock_x11;
     NiceMock<mtd::MockXkb> mock_xkb;
     NiceMock<mtd::MockInputDeviceRegistry> mock_registry;
-    mir::input::DefaultEventBuilder builder{0, mir::cookie::Authority::create(), mt::fake_shared(mock_seat)};
+    mtd::AdvanceableClock clock;
+    mir::input::DefaultEventBuilder builder{
+        0,
+        mt::fake_shared(clock),
+        mir::cookie::Authority::create(),
+        mt::fake_shared(mock_seat)};
 
     mir::input::X::XInputPlatform x11_platform{
         mt::fake_shared(mock_registry),
@@ -68,7 +73,7 @@ struct X11PlatformTest : ::testing::Test
     void capture_devices()
     {
         ON_CALL(mock_registry, add_device(_))
-            .WillByDefault(Invoke([this](auto const& dev)
+            .WillByDefault(Invoke([this](auto const& dev) -> std::weak_ptr<mi::Device>
                                   {
                                       devices.push_back(dev);
                                       auto const info = dev->get_device_info();
@@ -76,6 +81,7 @@ struct X11PlatformTest : ::testing::Test
                                           dev->start(&mock_pointer_sink, &builder);
                                       else if (contains(info.capabilities, mi::DeviceCapability::keyboard))
                                           dev->start(&mock_keyboard_sink, &builder);
+                                      return {};
                                   })
                           );
     }
