@@ -21,8 +21,6 @@
 #include "mir/test/doubles/stub_console_services.h"
 #include "src/platforms/gbm-kms/server/kms/platform.h"
 #include "src/platforms/gbm-kms/server/kms/quirks.h"
-#include "src/platforms/gbm-kms/include/native_buffer.h"
-#include "mir/graphics/graphic_buffer_allocator.h"
 #include "src/platforms/gbm-kms/server/buffer_allocator.h"
 #include "mir/graphics/buffer_properties.h"
 #include "mir/graphics/display.h"
@@ -36,11 +34,8 @@
 #include "mir/test/doubles/null_display_configuration_policy.h"
 #include "mir_test_framework/udev_environment.h"
 
-#include <cstdlib>
 #include <memory>
 #include <stdexcept>
-#include <system_error>
-#include <algorithm>
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
 
@@ -76,6 +71,15 @@ protected:
                     SetArgPointee<3>(GBM_FORMAT_XRGB8888),
                     Return(EGL_TRUE)));
 
+        // We sometimes want to copy the config of an existing context.
+        // Since our mocks don't check what config attribs we're asking for,
+        // we can just make something up.
+        ON_CALL(mock_egl, eglQueryContext(_,_,EGL_CONFIG_ID,_))
+            .WillByDefault(
+                DoAll(
+                    SetArgPointee<3>(0xabadbaab),
+                    Return(EGL_TRUE)));
+
         mock_egl.provide_egl_extensions();
         mock_gl.provide_gles_extensions();
 
