@@ -344,7 +344,7 @@ TEST_F(MesaDisplayTest, create_display_drm_failure)
 {
     using namespace testing;
 
-    EXPECT_CALL(mock_drm, open(_,_,_))
+    EXPECT_CALL(mock_drm, open(_,_))
         .Times(AtLeast(1))
         .WillRepeatedly(
             DoAll(
@@ -409,8 +409,8 @@ TEST_F(MesaDisplayTest, ignores_non_modesetting_nodes)
     using namespace testing;
 
     // The platform should open all DRM nodes. In particular, it should open the second one…
-    EXPECT_CALL(mock_drm, open(StrEq("/dev/dri/card0"), _, _)).Times(AtLeast(1));
-    EXPECT_CALL(mock_drm, open(StrEq("/dev/dri/card1"), _, _)).Times(AtLeast(1));
+    EXPECT_CALL(mock_drm, open(StrEq("/dev/dri/card0"), _)).Times(AtLeast(1));
+    EXPECT_CALL(mock_drm, open(StrEq("/dev/dri/card1"), _)).Times(AtLeast(1));
 
     // …mark the second DRM node as not supporting modesetting…
     char const busid[] = "pci:00:01:02:03";
@@ -436,8 +436,8 @@ TEST_F(MesaDisplayTest, handles_first_card_not_supporting_modeset)
     using namespace testing;
 
     // The platform should open all DRM nodes.
-    EXPECT_CALL(mock_drm, open(StrEq("/dev/dri/card0"), _, _)).Times(AtLeast(1));
-    EXPECT_CALL(mock_drm, open(StrEq("/dev/dri/card1"), _, _)).Times(AtLeast(1));
+    EXPECT_CALL(mock_drm, open(StrEq("/dev/dri/card0"), _)).Times(AtLeast(1));
+    EXPECT_CALL(mock_drm, open(StrEq("/dev/dri/card1"), _)).Times(AtLeast(1));
 
     // First device is rendering only…
     mock_drm.reset("/dev/dri/card0");
@@ -707,8 +707,7 @@ TEST_F(MesaDisplayTest, outputs_correct_string_for_successful_drm_mode_set_crtc_
     reporter->report_successful_drm_mode_set_crtc_on_construction();
 }
 
-// Disabled until gbm-kms drm platform and mir platform properly shows support for those extensions
-TEST_F(MesaDisplayTest, DISABLED_constructor_throws_if_egl_khr_image_pixmap_not_supported)
+TEST_F(MesaDisplayTest, constructor_throws_if_egl_khr_image_pixmap_not_supported)
 {
     using namespace ::testing;
 
@@ -823,6 +822,7 @@ TEST_F(MesaDisplayTest, respects_gl_config)
         .Times(AtLeast(1))
         .WillRepeatedly(Return(stencil_bits));
 
+    // We create at least one rendering context, with the requested attributes…
     EXPECT_CALL(mock_egl,
                 eglChooseConfig(
                     _,
@@ -833,6 +833,16 @@ TEST_F(MesaDisplayTest, respects_gl_config)
         .WillRepeatedly(DoAll(SetArgPointee<2>(mock_egl.fake_configs[0]),
                         SetArgPointee<4>(1),
                         Return(EGL_TRUE)));
+    //…we *also* create zero-or-more non-rendering contexts; we don't care what they ask for
+    EXPECT_CALL(mock_egl,
+                eglChooseConfig(
+                    _,
+                    Pointee(EGL_NONE),
+                    NotNull(),_,_))
+        .Times(AnyNumber())
+        .WillRepeatedly(DoAll(SetArgPointee<2>(mock_egl.fake_configs[0]),
+                        SetArgPointee<4>(1),
+                        Return(EGL_TRUE)));
     /* We actually want the default behaviour here, but because we've made an
      * EXPECT_CALL for eglChooseConfig GMock will ignore the ON_CALL behaviour
      */
@@ -854,31 +864,22 @@ TEST_F(MesaDisplayTest, respects_gl_config)
         null_report};
 }
 
-/*
- * It *would* be nice to support 15bit colour, but the gbm-kms platform
- * has, from the first commit, unconditonally allocated 24-bit framebuffers.
- *
- * It's not clear to me that Mir has ever been successfully tested on a platform
- * that doesn't support 24-bit rendering.
- */
-TEST_F(MesaDisplayTest, DISABLED_supports_as_low_as_15bit_colour)
-{  // Regression test for LP: #1212753
+TEST_F(MesaDisplayTest, uses_xrgb8888_framebuffer_when_argb8888_is_not_supported_by_EGL)
+{
     using namespace testing;
 
-    mtd::StubGLConfig stub_gl_config;
+    EXPECT_CALL(mock_egl, eglGetConfigAttrib(_, mock_egl.fake_configs[0], EGL_NATIVE_VISUAL_ID, _))
+        .WillRepeatedly(
+            DoAll(
+                SetArgPointee<3>(GBM_FORMAT_XRGB8888),
+                Return(EGL_TRUE)));
 
-    EXPECT_CALL(mock_egl,
-                eglChooseConfig(
-                    _,
-                    AllOf(mtd::EGLConfigContainsAttrib(EGL_RED_SIZE, 5),
-                          mtd::EGLConfigContainsAttrib(EGL_GREEN_SIZE, 5),
-                          mtd::EGLConfigContainsAttrib(EGL_BLUE_SIZE, 5),
-                          mtd::EGLConfigContainsAttrib(EGL_ALPHA_SIZE, 0)),
-                    _,_,_))
-        .Times(AtLeast(1))
-        .WillRepeatedly(DoAll(SetArgPointee<2>(mock_egl.fake_configs[0]),
-                        SetArgPointee<4>(1),
-                        Return(EGL_TRUE)));
+    InSequence s;
+    // Maybe we first try ARGB8888, then fallback…
+    EXPECT_CALL(mock_gbm, gbm_surface_create(_, _, _, GBM_FORMAT_ARGB8888, _))
+        .Times(AtMost(1));
+    // …but we end up creating an XRGB8888 surface.
+    EXPECT_CALL(mock_gbm, gbm_surface_create(_, _, _, GBM_FORMAT_XRGB8888, _));
 
     auto platform = create_platform();
     mgg::Display display{
@@ -887,7 +888,35 @@ TEST_F(MesaDisplayTest, DISABLED_supports_as_low_as_15bit_colour)
         platform->vt,
         platform->bypass_option(),
         std::make_shared<mg::CloneDisplayConfigurationPolicy>(),
-        mir::test::fake_shared(stub_gl_config),
+        std::make_shared<NiceMock<mtd::MockGLConfig>>(),
+        null_report};
+}
+
+TEST_F(MesaDisplayTest, uses_argb8888_framebuffer_when_xrgb8888_is_not_supported_by_EGL)
+{
+    using namespace testing;
+
+    EXPECT_CALL(mock_egl, eglGetConfigAttrib(_, _, EGL_NATIVE_VISUAL_ID, _))
+        .WillRepeatedly(
+            DoAll(
+                SetArgPointee<3>(GBM_FORMAT_ARGB8888),
+                Return(EGL_TRUE)));
+
+    InSequence s;
+    // Maybe we first try XRGB8888, then fallback…
+    EXPECT_CALL(mock_gbm, gbm_surface_create(_, _, _, GBM_FORMAT_XRGB8888, _))
+        .Times(AtMost(1));
+    // …but we end up creating an ARGB8888 surface.
+    EXPECT_CALL(mock_gbm, gbm_surface_create(_, _, _, GBM_FORMAT_ARGB8888, _));
+
+    auto platform = create_platform();
+    mgg::Display display{
+        platform->drm,
+        platform->gbm,
+        platform->vt,
+        platform->bypass_option(),
+        std::make_shared<mg::CloneDisplayConfigurationPolicy>(),
+        std::make_shared<NiceMock<mtd::MockGLConfig>>(),
         null_report};
 }
 
