@@ -24,8 +24,6 @@
 #include "mir/options/program_option.h"
 
 #include "mir/test/doubles/mock_buffer.h"
-#include "mir/test/doubles/mock_console_services.h"
-#include "mir/test/doubles/null_console_services.h"
 #include "mir/test/doubles/null_emergency_cleanup.h"
 
 #include <gtest/gtest.h>
@@ -33,22 +31,17 @@
 #include "mir_test_framework/udev_environment.h"
 #include "mir_test_framework/executable_path.h"
 #include "mir_test_framework/temporary_environment_value.h"
-#include "mir/test/pipe.h"
 
 #include "mir/test/doubles/mock_drm.h"
 #include "mir/test/doubles/mock_gbm.h"
 #include "mir/test/doubles/mock_egl.h"
 #include "mir/test/doubles/mock_gl.h"
-#include "mir/test/doubles/fd_matcher.h"
 #include "mir/test/doubles/stub_console_services.h"
 
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
 
-#include <stdexcept>
 #include <atomic>
-#include <thread>
-#include <chrono>
 
 namespace mg = mir::graphics;
 namespace mgg = mir::graphics::gbm;
@@ -124,7 +117,7 @@ TEST_F(MesaGraphicsPlatform, a_failure_while_creating_a_platform_results_in_an_e
 {
     using namespace ::testing;
 
-    EXPECT_CALL(mock_drm, open(_,_,_))
+    EXPECT_CALL(mock_drm, open(_,_))
             .WillRepeatedly(SetErrnoAndReturn(EINVAL, -1));
 
     try
@@ -250,6 +243,25 @@ TEST_F(MesaGraphicsPlatform, probe_returns_unsupported_when_gbm_platform_not_sup
     EXPECT_EQ(mg::PlatformPriority::unsupported, probe(stub_vt, options));
 }
 
+TEST_F(MesaGraphicsPlatform, probe_returns_supported_when_EGL_supports_gbm_platform_but_fails_to_get_EGL_display)
+{
+    using namespace testing;
+
+    mtf::UdevEnvironment udev_environment;
+    boost::program_options::options_description po;
+    mir::options::ProgramOption options;
+    auto const stub_vt = std::make_shared<mtd::StubConsoleServices>();
+
+    udev_environment.add_standard_device("standard-drm-devices");
+
+    ON_CALL(mock_egl, eglGetPlatformDisplayEXT(_,_,_))
+        .WillByDefault(Return(EGL_NO_DISPLAY));
+
+    mir::SharedLibrary platform_lib{mtf::server_platform("graphics-gbm-kms")};
+    auto probe = platform_lib.load_function<mg::PlatformProbe>(rendering_platform_probe_symbol);
+    EXPECT_EQ(mg::PlatformPriority::supported, probe(stub_vt, options));
+}
+
 TEST_F(MesaGraphicsPlatform, probe_returns_unsupported_when_modesetting_is_not_supported)
 {
     using namespace testing;
@@ -375,9 +387,9 @@ TEST_F(MesaGraphicsPlatform, display_probe_does_not_touch_quirked_device)
      */
     auto const options_with_quirk = parsed_options_from_args({"--driver-quirks=skip:devnode:/dev/dri/card1"}, po);
 
-    EXPECT_CALL(mock_drm, open(StrEq("/dev/dri/card0"), _, _))
+    EXPECT_CALL(mock_drm, open(StrEq("/dev/dri/card0"), _))
         .Times(AtLeast(1));
-    EXPECT_CALL(mock_drm, open(StrEq("/dev/dri/card1"), _, _))
+    EXPECT_CALL(mock_drm, open(StrEq("/dev/dri/card1"), _))
         .Times(0);
 
     auto probe = platform_lib.load_function<mg::PlatformProbe>(display_platform_probe_symbol);
@@ -412,9 +424,9 @@ TEST_F(MesaGraphicsPlatform, render_probe_does_not_touch_quirked_device)
      */
     auto const options_with_quirk = parsed_options_from_args({"--driver-quirks=skip:devnode:/dev/dri/card1"}, po);
 
-    EXPECT_CALL(mock_drm, open(StrEq("/dev/dri/card0"), _, _))
+    EXPECT_CALL(mock_drm, open(StrEq("/dev/dri/card0"), _))
         .Times(AtLeast(1));
-    EXPECT_CALL(mock_drm, open(StrEq("/dev/dri/card1"), _, _))
+    EXPECT_CALL(mock_drm, open(StrEq("/dev/dri/card1"), _))
         .Times(0);
 
     auto probe = platform_lib.load_function<mg::PlatformProbe>(rendering_platform_probe_symbol);
