@@ -16,7 +16,6 @@
  * Authored by: Sam Spilsbury <sam.spilsbury@canonical.com>
  */
 
-#include <functional>
 #include <stdexcept>
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
@@ -24,7 +23,6 @@
 #include <mir/test/fake_shared.h>
 #include <mir/test/doubles/mock_gl_buffer.h>
 #include <mir/test/doubles/mock_renderable.h>
-#include <mir/test/doubles/mock_buffer_stream.h>
 #include <mir/compositor/buffer_stream.h>
 #include <mir/test/doubles/mock_gl.h>
 #include <mir/test/doubles/mock_egl.h>
