@@ -22,7 +22,6 @@
 #include "mir/scene/session.h"
 #include "mir/scene/null_session_listener.h"
 #include "mir/scene/session_container.h"
-#include "mir/scene/surface_creation_parameters.h"
 #include "mir/scene/surface_factory.h"
 #include "mir/graphics/display_configuration_observer.h"
 
@@ -47,6 +46,7 @@
 
 #include "mir/test/fake_shared.h"
 #include "mir/test/event_matchers.h"
+#include "mir/test/make_surface_spec.h"
 
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
@@ -125,7 +125,7 @@ struct MockSurfaceFactory : public ms::SurfaceFactory
     MOCK_METHOD3(create_surface, std::shared_ptr<ms::Surface>(
         std::shared_ptr<ms::Session> const&,
         std::list<ms::StreamInfo> const&,
-        ms::SurfaceCreationParameters const&));
+        msh::SurfaceSpecification const&));
 };
 
 struct MockDecorationManager : public msh::decoration::NullManager
@@ -178,11 +178,27 @@ struct AbstractShell : Test
             .WillByDefault(Invoke(
                     []()
                     {
-                        return mev::make_event(0ns, 0, mir_input_event_modifier_none, 0.0f, 0.0f,
-                                               std::vector<mev::InputDeviceState>());
+                        return mev::make_input_configure_event(
+                            0ns, 0, mir_input_event_modifier_none, 0.0f, 0.0f,
+                            std::vector<mev::InputDeviceState>());
                     }));
     }
 
+    auto create_surface(ms::Surface& surface) -> std::shared_ptr<ms::Surface>
+    {
+        auto const session = shell.open_session(
+            __LINE__,
+            mir::Fd{mir::Fd::invalid},
+            "Foo",
+            std::shared_ptr<mf::EventSink>());
+        EXPECT_CALL(surface_factory, create_surface(_, _, _))
+            .WillOnce(Return(mt::fake_shared(surface)));
+        return shell.create_surface(
+            session,
+            mt::make_surface_spec(session->create_buffer_stream(properties)),
+            nullptr);
+    }
+
     std::chrono::nanoseconds const event_timestamp = std::chrono::nanoseconds(0);
     std::vector<uint8_t> const cookie{};
     mg::BufferProperties properties { geom::Size{1,1}, mir_pixel_format_abgr_8888, mg::BufferUsage::software};
@@ -196,7 +212,7 @@ TEST_F(AbstractShell, open_session_adds_session_to_window_manager)
     InSequence s;
     EXPECT_CALL(*wm, add_session(_)).WillOnce(SaveArg<0>(&new_session));
 
-    auto session = shell.open_session(__LINE__, "Visual Basic Studio", std::shared_ptr<mf::EventSink>());
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Visual Basic Studio", std::shared_ptr<mf::EventSink>());
     EXPECT_EQ(session, new_session);
 }
 
@@ -207,15 +223,15 @@ TEST_F(AbstractShell, close_session_removes_session_from_window_manager)
     InSequence s;
     EXPECT_CALL(*wm, remove_session(_)).WillOnce(SaveArg<0>(&old_session));
 
-    auto session = shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
     shell.close_session(session);
     EXPECT_EQ(session, old_session);
 }
 
 TEST_F(AbstractShell, close_session_notifies_session_event_sink)
 {
-    auto session = shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto session1 = shell.open_session(__LINE__, "Bla", std::shared_ptr<mf::EventSink>());
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
 
     InSequence s;
     EXPECT_CALL(session_event_sink, handle_session_stopping(session1));
@@ -235,13 +251,13 @@ TEST_F(AbstractShell, close_session_removes_existing_session_surfaces_from_windo
         WillOnce(Return(mt::fake_shared(surface2))).
         WillOnce(Return(mt::fake_shared(surface3)));
 
-    auto const session = shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto const session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
     auto const created_surface1 = shell.create_surface(session,
-        ms::a_surface().with_buffer_stream(session->create_buffer_stream(properties)), nullptr);
+        mt::make_surface_spec(session->create_buffer_stream(properties)), nullptr);
     auto const created_surface2 = shell.create_surface(session,
-        ms::a_surface().with_buffer_stream(session->create_buffer_stream(properties)), nullptr);
+        mt::make_surface_spec(session->create_buffer_stream(properties)), nullptr);
     auto const created_surface3 = shell.create_surface(session,
-        ms::a_surface().with_buffer_stream(session->create_buffer_stream(properties)), nullptr);
+        mt::make_surface_spec(session->create_buffer_stream(properties)), nullptr);
 
     session->destroy_surface(created_surface2);
 
@@ -257,11 +273,10 @@ TEST_F(AbstractShell, close_session_removes_existing_session_surfaces_from_windo
 TEST_F(AbstractShell, create_surface_provides_create_parameters_to_window_manager)
 {
     std::shared_ptr<ms::Session> session =
-        shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
-    auto params = ms::a_surface()
-        .with_buffer_stream(session->create_buffer_stream(properties));
-    EXPECT_CALL(*wm, add_surface(session, Ref(params), _));
+    auto params = mt::make_surface_spec(session->create_buffer_stream(properties));
+    EXPECT_CALL(*wm, add_surface(session, params, _));
 
     shell.create_surface(session, params, nullptr);
 }
@@ -269,20 +284,19 @@ TEST_F(AbstractShell, create_surface_provides_create_parameters_to_window_manage
 TEST_F(AbstractShell, create_surface_allows_window_manager_to_set_create_parameters)
 {
     std::shared_ptr<ms::Session> const session =
-        shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
-    auto params = ms::a_surface()
-        .with_buffer_stream(session->create_buffer_stream(properties));
-    auto placed_params = params;
-    placed_params.size.width = geom::Width{100};
+    auto params = mt::make_surface_spec(session->create_buffer_stream(properties));
+    params.width = geom::Width{100};
+    params.input_mode = mi::InputReceptionMode::receives_all_input;
 
-    EXPECT_CALL(surface_stack, add_surface(_,placed_params.input_mode));
+    EXPECT_CALL(surface_stack, add_surface(_, mi::InputReceptionMode::receives_all_input));
 
-    EXPECT_CALL(*wm, add_surface(session, Ref(params), _)).WillOnce(Invoke(
+    EXPECT_CALL(*wm, add_surface(session, params, _)).WillOnce(Invoke(
         [&](std::shared_ptr<ms::Session> const& session,
-            ms::SurfaceCreationParameters const&,
-            std::function<std::shared_ptr<ms::Surface>(std::shared_ptr<ms::Session> const& session, ms::SurfaceCreationParameters const&)> const& build)
-            { return build(session, placed_params); }));
+            msh::SurfaceSpecification const&,
+            std::function<std::shared_ptr<ms::Surface>(std::shared_ptr<ms::Session> const& session, msh::SurfaceSpecification const&)> const& build)
+            { return build(session, params); }));
 
     shell.create_surface(session, params, nullptr);
 }
@@ -290,20 +304,19 @@ TEST_F(AbstractShell, create_surface_allows_window_manager_to_set_create_paramet
 TEST_F(AbstractShell, create_surface_allows_window_manager_to_enable_ssd)
 {
     std::shared_ptr<ms::Session> const session =
-        shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
-    auto params = ms::a_surface()
-        .with_buffer_stream(session->create_buffer_stream(properties));
+    auto params = mt::make_surface_spec(session->create_buffer_stream(properties));
 
     EXPECT_CALL(decoration_manager, decorate(_))
         .Times(1);
 
-    EXPECT_CALL(*wm, add_surface(session, Ref(params), _)).WillOnce(Invoke(
+    EXPECT_CALL(*wm, add_surface(session, params, _)).WillOnce(Invoke(
         [&](std::shared_ptr<ms::Session> const& session,
-            ms::SurfaceCreationParameters const& params,
+            msh::SurfaceSpecification const& params,
             std::function<std::shared_ptr<ms::Surface>(
                 std::shared_ptr<ms::Session> const& session,
-                ms::SurfaceCreationParameters const&)> const& build)
+                msh::SurfaceSpecification const&)> const& build)
             {
                 auto modified_params = params;
                 modified_params.server_side_decorated = true;
@@ -316,21 +329,20 @@ TEST_F(AbstractShell, create_surface_allows_window_manager_to_enable_ssd)
 TEST_F(AbstractShell, create_surface_allows_window_manager_to_disable_ssd)
 {
     std::shared_ptr<ms::Session> const session =
-        shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
-    auto params = ms::a_surface()
-        .with_buffer_stream(session->create_buffer_stream(properties));
+    auto params = mt::make_surface_spec(session->create_buffer_stream(properties));
     params.server_side_decorated = true;
 
     EXPECT_CALL(decoration_manager, decorate(_))
         .Times(0);
 
-    EXPECT_CALL(*wm, add_surface(session, Ref(params), _)).WillOnce(Invoke(
+    EXPECT_CALL(*wm, add_surface(session, params, _)).WillOnce(Invoke(
         [&](std::shared_ptr<ms::Session> const& session,
-            ms::SurfaceCreationParameters const& params,
+            msh::SurfaceSpecification const& params,
             std::function<std::shared_ptr<ms::Surface>(
                 std::shared_ptr<ms::Session> const& session,
-                ms::SurfaceCreationParameters const&)> const& build)
+                msh::SurfaceSpecification const&)> const& build)
             {
                 auto modified_params = params;
                 modified_params.server_side_decorated = false;
@@ -345,13 +357,12 @@ TEST_F(AbstractShell, create_surface_sets_surfaces_session)
     auto const mock_surface = std::make_shared<mtd::MockSurface>();
 
     std::shared_ptr<ms::Session> session =
-        shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
     EXPECT_CALL(surface_factory, create_surface(session, _, _)).
         WillOnce(Return(mock_surface));
 
-    auto params = ms::a_surface()
-        .with_buffer_stream(session->create_buffer_stream(properties));
+    auto params = mt::make_surface_spec(session->create_buffer_stream(properties));
 
     shell.create_surface(session, params, nullptr);
 }
@@ -359,9 +370,8 @@ TEST_F(AbstractShell, create_surface_sets_surfaces_session)
 TEST_F(AbstractShell, destroy_surface_removes_surface_from_window_manager)
 {
     std::shared_ptr<ms::Session> const session =
-        shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto const params = ms::a_surface()
-        .with_buffer_stream(session->create_buffer_stream(properties));
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
 
     auto const surface = shell.create_surface(session, params, nullptr);
 
@@ -391,16 +401,16 @@ TEST_F(AbstractShell, remove_display_adds_display_to_window_manager)
 TEST_F(AbstractShell, key_input_events_are_handled_by_window_manager)
 {
     MirKeyboardAction const action{mir_keyboard_action_down};
-    xkb_keysym_t const key_code{0};
+    xkb_keysym_t const keysym{0};
     int const scan_code{0};
     MirInputEventModifiers const modifiers{mir_input_event_modifier_none};
 
-    auto const event = mir::events::make_event(
+    auto const event = mir::events::make_key_event(
         mir_input_event_type_key,
         event_timestamp,
         cookie,
         action,
-        key_code,
+        keysym,
         scan_code,
         modifiers);
 
@@ -416,7 +426,7 @@ TEST_F(AbstractShell, touch_input_events_are_handled_by_window_manager)
 {
     MirInputEventModifiers const modifiers{mir_input_event_modifier_none};
 
-    auto const event = mir::events::make_event(
+    auto const event = mir::events::make_touch_event(
         mir_input_event_type_touch,
         event_timestamp,
         cookie,
@@ -442,7 +452,7 @@ TEST_F(AbstractShell, pointer_input_events_are_handled_by_window_manager)
     float const relative_x_value{0.0};
     float const relative_y_value{0.0};
 
-    auto const event = mir::events::make_event(
+    auto const event = mir::events::make_pointer_event(
         mir_input_event_type_pointer,
         event_timestamp,
         cookie,
@@ -467,10 +477,9 @@ TEST_F(AbstractShell, pointer_input_events_are_handled_by_window_manager)
 TEST_F(AbstractShell, setting_surface_state_is_handled_by_window_manager)
 {
     std::shared_ptr<ms::Session> const session =
-        shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
-    auto const params = ms::a_surface()
-        .with_buffer_stream(session->create_buffer_stream(properties));
+    auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
     auto const surface = shell.create_surface(session, params, nullptr);
 
     MirWindowState const state{mir_window_state_fullscreen};
@@ -486,8 +495,8 @@ TEST_F(AbstractShell, setting_surface_state_is_handled_by_window_manager)
 
 TEST_F(AbstractShell, as_focus_controller_set_focus_to_notifies_session_event_sink)
 {
-    auto session = shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto session1 = shell.open_session(__LINE__, "Bla", std::shared_ptr<mf::EventSink>());
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
 
     InSequence s;
     EXPECT_CALL(session_event_sink, handle_focus_change(session1));
@@ -503,12 +512,10 @@ TEST_F(AbstractShell, as_focus_controller_set_focus_to_notifies_session_event_si
 TEST_F(AbstractShell, as_focus_controller_focus_next_session_notifies_session_event_sink)
 {
     msh::FocusController& focus_controller = shell;
-    auto session = shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto session1 = shell.open_session(__LINE__, "Bla", std::shared_ptr<mf::EventSink>());
-    auto const params = ms::a_surface()
-        .with_buffer_stream(session->create_buffer_stream(properties));
-    auto const params2 = ms::a_surface()
-        .with_buffer_stream(session1->create_buffer_stream(properties));
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
+    auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
+    auto const params2 = mt::make_surface_spec(session->create_buffer_stream(properties));
     shell.create_surface(session, params, nullptr);
     shell.create_surface(session1, params2, nullptr);
 
@@ -521,12 +528,10 @@ TEST_F(AbstractShell, as_focus_controller_focus_next_session_notifies_session_ev
 
 TEST_F(AbstractShell, as_focus_controller_focused_session_follows_focus)
 {
-    auto session = shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto session1 = shell.open_session(__LINE__, "Bla", std::shared_ptr<mf::EventSink>());
-    auto const params = ms::a_surface()
-        .with_buffer_stream(session->create_buffer_stream(properties));
-    auto const params2 = ms::a_surface()
-        .with_buffer_stream(session1->create_buffer_stream(properties));
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
+    auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
+    auto const params2 = mt::make_surface_spec(session->create_buffer_stream(properties));
     shell.create_surface(session, params, nullptr);
     shell.create_surface(session1, params2, nullptr);
 
@@ -542,20 +547,18 @@ TEST_F(AbstractShell, as_focus_controller_focused_session_follows_focus)
 
 TEST_F(AbstractShell, as_focus_controller_focused_surface_follows_focus)
 {
-    auto const session0 = shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto const session1 = shell.open_session(__LINE__, "Bla", std::shared_ptr<mf::EventSink>());
+    auto const session0 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto const session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
     NiceMock<mtd::MockSurface> dummy_surface;
     ON_CALL(dummy_surface, size()).WillByDefault(Return(geom::Size{}));
     EXPECT_CALL(surface_factory, create_surface(_, _, _)).Times(AnyNumber())
         .WillOnce(Return(mt::fake_shared(dummy_surface)))
         .WillOnce(Return(mt::fake_shared(mock_surface)));
 
-    auto const params = ms::a_surface()
-        .with_buffer_stream(session0->create_buffer_stream(properties));
-    auto const params2 = ms::a_surface()
-        .with_buffer_stream(session1->create_buffer_stream(properties));
-    auto const surface0 = shell.create_surface(session0, params, nullptr);
-    auto const surface1 = shell.create_surface(session1, params2, nullptr);
+    auto const params0 = mt::make_surface_spec(session0->create_buffer_stream(properties));
+    auto const params1 = mt::make_surface_spec(session1->create_buffer_stream(properties));
+    auto const surface0 = shell.create_surface(session0, params0, nullptr);
+    auto const surface1 = shell.create_surface(session1, params1, nullptr);
 
     msh::FocusController& focus_controller = shell;
 
@@ -588,14 +591,12 @@ TEST_F(AbstractShell, as_focus_controller_delegates_surface_at_to_surface_stack)
 TEST_F(AbstractShell, as_focus_controller_focus_next_session_skips_surfaceless_sessions)
 {
     msh::FocusController& focus_controller = shell;
-    auto session = shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto session1 = shell.open_session(__LINE__, "Surfaceless", std::shared_ptr<mf::EventSink>());
-    auto session2 = shell.open_session(__LINE__, "Bla", std::shared_ptr<mf::EventSink>());
-    auto const params = ms::a_surface()
-        .with_buffer_stream(session->create_buffer_stream(properties));
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Surfaceless", std::shared_ptr<mf::EventSink>());
+    auto session2 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
+    auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
     auto created_surface = shell.create_surface(session, params, nullptr);
-    auto const params2 = ms::a_surface()
-        .with_buffer_stream(session2->create_buffer_stream(properties));
+    auto const params2 = mt::make_surface_spec(session2->create_buffer_stream(properties));
     shell.create_surface(session2, params2, nullptr);
 
     focus_controller.set_focus_to(session, created_surface);
@@ -609,10 +610,9 @@ TEST_F(AbstractShell,
        as_focus_controller_focus_next_session_does_not_focus_any_session_if_no_session_has_surfaces)
 {
     msh::FocusController& focus_controller = shell;
-    auto session = shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto session1 = shell.open_session(__LINE__, "Surfaceless", std::shared_ptr<mf::EventSink>());
-    auto creation_params = ms::a_surface()
-        .with_buffer_stream(session->create_buffer_stream(properties));
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Surfaceless", std::shared_ptr<mf::EventSink>());
+    auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
     auto surface = shell.create_surface(session, creation_params, nullptr);
 
     focus_controller.set_focus_to(session, surface);
@@ -627,10 +627,9 @@ TEST_F(AbstractShell,
 TEST_F(AbstractShell, modify_surface_with_only_streams_doesnt_call_into_wm)
 {
     std::shared_ptr<ms::Session> session =
-        shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
-    auto creation_params = ms::a_surface()
-        .with_buffer_stream(session->create_buffer_stream(properties));
+    auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
     auto surface = shell.create_surface(session, creation_params, nullptr);
 
     msh::SurfaceSpecification stream_modification;
@@ -644,10 +643,9 @@ TEST_F(AbstractShell, modify_surface_with_only_streams_doesnt_call_into_wm)
 TEST_F(AbstractShell, modify_surface_does_not_call_wm_for_empty_changes)
 {
     std::shared_ptr<ms::Session> session =
-        shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
-    auto creation_params = ms::a_surface()
-        .with_buffer_stream(session->create_buffer_stream(properties));
+    auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
 
     auto surface = shell.create_surface(session, creation_params, nullptr);
 
@@ -669,10 +667,9 @@ TEST_F(AbstractShell, size_gets_adjusted_for_windows_with_margins)
         content_size.width + left + right,
         content_size.height + top + bottom};
     std::shared_ptr<ms::Session> session =
-        shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
-    auto creation_params = ms::a_surface()
-        .with_buffer_stream(session->create_buffer_stream(properties));
+    auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
     auto surface = shell.create_surface(session, creation_params, nullptr);
     surface->resize({50, 50});
     surface->set_window_margins(top, left, bottom, right);
@@ -701,10 +698,9 @@ TEST_F(AbstractShell, max_size_gets_adjusted_for_windows_with_margins)
         content_size.width + left + right,
         content_size.height + top + bottom};
     std::shared_ptr<ms::Session> session =
-        shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
-    auto creation_params = ms::a_surface()
-        .with_buffer_stream(session->create_buffer_stream(properties));
+    auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
     auto surface = shell.create_surface(session, creation_params, nullptr);
     surface->resize({50, 50});
     surface->set_window_margins(top, left, bottom, right);
@@ -733,10 +729,9 @@ TEST_F(AbstractShell, min_size_gets_adjusted_for_windows_with_margins)
         content_size.width + left + right,
         content_size.height + top + bottom};
     std::shared_ptr<ms::Session> session =
-        shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
-    auto creation_params = ms::a_surface()
-        .with_buffer_stream(session->create_buffer_stream(properties));
+    auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
     auto surface = shell.create_surface(session, creation_params, nullptr);
     surface->resize({50, 50});
     surface->set_window_margins(top, left, bottom, right);
@@ -766,10 +761,9 @@ TEST_F(AbstractShell, aux_rect_gets_adjusted_for_windows_with_margins)
         frontend_aux_rect.top_left + geom::Displacement{left, top},
         frontend_aux_rect.size};
     std::shared_ptr<ms::Session> session =
-        shell.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
-    auto creation_params = ms::a_surface()
-        .with_buffer_stream(session->create_buffer_stream(properties));
+    auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
     auto surface = shell.create_surface(session, creation_params, nullptr);
     surface->resize(content_size);
     surface->set_window_margins(top, left, bottom, right);
@@ -789,14 +783,13 @@ TEST_F(AbstractShell, aux_rect_gets_adjusted_for_windows_with_margins)
 TEST_F(AbstractShell, when_remaining_session_has_no_surface_focus_next_session_doesnt_loop_endlessly)
 {
     std::shared_ptr<ms::Session> empty_session =
-        shell.open_session(__LINE__, "empty_session", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "empty_session", std::shared_ptr<mf::EventSink>());
 
     {
         std::shared_ptr<ms::Session> another_session =
-            shell.open_session(__LINE__, "another_session", std::shared_ptr<mf::EventSink>());
+            shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "another_session", std::shared_ptr<mf::EventSink>());
 
-        auto creation_params = ms::a_surface()
-            .with_buffer_stream(another_session->create_buffer_stream(properties));
+        auto creation_params = mt::make_surface_spec(another_session->create_buffer_stream(properties));
         auto surface = shell.create_surface(another_session, creation_params, nullptr);
 
         shell.set_focus_to(another_session, surface);
@@ -807,6 +800,209 @@ TEST_F(AbstractShell, when_remaining_session_has_no_surface_focus_next_session_d
     shell.focus_next_session();
 }
 
+TEST_F(AbstractShell, focus_can_be_set)
+{
+    NiceMock<mtd::MockSurface> mock_surface1;
+    EXPECT_CALL(surface_factory, create_surface(_, _, _)).Times(AnyNumber())
+        .WillOnce(Return(mt::fake_shared(mock_surface1)))
+        .WillOnce(Return(mt::fake_shared(mock_surface)));
+
+    msh::FocusController& focus_controller = shell;
+    auto const session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
+    auto const created_surface1 = shell.create_surface(session, params, nullptr);
+    auto const created_surface2 = shell.create_surface(session, params, nullptr);
+
+    focus_controller.set_focus_to(session, created_surface2);
+    EXPECT_THAT(created_surface1->focus_state(), Eq(mir_window_focus_state_unfocused));
+    EXPECT_THAT(created_surface2->focus_state(), Eq(mir_window_focus_state_focused));
+
+    focus_controller.set_focus_to(session, created_surface1);
+    EXPECT_THAT(created_surface1->focus_state(), Eq(mir_window_focus_state_focused));
+    EXPECT_THAT(created_surface2->focus_state(), Eq(mir_window_focus_state_unfocused));
+}
+
+TEST_F(AbstractShell, setting_focus_to_child_makes_parent_active)
+{
+    NiceMock<mtd::MockSurface> mock_surface1;
+    NiceMock<mtd::MockSurface> mock_surface2;
+    ON_CALL(mock_surface1, parent())
+        .WillByDefault(Return(mt::fake_shared(mock_surface)));
+    EXPECT_CALL(surface_factory, create_surface(_, _, _)).Times(AnyNumber())
+        .WillOnce(Return(mt::fake_shared(mock_surface)))
+        .WillOnce(Return(mt::fake_shared(mock_surface1)))
+        .WillOnce(Return(mt::fake_shared(mock_surface2)));
+
+    msh::FocusController& focus_controller = shell;
+    auto const session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
+    auto const parent_surface = shell.create_surface(session, params, nullptr);
+    auto const child_surface = shell.create_surface(session, params, nullptr);
+    auto const other_surface = shell.create_surface(session, params, nullptr);
+
+    ASSERT_THAT(child_surface->parent(), Eq(parent_surface));
+
+    focus_controller.set_focus_to(session, other_surface);
+    EXPECT_THAT(child_surface->focus_state(), Eq(mir_window_focus_state_unfocused));
+    EXPECT_THAT(parent_surface->focus_state(), Eq(mir_window_focus_state_unfocused));
+
+    focus_controller.set_focus_to(session, child_surface);
+    EXPECT_THAT(child_surface->focus_state(), Eq(mir_window_focus_state_focused));
+    EXPECT_THAT(parent_surface->focus_state(), Eq(mir_window_focus_state_active));
+}
+
+TEST_F(AbstractShell, does_not_give_keyboard_focus_to_menu)
+{
+    auto const surface_parent = create_surface(mock_surface);
+
+    NiceMock<mtd::MockSurface> mock_surface_child;
+    auto const surface_child = create_surface(mock_surface_child);
+    ON_CALL(mock_surface_child, parent())
+        .WillByDefault(Return(surface_parent));
+    ON_CALL(mock_surface_child, type())
+        .WillByDefault(Return(mir_window_type_menu));
+
+    msh::FocusController& focus_controller = shell;
+
+    EXPECT_CALL(mock_surface_child, set_focus_state(mir_window_focus_state_active));
+    EXPECT_CALL(mock_surface, set_focus_state(mir_window_focus_state_focused));
+    focus_controller.set_focus_to(surface_child->session().lock(), surface_child);
+}
+
+TEST_F(AbstractShell, does_not_give_keyboard_focus_to_tip)
+{
+    auto const surface_parent = create_surface(mock_surface);
+
+    NiceMock<mtd::MockSurface> mock_surface_child;
+    auto const surface_child = create_surface(mock_surface_child);
+    ON_CALL(mock_surface_child, parent())
+        .WillByDefault(Return(surface_parent));
+    ON_CALL(mock_surface_child, type())
+        .WillByDefault(Return(mir_window_type_tip));
+
+    msh::FocusController& focus_controller = shell;
+
+    EXPECT_CALL(mock_surface_child, set_focus_state(mir_window_focus_state_active));
+    EXPECT_CALL(mock_surface, set_focus_state(mir_window_focus_state_focused));
+    focus_controller.set_focus_to(surface_child->session().lock(), surface_child);
+}
+
+TEST_F(AbstractShell, does_not_deactivate_parent_when_switching_children)
+{
+    auto const surface_parent = create_surface(mock_surface);
+
+    NiceMock<mtd::MockSurface> mock_surface_child_a;
+    auto const surface_child_a = create_surface(mock_surface_child_a);
+    ON_CALL(mock_surface_child_a, parent())
+        .WillByDefault(Return(surface_parent));
+
+    NiceMock<mtd::MockSurface> mock_surface_child_b;
+    auto const surface_child_b = create_surface(mock_surface_child_b);
+    ON_CALL(mock_surface_child_b, parent())
+        .WillByDefault(Return(surface_parent));
+
+    msh::FocusController& focus_controller = shell;
+    focus_controller.set_focus_to(surface_child_a->session().lock(), surface_child_a);
+
+    EXPECT_CALL(mock_surface, set_focus_state(mir_window_focus_state_active)).Times(AnyNumber());
+    focus_controller.set_focus_to(surface_child_b->session().lock(), surface_child_b);
+}
+
+TEST_F(AbstractShell, makes_parent_active_when_switching_to_child)
+{
+    auto const surface_parent = create_surface(mock_surface);
+
+    NiceMock<mtd::MockSurface> mock_surface_child;
+    auto const surface_child = create_surface(mock_surface_child);
+    ON_CALL(mock_surface_child, parent())
+        .WillByDefault(Return(surface_parent));
+
+    msh::FocusController& focus_controller = shell;
+    focus_controller.set_focus_to(surface_parent->session().lock(), surface_parent);
+    /* window         | expected focus state
+     * -----------------------------------------------
+     * surface_parent | mir_window_focus_state_focused 
+     * surface_child  | <don't care>
+    */
+
+    EXPECT_CALL(mock_surface, set_focus_state(mir_window_focus_state_active));
+    focus_controller.set_focus_to(surface_child->session().lock(), surface_child);
+    /* window         | expected focus state
+     * -----------------------------------------------
+     * surface_parent | mir_window_focus_state_active
+     * surface_child  | mir_window_focus_state_focused
+    */
+
+}
+
+TEST_F(AbstractShell, makes_parent_focused_when_switching_back_from_child)
+{
+    auto const surface_parent = create_surface(mock_surface);
+
+    NiceMock<mtd::MockSurface> mock_surface_child;
+    auto const surface_child = create_surface(mock_surface_child);
+    ON_CALL(mock_surface_child, parent())
+        .WillByDefault(Return(surface_parent));
+
+    msh::FocusController& focus_controller = shell;
+    focus_controller.set_focus_to(surface_child->session().lock(), surface_child);
+    /* window         | expected focus state
+     * -----------------------------------------------
+     * surface_parent | mir_window_focus_state_active
+     * surface_child  | mir_window_focus_state_focused
+    */
+
+    EXPECT_CALL(mock_surface, set_focus_state(mir_window_focus_state_focused));
+    focus_controller.set_focus_to(surface_parent->session().lock(), surface_parent);
+    /* window         | expected focus state
+     * -----------------------------------------------
+     * surface_parent | mir_window_focus_state_focused
+     * surface_child  | <don't care>
+    */
+}
+
+TEST_F(AbstractShell, removing_focus_from_menu_closes_it)
+{
+    auto const surface_parent = create_surface(mock_surface);
+
+    NiceMock<mtd::MockSurface> mock_surface_menu;
+    auto const surface_menu = create_surface(mock_surface_menu);
+    ON_CALL(mock_surface_menu, parent())
+        .WillByDefault(Return(surface_parent));
+    ON_CALL(mock_surface_menu, type())
+        .WillByDefault(Return(mir_window_type_menu));
+
+    msh::FocusController& focus_controller = shell;
+    focus_controller.set_focus_to(surface_menu->session().lock(), surface_menu);
+
+    EXPECT_CALL(mock_surface_menu, request_client_surface_close());
+    focus_controller.set_focus_to(surface_parent->session().lock(), surface_parent);
+}
+
+// Regression test for https://github.com/MirServer/mir/issues/2279
+TEST_F(AbstractShell, focus_next_session_allows_later_focusing_same_window)
+{
+    NiceMock<mtd::MockSurface> mock_surface1;
+    EXPECT_CALL(surface_factory, create_surface(_, _, _)).Times(AnyNumber())
+        .WillOnce(Return(mt::fake_shared(mock_surface1)))
+        .WillOnce(Return(mt::fake_shared(mock_surface)));
+
+    msh::FocusController& focus_controller = shell;
+    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto session2 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
+    auto const params1 = mt::make_surface_spec(session1->create_buffer_stream(properties));
+    auto created_surface1 = shell.create_surface(session1, params1, nullptr);
+    auto const params2 = mt::make_surface_spec(session2->create_buffer_stream(properties));
+    auto created_surface2 = shell.create_surface(session2, params2, nullptr);
+
+    focus_controller.set_focus_to(session1, created_surface1);
+    focus_controller.focus_next_session();
+    focus_controller.set_focus_to(session2, created_surface2);
+
+    EXPECT_THAT(created_surface1->focus_state(), Eq(mir_window_focus_state_unfocused));
+    EXPECT_THAT(created_surface2->focus_state(), Eq(mir_window_focus_state_focused));
+}
+
 namespace mir
 {
 namespace scene
@@ -836,9 +1032,8 @@ TEST_F(AbstractShell, as_focus_controller_emits_input_device_state_event_on_focu
 {
     EXPECT_CALL(mock_surface, consume(mt::InputDeviceStateEvent())).Times(1);
 
-    auto session = shell.open_session(__LINE__, "some", std::shared_ptr<mf::EventSink>());
-    auto creation_params = ms::a_surface()
-        .with_buffer_stream(session->create_buffer_stream(properties));
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "some", std::shared_ptr<mf::EventSink>());
+    auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
     auto surface = shell.create_surface(session, creation_params, nullptr);
 
     msh::FocusController& focus_controller = shell;
