@@ -20,7 +20,6 @@
 
 #include "mir/scene/session.h"
 #include "mir/scene/session_container.h"
-#include "mir/scene/session_listener.h"
 #include "mir/scene/null_session_listener.h"
 #include "mir/graphics/display_configuration_observer.h"
 #include "mir/compositor/buffer_stream.h"
@@ -43,6 +42,7 @@
 #include "mir/test/doubles/stub_observer_registrar.h"
 
 #include "mir/test/fake_shared.h"
+#include "mir/test/make_surface_spec.h"
 
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
@@ -132,7 +132,7 @@ TEST_F(SessionManagerSessionListenerSetup, session_listener_is_notified_of_lifec
     EXPECT_CALL(session_listener, starting(_)).Times(1);
     EXPECT_CALL(session_listener, stopping(_)).Times(1);
 
-    auto session = session_manager.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto session = session_manager.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
     session_manager.close_session(session);
 }
 
@@ -145,7 +145,7 @@ TEST_F(SessionManagerSessionListenerSetup, additional_listeners_receive_session_
     EXPECT_CALL(*additional_listener, stopping(_)).Times(1);
 
     session_manager.add_listener(additional_listener);
-    auto session = session_manager.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto session = session_manager.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
     session_manager.close_session(session);
 }
 
@@ -159,7 +159,7 @@ TEST_F(SessionManagerSessionListenerSetup, additional_listeners_receive_focus_ch
     EXPECT_CALL(*additional_listener, unfocused()).Times(1);
 
     session_manager.add_listener(additional_listener);
-    auto session = session_manager.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto session = session_manager.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
     session_manager.set_focus_to(session);
     session_manager.unset_focus();
 }
@@ -173,10 +173,10 @@ TEST_F(SessionManagerSessionListenerSetup, additional_listeners_receive_surface_
     EXPECT_CALL(*additional_listener, surface_created(_,_)).Times(1);
 
     session_manager.add_listener(additional_listener);
-    auto session = session_manager.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto session = session_manager.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
     auto bs = std::dynamic_pointer_cast<mc::BufferStream>(session->create_buffer_stream(
         mg::BufferProperties{{640, 480}, mir_pixel_format_abgr_8888, mg::BufferUsage::hardware}));
-    session->create_surface(nullptr, ms::SurfaceCreationParameters().with_buffer_stream(bs), mt::fake_shared(observer));
+    session->create_surface(nullptr, mt::make_surface_spec(bs), mt::fake_shared(observer));
 }
 
 namespace
@@ -210,8 +210,8 @@ TEST_F(SessionManagerSessionEventsSetup, session_event_sink_is_notified_of_lifec
 {
     using namespace ::testing;
 
-    auto session = session_manager.open_session(__LINE__, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto session1 = session_manager.open_session(__LINE__, "Bla", std::shared_ptr<mf::EventSink>());
+    auto session = session_manager.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto session1 = session_manager.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
 
     Mock::VerifyAndClearExpectations(&session_event_sink);
 
