@@ -19,21 +19,15 @@
 #include "mir/events/event_private.h"
 #include "mir/events/event_builders.h"
 #include "src/server/scene/basic_surface.h"
-#include "mir/scene/surface_observer.h"
 #include "mir/scene/surface_event_source.h"
 #include "src/server/report/null_report_factory.h"
-#include "mir/frontend/event_sink.h"
-#include "mir/graphics/display_configuration.h"
 #include "mir/scene/output_properties_cache.h"
 
-#include "mir/test/doubles/stub_buffer_stream.h"
 #include "mir/test/doubles/mock_buffer_stream.h"
-#include "mir/test/doubles/null_event_sink.h"
 #include "mir/test/doubles/mock_event_sink.h"
 #include "mir/test/fake_shared.h"
 #include "mir/test/event_matchers.h"
 
-#include <cstring>
 #include <stdexcept>
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
@@ -188,7 +182,7 @@ TEST_F(Surface, emits_resize_events)
 
     surface->add_observer(observer);
 
-    auto e = mev::make_event(stub_id, new_size);
+    auto e = mev::make_window_resize_event(stub_id, new_size);
     EXPECT_CALL(*sink, handle_event(MirResizeEventEq(e.get())))
         .Times(1);
 
@@ -208,11 +202,11 @@ TEST_F(Surface, emits_resize_events_only_on_change)
 
     surface->add_observer(observer);
 
-    auto e = mev::make_event(stub_id, new_size);
+    auto e = mev::make_window_resize_event(stub_id, new_size);
     EXPECT_CALL(*sink, handle_event(MirResizeEventEq(e.get())))
         .Times(1);
 
-    auto e2 = mev::make_event(stub_id, new_size2);
+    auto e2 = mev::make_window_resize_event(stub_id, new_size2);
     EXPECT_CALL(*sink, handle_event(MirResizeEventEq(e2.get())))
         .Times(1);
 
