@@ -22,7 +22,6 @@
 
 #include "mir/test/signal.h"
 #include "mir/test/pipe.h"
-#include "mir/test/fake_shared.h"
 #include "mir/test/auto_unblock_thread.h"
 #include "mir/test/barrier.h"
 #include "mir/test/doubles/advanceable_clock.h"
@@ -1579,7 +1578,7 @@ TEST_F(GLibMainLoopTest, run_with_context_as_thread_default_handles_exceptions)
 
     // Without a running loop
     EXPECT_THROW(
-        ml.run_with_context_as_thread_default([]() { throw std::logic_error{"Hello!"}; }),
+        ml.run_with_context_as_thread_default([]() { throw std::logic_error{"Hello!"}; }).get(),
         std::logic_error);
 
     UnblockMainLoop unblock{ml};
@@ -1594,10 +1593,72 @@ TEST_F(GLibMainLoopTest, run_with_context_as_thread_default_handles_exceptions)
     ASSERT_TRUE(started->wait_for(30s));
 
     EXPECT_THROW(
-        ml.run_with_context_as_thread_default([]() { throw std::out_of_range{"Hello!"}; }),
+        ml.run_with_context_as_thread_default([]() { throw std::out_of_range{"Hello!"}; }).get(),
         std::out_of_range);
 }
 
+TEST_F(GLibMainLoopTest, run_with_context_as_thread_default_may_be_called_from_the_mainloop)
+{
+    using namespace std::literals::chrono_literals;
+    using namespace testing;
+
+    UnblockMainLoop unblock{ml};
+
+    auto started = std::make_shared<mt::Signal>();
+    ml.spawn(
+        [started]()
+        {
+            started->raise();
+        });
+
+    ASSERT_TRUE(started->wait_for(30s));
+
+    auto done = std::make_shared<mt::Signal>();
+
+    ml.spawn(
+        [this, done]()
+        {
+            auto ml_thread = std::this_thread::get_id();
+            auto invoke_done = std::make_shared<mt::Signal>();
+            ml.run_with_context_as_thread_default(
+                [&ml_thread, invoke_done]()
+                {
+                    EXPECT_THAT(std::this_thread::get_id(), Eq(ml_thread));
+                    invoke_done->raise();
+                });
+            EXPECT_TRUE(invoke_done->wait_for(30s));
+            done->raise();
+        });
+
+    EXPECT_TRUE(done->wait_for(30s));
+}
+
+TEST_F(GLibMainLoopTest, run_with_main_context_as_default_functor_can_return_values)
+{
+    using namespace std::literals::chrono_literals;
+    using namespace testing;
+
+    UnblockMainLoop unblock{ml};
+    auto constexpr expected_value{42};
+
+    auto future_int = ml.run_with_context_as_thread_default(
+        []()
+        {
+            return expected_value;
+        });
+
+    ASSERT_THAT(future_int.wait_for(30s), Eq(std::future_status::ready));
+    EXPECT_THAT(future_int.get(), Eq(expected_value));
+
+    auto future_void = ml.run_with_context_as_thread_default(
+        []()
+        {
+            return;
+        });
+
+    EXPECT_THAT(future_void.wait_for(30s), Eq(std::future_status::ready));
+}
+
 // This test recreates a scenario we get in our integration and acceptance test
 // runs, and which creates problems for the default glib signal source. The
 // scenario involves creating, running (with signal handling) and destroying
