@@ -23,21 +23,6 @@
 #include <gmock/gmock.h>
 
 #include <chrono>
-#include <fcntl.h>
-
-namespace {
-
-void drain_dev_random()
-{
-    // Flush the entropy pool
-    int fd = open("/dev/random", O_RDONLY | O_NONBLOCK);
-    ASSERT_THAT(fd, ::testing::Ge(0));
-    char buf[256];
-    while (read(fd, buf, sizeof buf) > 0) {}
-    close(fd);
-}
-
-} // anonymous namespace
 
 
 TEST(MirCookieAuthority, attests_real_timestamp)
@@ -133,35 +118,3 @@ TEST(MirCookieAuthority, optimal_secret_size_is_larger_than_minimum_size)
     EXPECT_THAT(mir::cookie::Authority::optimal_secret_size(),
         Ge(mir::cookie::Authority::minimum_secret_size));
 }
-
-TEST(MirCookieAuthority, DISABLED_given_low_entropy_does_not_hang_or_crash)
-{   // Regression test for LP: #1536662 and LP: #1541188
-    using namespace testing;
-
-    drain_dev_random();
-
-    auto start = std::chrono::high_resolution_clock::now();
-
-    EXPECT_NO_THROW( mir::cookie::Authority::create() );
-
-    auto duration = std::chrono::high_resolution_clock::now() - start;
-    int seconds = std::chrono::duration_cast<std::chrono::seconds>(duration).count();
-    EXPECT_THAT(seconds, Lt(15));
-}
-
-TEST(MirCookieAuthority, DISABLED_makes_cookies_quickly)
-{   // Regression test for LP: #1536662 and LP: #1541188
-    using namespace testing;
-
-    drain_dev_random();
-    uint64_t timestamp = 23;
-    std::vector<uint8_t> secret;
-    auto source_authority = mir::cookie::Authority::create_saving(secret);
-
-    drain_dev_random();
-    auto start = std::chrono::high_resolution_clock::now();
-    auto cookie = source_authority->make_cookie(timestamp);
-    auto duration = std::chrono::high_resolution_clock::now() - start;
-    int seconds = std::chrono::duration_cast<std::chrono::seconds>(duration).count();
-    EXPECT_THAT(seconds, Lt(5));
-}
