@@ -8,21 +8,14 @@ timeout=3
 wayland_display="mir-smoke-test"
 options="--test-timeout=${timeout}"
 
-if [ -v MIR_SOCKET ]
-then
-  if [ ! -e "${MIR_SOCKET}" ]
-  then
-    echo "Error: Host endpoint '${MIR_SOCKET}' does not exist"; exit 1
-  fi
-  options="${options} --host-socket ${MIR_SOCKET}"
-fi
-
 root="$( dirname "${BASH_SOURCE[0]}" )"
 
 client_list=`find ${root} -name mir_demo_client_* | grep -v bin$ | sed s?${root}/??`
 echo "I: client_list=" ${client_list}
 
 ### Run Tests ###
+# The CI environment sets this test-specific env var, mir_demo_server doesn't know it
+unset MIR_SERVER_LOGGING
 
 # Start with eglinfo for the system
 echo Running eglinfo client
@@ -32,6 +25,12 @@ WAYLAND_DISPLAY=${wayland_display} ${root}/mir_demo_server ${options} --test-cli
 date --utc --iso-8601=seconds | xargs echo "[timestamp] End :" ${client}
 
 for client in ${client_list}; do
+  if [[ "$XAUTHORITY" =~ .*xvfb-run.* ]]; then
+    if [[ "${client}" = mir_demo_client_wayland_egl_spinner ]]; then
+      # Skipped because of https://github.com/MirServer/mir/issues/2154
+      continue
+    fi
+  fi
     echo running client ${client}
     date --utc --iso-8601=seconds | xargs echo "[timestamp] Start :" ${client}
     echo WAYLAND_DISPLAY=${wayland_display} ${root}/mir_demo_server ${options} --test-client ${root}/${client}
